@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Colour
 ======
@@ -13,6 +12,7 @@ Subpackages
 -   adaptation: Chromatic adaptation models and transformations.
 -   algebra: Algebra utilities.
 -   appearance: Colour appearance models.
+-   biochemistry: Biochemistry computations.
 -   characterisation: Colour fitting and camera characterisation.
 -   colorimetry: Core objects for colour computations.
 -   constants: *CIE* and *CODATA* constants.
@@ -40,6 +40,8 @@ from .adaptation import *  # noqa
 from . import adaptation  # noqa
 from .algebra import *  # noqa
 from . import algebra  # noqa
+from .biochemistry import *  # noqa
+from . import biochemistry  # noqa
 from .colorimetry import *  # noqa
 from . import colorimetry  # noqa
 from .appearance import *  # noqa
@@ -80,6 +82,7 @@ __all__ = []
 __all__ += utilities.__all__
 __all__ += adaptation.__all__
 __all__ += algebra.__all__
+__all__ += biochemistry.__all__
 __all__ += colorimetry.__all__
 __all__ += appearance.__all__
 __all__ += constants.__all__
@@ -99,7 +102,8 @@ __application_name__ = 'Colour'
 
 __major_version__ = '0'
 __minor_version__ = '3'
-__change_version__ = '9'
-__version__ = '.'.join((__major_version__,
-                        __minor_version__,
-                        __change_version__))
+__change_version__ = '10'
+__version__ = '.'.join(
+    (__major_version__,
+     __minor_version__,
+     __change_version__))  # yapf: disable
