@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Chromatic Adaptation Transforms
 ===============================
@@ -62,18 +61,11 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['XYZ_SCALING_CAT',
-           'VON_KRIES_CAT',
-           'BRADFORD_CAT',
-           'SHARP_CAT',
-           'FAIRCHILD_CAT',
-           'CMCCAT97_CAT',
-           'CMCCAT2000_CAT',
-           'CAT02_CAT',
-           'CAT02_BRILL_CAT',
-           'BS_CAT',
-           'BS_PC_CAT',
-           'CHROMATIC_ADAPTATION_TRANSFORMS']
+__all__ = [
+    'XYZ_SCALING_CAT', 'VON_KRIES_CAT', 'BRADFORD_CAT', 'SHARP_CAT',
+    'FAIRCHILD_CAT', 'CMCCAT97_CAT', 'CMCCAT2000_CAT', 'CAT02_CAT',
+    'CAT02_BRILL_CAT', 'BS_CAT', 'BS_PC_CAT', 'CHROMATIC_ADAPTATION_TRANSFORMS'
+]
 
 XYZ_SCALING_CAT = np.array(np.identity(3)).reshape((3, 3))
 """
@@ -85,7 +77,7 @@ XYZ_SCALING_CAT : array_like, (3, 3)
 VON_KRIES_CAT = np.array(
     [[0.4002400, 0.7076000, -0.0808100],
      [-0.2263000, 1.1653200, 0.0457000],
-     [0.0000000, 0.0000000, 0.9182200]])
+     [0.0000000, 0.0000000, 0.9182200]])  # yapf: disable
 """
 *Von Kries* chromatic adaptation transform. [1]_
 
@@ -95,7 +87,7 @@ VON_KRIES_CAT : array_like, (3, 3)
 BRADFORD_CAT = np.array(
     [[0.8951000, 0.2664000, -0.1614000],
      [-0.7502000, 1.7135000, 0.0367000],
-     [0.0389000, -0.0685000, 1.0296000]])
+     [0.0389000, -0.0685000, 1.0296000]])  # yapf: disable
 """
 *Bradford* chromatic adaptation transform. [1]_
 
@@ -105,7 +97,7 @@ BRADFORD_CAT : array_like, (3, 3)
 SHARP_CAT = np.array(
     [[1.2694, -0.0988, -0.1706],
      [-0.8364, 1.8006, 0.0357],
-     [0.0297, -0.0315, 1.0018]])
+     [0.0297, -0.0315, 1.0018]])  # yapf: disable
 """
 *Sharp* chromatic adaptation transform. [4]_
 
@@ -115,7 +107,7 @@ SHARP_CAT : array_like, (3, 3)
 FAIRCHILD_CAT = np.array(
     [[0.8562, 0.3372, -0.1934],
      [-0.8360, 1.8327, 0.0033],
-     [0.0357, -0.0469, 1.0112]])
+     [0.0357, -0.0469, 1.0112]])  # yapf: disable
 """
 *Fairchild* chromatic adaptation transform. [2]_
 
@@ -125,7 +117,7 @@ FAIRCHILD_CAT : array_like, (3, 3)
 CMCCAT97_CAT = np.array(
     [[0.8951, -0.7502, 0.0389],
      [0.2664, 1.7135, 0.0685],
-     [-0.1614, 0.0367, 1.0296]])
+     [-0.1614, 0.0367, 1.0296]])  # yapf: disable
 """
 *CMCCAT97* chromatic adaptation transform. [5]_
 
@@ -135,7 +127,7 @@ CMCCAT97_CAT : array_like, (3, 3)
 CMCCAT2000_CAT = np.array(
     [[0.7982, 0.3389, -0.1371],
      [-0.5918, 1.5512, 0.0406],
-     [0.0008, 0.0239, 0.9753]])
+     [0.0008, 0.0239, 0.9753]])  # yapf: disable
 """
 *CMCCAT2000* chromatic adaptation transform. [5]_
 
@@ -145,7 +137,7 @@ CMCCAT2000_CAT : array_like, (3, 3)
 CAT02_CAT = np.array(
     [[0.7328, 0.4296, -0.1624],
      [-0.7036, 1.6975, 0.0061],
-     [0.0030, 0.0136, 0.9834]])
+     [0.0030, 0.0136, 0.9834]])  # yapf: disable
 """
 *CAT02* chromatic adaptation transform. [3]_
 
@@ -155,7 +147,7 @@ CAT02_CAT : array_like, (3, 3)
 CAT02_BRILL_CAT = np.array(
     [[0.7328, 0.4296, -0.1624],
      [-0.7036, 1.6975, 0.0061],
-     [0.0000, 0.0000, 1.0000]])
+     [0.0000, 0.0000, 1.0000]])  # yapf: disable
 """
 *Brill and Süsstrunk (2008)* corrected CAT02 chromatic adaptation
 transform. [6]_ [7]
@@ -166,7 +158,7 @@ CAT02_BRILL_CAT : array_like, (3, 3)
 BS_CAT = np.array(
     [[0.8752, 0.2787, -0.1539],
      [-0.8904, 1.8709, 0.0195],
-     [-0.0061, 0.0162, 0.9899]])
+     [-0.0061, 0.0162, 0.9899]])  # yapf: disable
 """
 *Bianco and Schettini (2010)* chromatic adaptation transform. [4]_
 
@@ -176,7 +168,7 @@ BS_CAT : array_like, (3, 3)
 BS_PC_CAT = np.array(
     [[0.6489, 0.3915, -0.0404],
      [-0.3775, 1.3055, 0.0720],
-     [-0.0271, 0.0888, 0.9383]])
+     [-0.0271, 0.0888, 0.9383]])  # yapf: disable
 """
 *Bianco and Schettini PC (2010)* chromatic adaptation transform. [4]_
 
@@ -187,18 +179,19 @@ Notes
 -   This chromatic adaptation transform has no negative lobes.
 """
 
-CHROMATIC_ADAPTATION_TRANSFORMS = CaseInsensitiveMapping(
-    {'XYZ Scaling': XYZ_SCALING_CAT,
-     'Von Kries': VON_KRIES_CAT,
-     'Bradford': BRADFORD_CAT,
-     'Sharp': SHARP_CAT,
-     'Fairchild': FAIRCHILD_CAT,
-     'CMCCAT97': CMCCAT97_CAT,
-     'CMCCAT2000': CMCCAT2000_CAT,
-     'CAT02': CAT02_CAT,
-     'CAT02_BRILL_CAT': CAT02_BRILL_CAT,
-     'Bianco': BS_CAT,
-     'Bianco PC': BS_PC_CAT})
+CHROMATIC_ADAPTATION_TRANSFORMS = CaseInsensitiveMapping({
+    'XYZ Scaling': XYZ_SCALING_CAT,
+    'Von Kries': VON_KRIES_CAT,
+    'Bradford': BRADFORD_CAT,
+    'Sharp': SHARP_CAT,
+    'Fairchild': FAIRCHILD_CAT,
+    'CMCCAT97': CMCCAT97_CAT,
+    'CMCCAT2000': CMCCAT2000_CAT,
+    'CAT02': CAT02_CAT,
+    'CAT02_BRILL_CAT': CAT02_BRILL_CAT,
+    'Bianco': BS_CAT,
+    'Bianco PC': BS_PC_CAT
+})
 """
 Supported chromatic adaptation transforms.
 
