@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Defines unit tests for :mod:`colour.algebra.random` module.
 """
@@ -19,20 +18,19 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['RANDOM_TRIPLETS',
-           'TestRandomTripletGenerator']
+__all__ = ['RANDOM_TRIPLETS', 'TestRandomTripletGenerator']
 
-RANDOM_TRIPLETS = np.array([
-    [0.96702984, 0.54723225, 0.97268436],
-    [0.71481599, 0.69772882, 0.21608950],
-    [0.97627445, 0.00623026, 0.25298236],
-    [0.43479153, 0.77938292, 0.19768507],
-    [0.86299324, 0.98340068, 0.16384224],
-    [0.59733394, 0.00898610, 0.38657128],
-    [0.04416006, 0.95665297, 0.43614665],
-    [0.94897731, 0.78630599, 0.86628930],
-    [0.17316542, 0.07494859, 0.60074272],
-    [0.16797218, 0.73338017, 0.40844386]])
+RANDOM_TRIPLETS = np.array(
+    [[0.96702984, 0.54723225, 0.97268436],
+     [0.71481599, 0.69772882, 0.21608950],
+     [0.97627445, 0.00623026, 0.25298236],
+     [0.43479153, 0.77938292, 0.19768507],
+     [0.86299324, 0.98340068, 0.16384224],
+     [0.59733394, 0.00898610, 0.38657128],
+     [0.04416006, 0.95665297, 0.43614665],
+     [0.94897731, 0.78630599, 0.86628930],
+     [0.17316542, 0.07494859, 0.60074272],
+     [0.16797218, 0.73338017, 0.40844386]])  # yapf: disable
 
 
 class TestRandomTripletGenerator(unittest.TestCase):
