@@ -3,12 +3,14 @@
 
 from __future__ import absolute_import
 
+from .cameras import RGB_SpectralSensitivities
 from .displays import RGB_DisplayPrimaries
 from .dataset import *  # noqa
 from . import dataset
 from .fitting import first_order_colour_fit
 
 __all__ = []
+__all__ += ['RGB_SpectralSensitivities']
 __all__ += ['RGB_DisplayPrimaries']
 __all__ += dataset.__all__
 __all__ += ['first_order_colour_fit']
