@@ -8,7 +8,7 @@ from .d_illuminants_s_spds import D_ILLUMINANTS_S_SPDS
 from .hunterlab import HUNTERLAB_ILLUMINANTS
 from .spds import ILLUMINANTS_RELATIVE_SPDS
 
-__all__ = ['ILLUMINANTS',
-           'D_ILLUMINANTS_S_SPDS',
-           'HUNTERLAB_ILLUMINANTS',
-           'ILLUMINANTS_RELATIVE_SPDS']
+__all__ = [
+    'ILLUMINANTS', 'D_ILLUMINANTS_S_SPDS', 'HUNTERLAB_ILLUMINANTS',
+    'ILLUMINANTS_RELATIVE_SPDS'
+]
