@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Illuminants Chromaticity Coordinates
 ====================================
@@ -70,32 +69,32 @@ __status__ = 'Production'
 
 __all__ = [
     'ILLUMINANTS_CIE_1931_2_DEGREE_STANDARD_OBSERVER',
-    'ILLUMINANTS_CIE_1964_10_DEGREE_STANDARD_OBSERVER',
-    'ILLUMINANTS']
+    'ILLUMINANTS_CIE_1964_10_DEGREE_STANDARD_OBSERVER', 'ILLUMINANTS'
+]
 
-ILLUMINANTS_CIE_1931_2_DEGREE_STANDARD_OBSERVER = (
-    CaseInsensitiveMapping({
-        'A': np.array([0.44757, 0.40745]),
-        'B': np.array([0.34842, 0.35161]),
-        'C': np.array([0.31006, 0.31616]),
-        'D50': np.array([0.34570, 0.35850]),
-        'D55': np.array([0.33242, 0.34743]),
-        'D60': np.array([0.32168, 0.33767]),
-        'D65': np.array([0.31270, 0.32900]),
-        'D75': np.array([0.29902, 0.31485]),
-        'E': np.array([1 / 3, 1 / 3]),
-        'F1': np.array([0.31310, 0.33727]),
-        'F2': np.array([0.37208, 0.37529]),
-        'F3': np.array([0.40910, 0.39430]),
-        'F4': np.array([0.44018, 0.40329]),
-        'F5': np.array([0.31379, 0.34531]),
-        'F6': np.array([0.37790, 0.38835]),
-        'F7': np.array([0.31292, 0.32933]),
-        'F8': np.array([0.34588, 0.35875]),
-        'F9': np.array([0.37417, 0.37281]),
-        'F10': np.array([0.34609, 0.35986]),
-        'F11': np.array([0.38052, 0.37713]),
-        'F12': np.array([0.43695, 0.40441])}))
+ILLUMINANTS_CIE_1931_2_DEGREE_STANDARD_OBSERVER = CaseInsensitiveMapping({
+    'A': np.array([0.44757, 0.40745]),
+    'B': np.array([0.34842, 0.35161]),
+    'C': np.array([0.31006, 0.31616]),
+    'D50': np.array([0.34570, 0.35850]),
+    'D55': np.array([0.33242, 0.34743]),
+    'D60': np.array([0.32168, 0.33767]),
+    'D65': np.array([0.31270, 0.32900]),
+    'D75': np.array([0.29902, 0.31485]),
+    'E': np.array([1 / 3, 1 / 3]),
+    'F1': np.array([0.31310, 0.33727]),
+    'F2': np.array([0.37208, 0.37529]),
+    'F3': np.array([0.40910, 0.39430]),
+    'F4': np.array([0.44018, 0.40329]),
+    'F5': np.array([0.31379, 0.34531]),
+    'F6': np.array([0.37790, 0.38835]),
+    'F7': np.array([0.31292, 0.32933]),
+    'F8': np.array([0.34588, 0.35875]),
+    'F9': np.array([0.37417, 0.37281]),
+    'F10': np.array([0.34609, 0.35986]),
+    'F11': np.array([0.38052, 0.37713]),
+    'F12': np.array([0.43695, 0.40441])
+})
 """
 *CIE* illuminant chromaticity coordinates for
 *CIE 1931 2 Degree Standard Observer*.
@@ -103,29 +102,29 @@ ILLUMINANTS_CIE_1931_2_DEGREE_STANDARD_OBSERVER = (
 ILLUMINANTS_CIE_1931_2_DEGREE_STANDARD_OBSERVER : CaseInsensitiveMapping
 """
 
-ILLUMINANTS_CIE_1964_10_DEGREE_STANDARD_OBSERVER = (
-    CaseInsensitiveMapping({
-        'A': np.array([0.45117, 0.40594]),
-        'B': np.array([0.34980, 0.35270]),
-        'C': np.array([0.31039, 0.31905]),
-        'D50': np.array([0.34773, 0.35952]),
-        'D55': np.array([0.33411, 0.34877]),
-        'D60': np.array([0.322957407931312, 0.339135835524579]),
-        'D65': np.array([0.31382, 0.33100]),
-        'D75': np.array([0.29968, 0.31740]),
-        'E': np.array([1 / 3, 1 / 3]),
-        'F1': np.array([0.31811, 0.33559]),
-        'F2': np.array([0.37925, 0.36733]),
-        'F3': np.array([0.41761, 0.38324]),
-        'F4': np.array([0.44920, 0.39074]),
-        'F5': np.array([0.31975, 0.34246]),
-        'F6': np.array([0.38660, 0.37847]),
-        'F7': np.array([0.31569, 0.32960]),
-        'F8': np.array([0.34902, 0.35939]),
-        'F9': np.array([0.37829, 0.37045]),
-        'F10': np.array([0.35090, 0.35444]),
-        'F11': np.array([0.38541, 0.37123]),
-        'F12': np.array([0.44256, 0.39717])}))
+ILLUMINANTS_CIE_1964_10_DEGREE_STANDARD_OBSERVER = CaseInsensitiveMapping({
+    'A': np.array([0.45117, 0.40594]),
+    'B': np.array([0.34980, 0.35270]),
+    'C': np.array([0.31039, 0.31905]),
+    'D50': np.array([0.34773, 0.35952]),
+    'D55': np.array([0.33411, 0.34877]),
+    'D60': np.array([0.322957407931312, 0.339135835524579]),
+    'D65': np.array([0.31382, 0.33100]),
+    'D75': np.array([0.29968, 0.31740]),
+    'E': np.array([1 / 3, 1 / 3]),
+    'F1': np.array([0.31811, 0.33559]),
+    'F2': np.array([0.37925, 0.36733]),
+    'F3': np.array([0.41761, 0.38324]),
+    'F4': np.array([0.44920, 0.39074]),
+    'F5': np.array([0.31975, 0.34246]),
+    'F6': np.array([0.38660, 0.37847]),
+    'F7': np.array([0.31569, 0.32960]),
+    'F8': np.array([0.34902, 0.35939]),
+    'F9': np.array([0.37829, 0.37045]),
+    'F10': np.array([0.35090, 0.35444]),
+    'F11': np.array([0.38541, 0.37123]),
+    'F12': np.array([0.44256, 0.39717])
+})
 """
 *CIE* illuminant chromaticity coordinates for
 *CIE 1964 10 Degree Standard Observer*.
@@ -137,7 +136,8 @@ ILLUMINANTS = CaseInsensitiveMapping({
     'CIE 1931 2 Degree Standard Observer':
         ILLUMINANTS_CIE_1931_2_DEGREE_STANDARD_OBSERVER,
     'CIE 1964 10 Degree Standard Observer':
-        ILLUMINANTS_CIE_1964_10_DEGREE_STANDARD_OBSERVER})
+        ILLUMINANTS_CIE_1964_10_DEGREE_STANDARD_OBSERVER
+})
 """
 Aggregated *CIE* illuminants chromaticity coordinates.
 
@@ -175,7 +175,8 @@ ILLUMINANTS_CIE_1931_2_DEGREE_STANDARD_OBSERVER.update({
     'HP2': np.array([0.477790101185585, 0.415837783979245]),
     'HP3': np.array([0.430229454588196, 0.407513947069155]),
     'HP4': np.array([0.381167337458579, 0.379718304902536]),
-    'HP5': np.array([0.377583057157757, 0.371347698500182])})
+    'HP5': np.array([0.377583057157757, 0.371347698500182])
+})
 
 ILLUMINANTS_CIE_1964_10_DEGREE_STANDARD_OBSERVER.update({
     'FL3.1': np.array([0.449830684010003, 0.390231404321266]),
@@ -197,7 +198,9 @@ ILLUMINANTS_CIE_1964_10_DEGREE_STANDARD_OBSERVER.update({
     'HP2': np.array([0.482647330648721, 0.410815644179685]),
     'HP3': np.array([0.435560034503954, 0.398801084399711]),
     'HP4': np.array([0.385193641123543, 0.368275479241015]),
-    'HP5': np.array([0.380316415606638, 0.366617114797851])})
+    'HP5': np.array([0.380316415606638, 0.366617114797851])
+})
 
 ILLUMINANTS_CIE_1931_2_DEGREE_STANDARD_OBSERVER.update({
-    'DCI-P3': np.array([0.31400, 0.35100])})
+    'DCI-P3': np.array([0.31400, 0.35100])
+})
