@@ -6,5 +6,4 @@ from __future__ import absolute_import
 from .chromaticity_coordinates import LIGHT_SOURCES
 from .spds import LIGHT_SOURCES_RELATIVE_SPDS
 
-__all__ = ['LIGHT_SOURCES',
-           'LIGHT_SOURCES_RELATIVE_SPDS']
+__all__ = ['LIGHT_SOURCES', 'LIGHT_SOURCES_RELATIVE_SPDS']
