@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Defines unit tests for :mod:`colour.colorimetry.lightness` module.
 """
@@ -10,10 +9,8 @@ from __future__ import division, unicode_literals
 import numpy as np
 import unittest
 
-from colour.colorimetry import (
-    lightness_Glasser1958,
-    lightness_Wyszecki1963,
-    lightness_CIE1976)
+from colour.colorimetry import (lightness_Glasser1958, lightness_Wyszecki1963,
+                                lightness_CIE1976, lightness_Fairchild2010)
 from colour.utilities import ignore_numpy_errors
 
 __author__ = 'Colour Developers'
@@ -23,9 +20,10 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['TestLightnessGlasser1958',
-           'TestLightnessWyszecki1963',
-           'TestLightnessCIE1976']
+__all__ = [
+    'TestLightnessGlasser1958', 'TestLightnessWyszecki1963',
+    'TestLightnessCIE1976', 'TestLightnessFairchild2010'
+]
 
 
 class TestLightnessGlasser1958(unittest.TestCase):
@@ -41,19 +39,13 @@ class TestLightnessGlasser1958(unittest.TestCase):
         """
 
         self.assertAlmostEqual(
-            lightness_Glasser1958(10.08),
-            36.25056265,
-            places=7)
+            lightness_Glasser1958(10.08), 36.25056265, places=7)
 
         self.assertAlmostEqual(
-            lightness_Glasser1958(56.76),
-            78.81179990,
-            places=7)
+            lightness_Glasser1958(56.76), 78.81179990, places=7)
 
         self.assertAlmostEqual(
-            lightness_Glasser1958(98.32),
-            98.34470526,
-            places=7)
+            lightness_Glasser1958(98.32), 98.34470526, places=7)
 
     def test_n_dimensional_lightness_Glasser1958(self):
         """
@@ -63,31 +55,19 @@ class TestLightnessGlasser1958(unittest.TestCase):
 
         Y = 10.08
         L = 36.25056265
-        np.testing.assert_almost_equal(
-            lightness_Glasser1958(Y),
-            L,
-            decimal=7)
+        np.testing.assert_almost_equal(lightness_Glasser1958(Y), L, decimal=7)
 
         Y = np.tile(Y, 6)
         L = np.tile(L, 6)
-        np.testing.assert_almost_equal(
-            lightness_Glasser1958(Y),
-            L,
-            decimal=7)
+        np.testing.assert_almost_equal(lightness_Glasser1958(Y), L, decimal=7)
 
         Y = np.reshape(Y, (2, 3))
         L = np.reshape(L, (2, 3))
-        np.testing.assert_almost_equal(
-            lightness_Glasser1958(Y),
-            L,
-            decimal=7)
+        np.testing.assert_almost_equal(lightness_Glasser1958(Y), L, decimal=7)
 
         Y = np.reshape(Y, (2, 3, 1))
         L = np.reshape(L, (2, 3, 1))
-        np.testing.assert_almost_equal(
-            lightness_Glasser1958(Y),
-            L,
-            decimal=7)
+        np.testing.assert_almost_equal(lightness_Glasser1958(Y), L, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_lightness_Glasser1958(self):
@@ -113,19 +93,13 @@ class TestLightnessWyszecki1963(unittest.TestCase):
         """
 
         self.assertAlmostEqual(
-            lightness_Wyszecki1963(10.08),
-            37.00411491,
-            places=7)
+            lightness_Wyszecki1963(10.08), 37.00411491, places=7)
 
         self.assertAlmostEqual(
-            lightness_Wyszecki1963(56.76),
-            79.07730319,
-            places=7)
+            lightness_Wyszecki1963(56.76), 79.07730319, places=7)
 
         self.assertAlmostEqual(
-            lightness_Wyszecki1963(98.32),
-            98.38622505,
-            places=7)
+            lightness_Wyszecki1963(98.32), 98.38622505, places=7)
 
     def test_n_dimensional_lightness_Wyszecki1963(self):
         """
@@ -135,31 +109,19 @@ class TestLightnessWyszecki1963(unittest.TestCase):
 
         Y = 10.08
         W = 37.004114912764535
-        np.testing.assert_almost_equal(
-            lightness_Wyszecki1963(Y),
-            W,
-            decimal=7)
+        np.testing.assert_almost_equal(lightness_Wyszecki1963(Y), W, decimal=7)
 
         Y = np.tile(Y, 6)
         W = np.tile(W, 6)
-        np.testing.assert_almost_equal(
-            lightness_Wyszecki1963(Y),
-            W,
-            decimal=7)
+        np.testing.assert_almost_equal(lightness_Wyszecki1963(Y), W, decimal=7)
 
         Y = np.reshape(Y, (2, 3))
         W = np.reshape(W, (2, 3))
-        np.testing.assert_almost_equal(
-            lightness_Wyszecki1963(Y),
-            W,
-            decimal=7)
+        np.testing.assert_almost_equal(lightness_Wyszecki1963(Y), W, decimal=7)
 
         Y = np.reshape(Y, (2, 3, 1))
         W = np.reshape(W, (2, 3, 1))
-        np.testing.assert_almost_equal(
-            lightness_Wyszecki1963(Y),
-            W,
-            decimal=7)
+        np.testing.assert_almost_equal(lightness_Wyszecki1963(Y), W, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_lightness_Wyszecki1963(self):
@@ -184,35 +146,20 @@ class TestLightnessCIE1976(unittest.TestCase):
         definition.
         """
 
-        self.assertAlmostEqual(
-            lightness_CIE1976(10.08),
-            37.98562910,
-            places=7)
+        self.assertAlmostEqual(lightness_CIE1976(10.08), 37.98562910, places=7)
+
+        self.assertAlmostEqual(lightness_CIE1976(56.76), 80.04441556, places=7)
+
+        self.assertAlmostEqual(lightness_CIE1976(98.32), 99.34672790, places=7)
 
         self.assertAlmostEqual(
-            lightness_CIE1976(56.76),
-            80.04441556,
-            places=7)
+            lightness_CIE1976(10.08, 50), 52.01763049, places=7)
 
         self.assertAlmostEqual(
-            lightness_CIE1976(98.32),
-            99.34672790,
-            places=7)
+            lightness_CIE1976(10.08, 75), 43.41887326, places=7)
 
         self.assertAlmostEqual(
-            lightness_CIE1976(10.08, 50),
-            52.01763049,
-            places=7)
-
-        self.assertAlmostEqual(
-            lightness_CIE1976(10.08, 75),
-            43.41887326,
-            places=7)
-
-        self.assertAlmostEqual(
-            lightness_CIE1976(10.08, 95),
-            38.91659876,
-            places=7)
+            lightness_CIE1976(10.08, 95), 38.91659876, places=7)
 
     def test_n_dimensional_lightness_CIE1976(self):
         """
@@ -222,31 +169,19 @@ class TestLightnessCIE1976(unittest.TestCase):
 
         Y = 10.08
         Lstar = 37.98562910
-        np.testing.assert_almost_equal(
-            lightness_CIE1976(Y),
-            Lstar,
-            decimal=7)
+        np.testing.assert_almost_equal(lightness_CIE1976(Y), Lstar, decimal=7)
 
         Y = np.tile(Y, 6)
         Lstar = np.tile(Lstar, 6)
-        np.testing.assert_almost_equal(
-            lightness_CIE1976(Y),
-            Lstar,
-            decimal=7)
+        np.testing.assert_almost_equal(lightness_CIE1976(Y), Lstar, decimal=7)
 
         Y = np.reshape(Y, (2, 3))
         Lstar = np.reshape(Lstar, (2, 3))
-        np.testing.assert_almost_equal(
-            lightness_CIE1976(Y),
-            Lstar,
-            decimal=7)
+        np.testing.assert_almost_equal(lightness_CIE1976(Y), Lstar, decimal=7)
 
         Y = np.reshape(Y, (2, 3, 1))
         Lstar = np.reshape(Lstar, (2, 3, 1))
-        np.testing.assert_almost_equal(
-            lightness_CIE1976(Y),
-            Lstar,
-            decimal=7)
+        np.testing.assert_almost_equal(lightness_CIE1976(Y), Lstar, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_lightness_CIE1976(self):
@@ -255,7 +190,73 @@ class TestLightnessCIE1976(unittest.TestCase):
         definition nan support.
         """
 
-        lightness_CIE1976(
+        lightness_CIE1976(np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
+
+
+class TestLightnessFairchild2010(unittest.TestCase):
+    """
+    Defines :func:`colour.colorimetry.lightness.lightness_Fairchild2010`
+    definition unit tests methods.
+    """
+
+    def test_lightness_Fairchild2010(self):
+        """
+        Tests :func:`colour.colorimetry.lightness.lightness_Fairchild2010`
+        definition.
+        """
+
+        self.assertAlmostEqual(
+            lightness_Fairchild2010(10.08 / 100), 23.10363383, places=7)
+
+        self.assertAlmostEqual(
+            lightness_Fairchild2010(56.76 / 100), 90.51057574, places=7)
+
+        self.assertAlmostEqual(
+            lightness_Fairchild2010(98.32 / 100), 96.636221285, places=7)
+
+        self.assertAlmostEqual(
+            lightness_Fairchild2010(10.08 / 100, 2.75), 16.06420271, places=7)
+
+        self.assertAlmostEqual(
+            lightness_Fairchild2010(1008), 100.01999667, places=7)
+
+        self.assertAlmostEqual(
+            lightness_Fairchild2010(100800), 100.01999999, places=7)
+
+    def test_n_dimensional_lightness_Fairchild2010(self):
+        """
+        Tests :func:`colour.colorimetry.lightness.lightness_Fairchild2010`
+        definition n-dimensional arrays support.
+        """
+
+        Y = 10.08 / 100
+        L = 23.10363383
+        np.testing.assert_almost_equal(
+            lightness_Fairchild2010(Y), L, decimal=7)
+
+        Y = np.tile(Y, 6)
+        L = np.tile(L, 6)
+        np.testing.assert_almost_equal(
+            lightness_Fairchild2010(Y), L, decimal=7)
+
+        Y = np.reshape(Y, (2, 3))
+        L = np.reshape(L, (2, 3))
+        np.testing.assert_almost_equal(
+            lightness_Fairchild2010(Y), L, decimal=7)
+
+        Y = np.reshape(Y, (2, 3, 1))
+        L = np.reshape(L, (2, 3, 1))
+        np.testing.assert_almost_equal(
+            lightness_Fairchild2010(Y), L, decimal=7)
+
+    @ignore_numpy_errors
+    def test_nan_lightness_Fairchild2010(self):
+        """
+        Tests :func:`colour.colorimetry.lightness.lightness_Fairchild2010`
+        definition nan support.
+        """
+
+        lightness_Fairchild2010(
             np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
 
 
