@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Defines unit tests for :mod:`colour.colorimetry.luminance` module.
 """
@@ -11,9 +10,8 @@ import numpy as np
 import unittest
 
 from colour.colorimetry.luminance import (
-    luminance_Newhall1943,
-    luminance_CIE1976,
-    luminance_ASTMD153508)
+    luminance_Newhall1943, luminance_CIE1976, luminance_ASTMD153508,
+    luminance_Fairchild2010)
 from colour.utilities import ignore_numpy_errors
 
 __author__ = 'Colour Developers'
@@ -23,9 +21,10 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['TestLuminanceNewhall1943',
-           'TestLuminanceASTMD153508',
-           'TestLuminanceCIE1976']
+__all__ = [
+    'TestLuminanceNewhall1943', 'TestLuminanceASTMD153508',
+    'TestLuminanceCIE1976', 'TestLuminanceFairchild2010'
+]
 
 
 class TestLuminanceNewhall1943(unittest.TestCase):
@@ -41,19 +40,13 @@ class TestLuminanceNewhall1943(unittest.TestCase):
         """
 
         self.assertAlmostEqual(
-            luminance_Newhall1943(3.74629715),
-            10.40898746,
-            places=7)
+            luminance_Newhall1943(3.74629715), 10.40898746, places=7)
 
         self.assertAlmostEqual(
-            luminance_Newhall1943(8.64728711),
-            71.31748010,
-            places=7)
+            luminance_Newhall1943(8.64728711), 71.31748010, places=7)
 
         self.assertAlmostEqual(
-            luminance_Newhall1943(1.52569022),
-            2.06998750,
-            places=7)
+            luminance_Newhall1943(1.52569022), 2.06998750, places=7)
 
     def test_n_dimensional_luminance_Newhall1943(self):
         """
@@ -63,31 +56,19 @@ class TestLuminanceNewhall1943(unittest.TestCase):
 
         V = 3.74629715
         Y = 10.408987457743208
-        np.testing.assert_almost_equal(
-            luminance_Newhall1943(V),
-            Y,
-            decimal=7)
+        np.testing.assert_almost_equal(luminance_Newhall1943(V), Y, decimal=7)
 
         V = np.tile(V, 6)
         Y = np.tile(Y, 6)
-        np.testing.assert_almost_equal(
-            luminance_Newhall1943(V),
-            Y,
-            decimal=7)
+        np.testing.assert_almost_equal(luminance_Newhall1943(V), Y, decimal=7)
 
         V = np.reshape(V, (2, 3))
         Y = np.reshape(Y, (2, 3))
-        np.testing.assert_almost_equal(
-            luminance_Newhall1943(V),
-            Y,
-            decimal=7)
+        np.testing.assert_almost_equal(luminance_Newhall1943(V), Y, decimal=7)
 
         V = np.reshape(V, (2, 3, 1))
         Y = np.reshape(Y, (2, 3, 1))
-        np.testing.assert_almost_equal(
-            luminance_Newhall1943(V),
-            Y,
-            decimal=7)
+        np.testing.assert_almost_equal(luminance_Newhall1943(V), Y, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_luminance_Newhall1943(self):
@@ -113,19 +94,13 @@ class TestLuminanceASTMD153508(unittest.TestCase):
         """
 
         self.assertAlmostEqual(
-            luminance_ASTMD153508(3.74629715),
-            10.14880968,
-            places=7)
+            luminance_ASTMD153508(3.74629715), 10.14880968, places=7)
 
         self.assertAlmostEqual(
-            luminance_ASTMD153508(8.64728711),
-            69.53240916,
-            places=7)
+            luminance_ASTMD153508(8.64728711), 69.53240916, places=7)
 
         self.assertAlmostEqual(
-            luminance_ASTMD153508(1.52569022),
-            2.01830631,
-            places=7)
+            luminance_ASTMD153508(1.52569022), 2.01830631, places=7)
 
     def test_n_dimensional_luminance_ASTMD153508(self):
         """
@@ -135,31 +110,19 @@ class TestLuminanceASTMD153508(unittest.TestCase):
 
         V = 3.74629715
         Y = 10.148809678226682
-        np.testing.assert_almost_equal(
-            luminance_ASTMD153508(V),
-            Y,
-            decimal=7)
+        np.testing.assert_almost_equal(luminance_ASTMD153508(V), Y, decimal=7)
 
         V = np.tile(V, 6)
         Y = np.tile(Y, 6)
-        np.testing.assert_almost_equal(
-            luminance_ASTMD153508(V),
-            Y,
-            decimal=7)
+        np.testing.assert_almost_equal(luminance_ASTMD153508(V), Y, decimal=7)
 
         V = np.reshape(V, (2, 3))
         Y = np.reshape(Y, (2, 3))
-        np.testing.assert_almost_equal(
-            luminance_ASTMD153508(V),
-            Y,
-            decimal=7)
+        np.testing.assert_almost_equal(luminance_ASTMD153508(V), Y, decimal=7)
 
         V = np.reshape(V, (2, 3, 1))
         Y = np.reshape(Y, (2, 3, 1))
-        np.testing.assert_almost_equal(
-            luminance_ASTMD153508(V),
-            Y,
-            decimal=7)
+        np.testing.assert_almost_equal(luminance_ASTMD153508(V), Y, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_luminance_ASTMD153508(self):
@@ -185,34 +148,22 @@ class TestLuminanceCIE1976(unittest.TestCase):
         """
 
         self.assertAlmostEqual(
-            luminance_CIE1976(37.98562910),
-            10.08000000,
-            places=7)
+            luminance_CIE1976(37.98562910), 10.08000000, places=7)
 
         self.assertAlmostEqual(
-            luminance_CIE1976(80.04441556),
-            56.76000000,
-            places=7)
+            luminance_CIE1976(80.04441556), 56.76000000, places=7)
 
         self.assertAlmostEqual(
-            luminance_CIE1976(99.34672790),
-            98.32000000,
-            places=7)
+            luminance_CIE1976(99.34672790), 98.32000000, places=7)
 
         self.assertAlmostEqual(
-            luminance_CIE1976(37.98562910, 50),
-            5.04000000,
-            places=7)
+            luminance_CIE1976(37.98562910, 50), 5.04000000, places=7)
 
         self.assertAlmostEqual(
-            luminance_CIE1976(37.98562910, 75),
-            7.56000000,
-            places=7)
+            luminance_CIE1976(37.98562910, 75), 7.56000000, places=7)
 
         self.assertAlmostEqual(
-            luminance_CIE1976(37.98562910, 95),
-            9.57600000,
-            places=7)
+            luminance_CIE1976(37.98562910, 95), 9.57600000, places=7)
 
     def test_n_dimensional_luminance_CIE1976(self):
         """
@@ -222,31 +173,19 @@ class TestLuminanceCIE1976(unittest.TestCase):
 
         Lstar = 37.98562910
         Y = 10.080000000026304
-        np.testing.assert_almost_equal(
-            luminance_CIE1976(Lstar),
-            Y,
-            decimal=7)
+        np.testing.assert_almost_equal(luminance_CIE1976(Lstar), Y, decimal=7)
 
         Lstar = np.tile(Lstar, 6)
         Y = np.tile(Y, 6)
-        np.testing.assert_almost_equal(
-            luminance_CIE1976(Lstar),
-            Y,
-            decimal=7)
+        np.testing.assert_almost_equal(luminance_CIE1976(Lstar), Y, decimal=7)
 
         Lstar = np.reshape(Lstar, (2, 3))
         Y = np.reshape(Y, (2, 3))
-        np.testing.assert_almost_equal(
-            luminance_CIE1976(Lstar),
-            Y,
-            decimal=7)
+        np.testing.assert_almost_equal(luminance_CIE1976(Lstar), Y, decimal=7)
 
         Lstar = np.reshape(Lstar, (2, 3, 1))
         Y = np.reshape(Y, (2, 3, 1))
-        np.testing.assert_almost_equal(
-            luminance_CIE1976(Lstar),
-            Y,
-            decimal=7)
+        np.testing.assert_almost_equal(luminance_CIE1976(Lstar), Y, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_luminance_CIE1976(self):
@@ -255,7 +194,79 @@ class TestLuminanceCIE1976(unittest.TestCase):
         definition nan support.
         """
 
-        luminance_CIE1976(
+        luminance_CIE1976(np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
+
+
+class TestLuminanceFairchild2010(unittest.TestCase):
+    """
+    Defines :func:`colour.colorimetry.luminance.luminance_Fairchild2010`
+    definition unit tests methods.
+    """
+
+    def test_luminance_Fairchild2010(self):
+        """
+        Tests :func:`colour.colorimetry.luminance.luminance_Fairchild2010`
+        definition.
+        """
+
+        self.assertAlmostEqual(
+            luminance_Fairchild2010(23.103633825753175), 0.10079999, places=7)
+
+        self.assertAlmostEqual(
+            luminance_Fairchild2010(90.510575738115122), 0.56759999, places=7)
+
+        self.assertAlmostEqual(
+            luminance_Fairchild2010(96.636221285055527), 0.98319999, places=7)
+
+        self.assertAlmostEqual(
+            luminance_Fairchild2010(16.064202706248068, 2.75),
+            0.10079999,
+            places=7)
+
+        self.assertAlmostEqual(
+            luminance_Fairchild2010(100.01999666792653),
+            1007.99999963,
+            places=7)
+
+        self.assertAlmostEqual(
+            luminance_Fairchild2010(100.01999999966679),
+            100800.82383352,
+            places=7)
+
+    def test_n_dimensional_luminance_Fairchild2010(self):
+        """
+        Tests :func:`colour.colorimetry.lightness.luminance_Fairchild2010`
+        definition n-dimensional arrays support.
+        """
+
+        L_hdr = 23.103633825753175
+        Y = 10.08 / 100
+        np.testing.assert_almost_equal(
+            luminance_Fairchild2010(L_hdr), Y, decimal=7)
+
+        L_hdr = np.tile(L_hdr, 6)
+        Y = np.tile(Y, 6)
+        np.testing.assert_almost_equal(
+            luminance_Fairchild2010(L_hdr), Y, decimal=7)
+
+        L_hdr = np.reshape(L_hdr, (2, 3))
+        Y = np.reshape(Y, (2, 3))
+        np.testing.assert_almost_equal(
+            luminance_Fairchild2010(L_hdr), Y, decimal=7)
+
+        L_hdr = np.reshape(L_hdr, (2, 3, 1))
+        Y = np.reshape(Y, (2, 3, 1))
+        np.testing.assert_almost_equal(
+            luminance_Fairchild2010(L_hdr), Y, decimal=7)
+
+    @ignore_numpy_errors
+    def test_nan_luminance_Fairchild2010(self):
+        """
+        Tests :func:`colour.colorimetry.luminance.luminance_Fairchild2010`
+        definition nan support.
+        """
+
+        luminance_Fairchild2010(
             np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
 
 
