@@ -4,16 +4,12 @@
 from __future__ import absolute_import
 
 from .cie import CIE_E, CIE_K, K_M, KP_M
-from .codata import (
-    AVOGADRO_CONSTANT,
-    BOLTZMANN_CONSTANT,
-    LIGHT_SPEED,
-    PLANCK_CONSTANT)
+from .codata import (AVOGADRO_CONSTANT, BOLTZMANN_CONSTANT, LIGHT_SPEED,
+                     PLANCK_CONSTANT)
 from .common import FLOATING_POINT_NUMBER_PATTERN, INTEGER_THRESHOLD, EPSILON
 
 __all__ = ['CIE_E', 'CIE_K', 'K_M', 'KP_M']
-__all__ += ['AVOGADRO_CONSTANT',
-            'BOLTZMANN_CONSTANT',
-            'LIGHT_SPEED',
-            'PLANCK_CONSTANT']
+__all__ += [
+    'AVOGADRO_CONSTANT', 'BOLTZMANN_CONSTANT', 'LIGHT_SPEED', 'PLANCK_CONSTANT'
+]
 __all__ += ['FLOATING_POINT_NUMBER_PATTERN', 'INTEGER_THRESHOLD', 'EPSILON']
