@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Showcases *Von Kries* chromatic adaptation model computations.
 """
@@ -15,7 +14,7 @@ XYZ_wr = (1.09846607, 1.00000000, 0.35582280)
 message_box(('Computing the chromatic adaptation matrix from two source '
              '"CIE XYZ" tristimulus values arrays, default CAT is "CAT02".\n'
              '\n\t"XYZ_w":\n\t\t{0}\n\t"XYZ_wr":\n\t\t{1}'.format(
-                XYZ_w, XYZ_wr)))
+                 XYZ_w, XYZ_wr)))
 print(colour.chromatic_adaptation_matrix_VonKries(XYZ_w, XYZ_wr))
 
 print('\n')
@@ -32,9 +31,7 @@ message_box(('Computing the chromatic adaptation matrix from '
 A = colour.ILLUMINANTS['CIE 1931 2 Degree Standard Observer']['A']
 D65 = colour.ILLUMINANTS['CIE 1931 2 Degree Standard Observer']['D65']
 print(colour.chromatic_adaptation_matrix_VonKries(
-    colour.xy_to_XYZ(A),
-    colour.xy_to_XYZ(D65),
-    transform='Von Kries'))
+    colour.xy_to_XYZ(A), colour.xy_to_XYZ(D65), transform='Von Kries'))
 
 print('\n')
 
@@ -44,7 +41,4 @@ message_box(('Adapting given "CIE XYZ" tristimulus values from '
              '"CIE Standard Illuminant D Series D65" using "Sharp" CAT.\n'
              '\n\t"XYZ":\n\t\t{0}'.format(XYZ)))
 print(colour.chromatic_adaptation_VonKries(
-    XYZ,
-    colour.xy_to_XYZ(A),
-    colour.xy_to_XYZ(D65),
-    transform='Sharp'))
+    XYZ, colour.xy_to_XYZ(A), colour.xy_to_XYZ(D65), transform='Sharp'))
