@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Showcases colour fitting computations.
 """
@@ -40,7 +39,7 @@ reference = (
      (0.35499180, 0.36538033, 0.36757315),
      (0.19011528, 0.19180135, 0.19309001),
      (0.08525591, 0.08890588, 0.09252104),
-     (0.03039192, 0.03118624, 0.03278316)))
+     (0.03039192, 0.03118624, 0.03278316)))  # yapf: disable
 
 measured = (
     ((0.15579559, 0.09715755, 0.07514556),
@@ -66,6 +65,6 @@ measured = (
      (0.33045354, 0.32904184, 0.33228886),
      (0.18001305, 0.17978567, 0.18004416),
      (0.10283975, 0.10424680, 0.10384975),
-     (0.04742204, 0.04772203, 0.04914226)))
+     (0.04742204, 0.04772203, 0.04914226)))  # yapf: disable
 
 print(colour.first_order_colour_fit(reference, measured))
