@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Showcases colour matching functions computations.
 """
@@ -21,8 +20,8 @@ message_box(('Converting from "Wright & Guild 1931 2 Degree RGB CMFs" colour '
              'matching functions to "CIE 1931 2 Degree Standard Observer" at '
              'wavelength 700 nm.'))
 print(colour.RGB_2_degree_cmfs_to_XYZ_2_degree_cmfs(700))
-print(colour.STANDARD_OBSERVERS_CMFS[
-    'CIE 1931 2 Degree Standard Observer'][700])
+print(
+    colour.STANDARD_OBSERVERS_CMFS['CIE 1931 2 Degree Standard Observer'][700])
 
 print('\n')
 
@@ -30,8 +29,8 @@ message_box(('Converting from "Stiles & Burch 1959 10 Degree RGB CMFs" colour '
              'matching functions to "CIE 1964 10 Degree Standard Observer" at '
              'wavelength 700 nm.'))
 print(colour.RGB_10_degree_cmfs_to_XYZ_10_degree_cmfs(700))
-print(colour.STANDARD_OBSERVERS_CMFS[
-    'CIE 1964 10 Degree Standard Observer'][700])
+print(colour.STANDARD_OBSERVERS_CMFS['CIE 1964 10 Degree Standard Observer'][
+    700])
 
 print('\n')
 
@@ -49,8 +48,8 @@ message_box(('Converting from "Stockman & Sharpe 2 Degree Cone Fundamentals" '
              '"CIE 2012 2 Degree Standard Observer" spectral sensitivity '
              'functions at wavelength 700 nm.'))
 print(colour.LMS_2_degree_cmfs_to_XYZ_2_degree_cmfs(700))
-print(colour.STANDARD_OBSERVERS_CMFS[
-    'CIE 2012 2 Degree Standard Observer'][700])
+print(
+    colour.STANDARD_OBSERVERS_CMFS['CIE 2012 2 Degree Standard Observer'][700])
 
 print('\n')
 
@@ -59,5 +58,5 @@ message_box(('Converting from "Stockman & Sharpe 10 Degree Cone Fundamentals" '
              '"CIE 2012 10 Degree Standard Observer" spectral sensitivity '
              'functions at wavelength 700 nm.'))
 print(colour.LMS_10_degree_cmfs_to_XYZ_10_degree_cmfs(700))
-print(colour.STANDARD_OBSERVERS_CMFS[
-    'CIE 2012 10 Degree Standard Observer'][700])
+print(colour.STANDARD_OBSERVERS_CMFS['CIE 2012 10 Degree Standard Observer'][
+    700])
