@@ -1,15 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Showcases *Rayleigh Optical Depth* computations examples.
 """
 
 import colour
 from colour.phenomenons import (
-    rayleigh_optical_depth,
-    rayleigh_scattering_spd,
-    scattering_cross_section)
+    rayleigh_optical_depth, rayleigh_scattering_spd, scattering_cross_section)
 from colour.utilities.verbose import message_box
 
 message_box('"Rayleigh" Optical Depth Computations')
