@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Showcases colour models plotting examples.
 """
@@ -44,27 +43,21 @@ RGB = np.random.random((32, 32, 3))
 message_box('Plotting "RGB" chromaticity coordinates in '
             '"CIE 1931 Chromaticity Diagram".')
 RGB_chromaticity_coordinates_CIE_1931_chromaticity_diagram_plot(
-    RGB,
-    'Rec. 709',
-    colourspaces=['ACEScg', 'S-Gamut', 'Pointer Gamut'])
+    RGB, 'Rec. 709', colourspaces=['ACEScg', 'S-Gamut', 'Pointer Gamut'])
 
 print('\n')
 
 message_box('Plotting "RGB" chromaticity coordinates in '
             '"CIE 1960 UCS Chromaticity Diagram".')
 RGB_chromaticity_coordinates_CIE_1960_UCS_chromaticity_diagram_plot(
-    RGB,
-    'Rec. 709',
-    colourspaces=['ACEScg', 'S-Gamut', 'Pointer Gamut'])
+    RGB, 'Rec. 709', colourspaces=['ACEScg', 'S-Gamut', 'Pointer Gamut'])
 
 print('\n')
 
 message_box('Plotting "RGB" chromaticity coordinates in '
             '"CIE 1976 UCS Chromaticity Diagram".')
 RGB_chromaticity_coordinates_CIE_1976_UCS_chromaticity_diagram_plot(
-    RGB,
-    'Rec. 709',
-    colourspaces=['ACEScg', 'S-Gamut', 'Pointer Gamut'])
+    RGB, 'Rec. 709', colourspaces=['ACEScg', 'S-Gamut', 'Pointer Gamut'])
 
 print('\n')
 
@@ -72,10 +65,11 @@ message_box(('Plotting a single custom "RGB" colourspace in '
              '"CIE 1931 Chromaticity Diagram".'))
 colour.RGB_COLOURSPACES['Awful RGB'] = colour.RGB_Colourspace(
     'Awful RGB',
-    primaries=np.array([[0.10, 0.20],
-                        [0.30, 0.15],
-                        [0.05, 0.60]]),
-    whitepoint=np.array([1.0 / 3.0, 1.0 / 3.0]))
+    primaries=np.array(
+        [[0.10, 0.20],
+         [0.30, 0.15],
+         [0.05, 0.60]]),
+    whitepoint=np.array([1.0 / 3.0, 1.0 / 3.0]))  # yapf: disable
 pprint(sorted(colour.RGB_COLOURSPACES.keys()))
 RGB_colourspaces_CIE_1931_chromaticity_diagram_plot(['Rec. 709', 'Awful RGB'])
 
