@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Showcases reflectance recovery computations using *Smits (1999)* method.
 """
@@ -18,8 +17,8 @@ print(colour.RGB_to_spectral_Smits1999(RGB))
 
 print('\n')
 
-message_box((
-    'An analysis of "Smits (1999)" method is available at the '
-    'following url : '
-    'http://nbviewer.jupyter.org/github/colour-science/colour-website/'
-    'blob/master/ipython/about_reflectance_recovery.ipynb'))
+message_box(
+    ('An analysis of "Smits (1999)" method is available at the '
+     'following url : '
+     'http://nbviewer.jupyter.org/github/colour-science/colour-website/'
+     'blob/master/ipython/about_reflectance_recovery.ipynb'))
