@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Showcases RGB colourspace volume computations.
 """
@@ -20,14 +19,11 @@ samples = 10e4
 message_box(('Computing "ProPhoto RGB" RGB colourspace volume using '
              '{0} samples.'.format(samples)))
 print(colour.RGB_colourspace_volume_MonteCarlo(
-    colour.PROPHOTO_RGB_COLOURSPACE,
-    samples=samples,
-    limits=limits * 1.1))
+    colour.PROPHOTO_RGB_COLOURSPACE, samples=samples, limits=limits * 1.1))
 
 print('\n')
 
 message_box(('Computing "ProPhoto RGB" RGB colourspace coverage of Pointer\'s '
              'Gamut using {0} samples.'.format(samples)))
 print(colour.RGB_colourspace_pointer_gamut_coverage_MonteCarlo(
-    colour.PROPHOTO_RGB_COLOURSPACE,
-    samples=samples))
+    colour.PROPHOTO_RGB_COLOURSPACE, samples=samples))
