@@ -5,15 +5,14 @@ from __future__ import absolute_import
 
 from .ies_tm2714 import IES_TM2714_Spd
 from .image import read_image, write_image
-from .tabular import (
-    read_spectral_data_from_csv_file,
-    read_spds_from_csv_file,
-    write_spds_to_csv_file)
+from .tabular import (read_spectral_data_from_csv_file,
+                      read_spds_from_csv_file, write_spds_to_csv_file)
 from .xrite import read_spds_from_xrite_file
 
 __all__ = ['IES_TM2714_Spd']
 __all__ += ['read_image', 'write_image']
-__all__ += ['read_spectral_data_from_csv_file',
-            'read_spds_from_csv_file',
-            'write_spds_to_csv_file']
+__all__ += [
+    'read_spectral_data_from_csv_file', 'read_spds_from_csv_file',
+    'write_spds_to_csv_file'
+]
 __all__ += ['read_spds_from_xrite_file']
