@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 IPT Colourspace
 ===============
@@ -14,6 +13,12 @@ And computation of correlates:
 
 -   :func:`IPT_hue_angle`
 
+See Also
+--------
+`IPT Colourspace Jupyter Notebook
+<http://nbviewer.jupyter.org/github/colour-science/colour-notebooks/\
+blob/master/notebooks/models/ipt.ipynb>`_
+
 References
 ----------
 .. [1]  Fairchild, M. D. (2013). IPT Colourspace. In Color Appearance Models
@@ -33,18 +38,15 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['IPT_XYZ_TO_LMS_MATRIX',
-           'IPT_LMS_TO_XYZ_MATRIX',
-           'IPT_LMS_TO_IPT_MATRIX',
-           'IPT_IPT_TO_LMS_MATRIX',
-           'XYZ_to_IPT',
-           'IPT_to_XYZ',
-           'IPT_hue_angle']
+__all__ = [
+    'IPT_XYZ_TO_LMS_MATRIX', 'IPT_LMS_TO_XYZ_MATRIX', 'IPT_LMS_TO_IPT_MATRIX',
+    'IPT_IPT_TO_LMS_MATRIX', 'XYZ_to_IPT', 'IPT_to_XYZ', 'IPT_hue_angle'
+]
 
-IPT_XYZ_TO_LMS_MATRIX = np.array([
-    [0.4002, 0.7075, -0.0807],
-    [-0.2280, 1.1500, 0.0612],
-    [0.0000, 0.0000, 0.9184]])
+IPT_XYZ_TO_LMS_MATRIX = np.array(
+    [[0.4002, 0.7075, -0.0807],
+     [-0.2280, 1.1500, 0.0612],
+     [0.0000, 0.0000, 0.9184]])  # yapf: disable
 """
 *CIE XYZ* tristimulus values to normalised cone responses matrix.
 
@@ -58,10 +60,10 @@ Normalised cone responses to *CIE XYZ* tristimulus values matrix.
 IPT_LMS_TO_XYZ_MATRIX : array_like, (3, 3)
 """
 
-IPT_LMS_TO_IPT_MATRIX = np.array([
-    [0.4000, 0.4000, 0.2000],
-    [4.4550, -4.8510, 0.3960],
-    [0.8056, 0.3572, -1.1628]])
+IPT_LMS_TO_IPT_MATRIX = np.array(
+    [[0.4000, 0.4000, 0.2000],
+     [4.4550, -4.8510, 0.3960],
+     [0.8056, 0.3572, -1.1628]])  # yapf: disable
 """
 Normalised cone responses to *IPT* colourspace matrix.
 
