@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Adobe Wide Gamut RGB Colourspace
 ================================
@@ -27,10 +26,8 @@ import numpy as np
 from functools import partial
 
 from colour.colorimetry import ILLUMINANTS
-from colour.models.rgb import (
-    RGB_Colourspace,
-    gamma_function,
-    normalised_primary_matrix)
+from colour.models.rgb import (RGB_Colourspace, function_gamma,
+                               normalised_primary_matrix)
 
 __author__ = 'Colour Developers'
 __copyright__ = 'Copyright (C) 2013-2017 - Colour Developers'
@@ -39,17 +36,16 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['ADOBE_WIDE_GAMUT_RGB_PRIMARIES',
-           'ADOBE_WIDE_GAMUT_RGB_ILLUMINANT',
-           'ADOBE_WIDE_GAMUT_RGB_WHITEPOINT',
-           'ADOBE_WIDE_GAMUT_RGB_TO_XYZ_MATRIX',
-           'XYZ_TO_ADOBE_WIDE_GAMUT_RGB_MATRIX',
-           'ADOBE_WIDE_GAMUT_RGB_COLOURSPACE']
+__all__ = [
+    'ADOBE_WIDE_GAMUT_RGB_PRIMARIES', 'ADOBE_WIDE_GAMUT_RGB_ILLUMINANT',
+    'ADOBE_WIDE_GAMUT_RGB_WHITEPOINT', 'ADOBE_WIDE_GAMUT_RGB_TO_XYZ_MATRIX',
+    'XYZ_TO_ADOBE_WIDE_GAMUT_RGB_MATRIX', 'ADOBE_WIDE_GAMUT_RGB_COLOURSPACE'
+]
 
 ADOBE_WIDE_GAMUT_RGB_PRIMARIES = np.array(
     [[0.7347, 0.2653],
      [0.1152, 0.8264],
-     [0.1566, 0.0177]])
+     [0.1566, 0.0177]])  # yapf: disable
 """
 *Adobe Wide Gamut RGB* colourspace primaries.
 
@@ -64,8 +60,8 @@ ADOBE_WIDE_GAMUT_RGB_ILLUMINANT : unicode
 """
 
 ADOBE_WIDE_GAMUT_RGB_WHITEPOINT = (
-    ILLUMINANTS['CIE 1931 2 Degree Standard Observer'][
-        ADOBE_WIDE_GAMUT_RGB_ILLUMINANT])
+    ILLUMINANTS['CIE 1931 2 Degree Standard Observer']
+    [ADOBE_WIDE_GAMUT_RGB_ILLUMINANT])  # yapf: disable
 """
 *Adobe Wide Gamut RGB* colourspace whitepoint.
 
@@ -95,8 +91,8 @@ ADOBE_WIDE_GAMUT_RGB_COLOURSPACE = RGB_Colourspace(
     ADOBE_WIDE_GAMUT_RGB_ILLUMINANT,
     ADOBE_WIDE_GAMUT_RGB_TO_XYZ_MATRIX,
     XYZ_TO_ADOBE_WIDE_GAMUT_RGB_MATRIX,
-    partial(gamma_function, exponent=1 / (563 / 256)),
-    partial(gamma_function, exponent=563 / 256))
+    partial(function_gamma, exponent=1 / (563 / 256)),
+    partial(function_gamma, exponent=563 / 256))  # yapf: disable
 """
 *Adobe Wide Gamut RGB* colourspace.
 
