@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 ALEXA Wide Gamut RGB Colourspace
 ================================
@@ -26,10 +25,8 @@ from __future__ import division, unicode_literals
 import numpy as np
 
 from colour.colorimetry import ILLUMINANTS
-from colour.models.rgb import (
-    RGB_Colourspace,
-    log_encoding_ALEXALogC,
-    log_decoding_ALEXALogC)
+from colour.models.rgb import (RGB_Colourspace, log_encoding_ALEXALogC,
+                               log_decoding_ALEXALogC)
 
 __author__ = 'Colour Developers'
 __copyright__ = 'Copyright (C) 2013-2017 - Colour Developers'
@@ -38,17 +35,16 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['ALEXA_WIDE_GAMUT_RGB_PRIMARIES',
-           'ALEXA_WIDE_GAMUT_RGB_ILLUMINANT',
-           'ALEXA_WIDE_GAMUT_RGB_WHITEPOINT',
-           'ALEXA_WIDE_GAMUT_RGB_TO_XYZ_MATRIX',
-           'XYZ_TO_ALEXA_WIDE_GAMUT_RGB_MATRIX',
-           'ALEXA_WIDE_GAMUT_RGB_COLOURSPACE']
+__all__ = [
+    'ALEXA_WIDE_GAMUT_RGB_PRIMARIES', 'ALEXA_WIDE_GAMUT_RGB_ILLUMINANT',
+    'ALEXA_WIDE_GAMUT_RGB_WHITEPOINT', 'ALEXA_WIDE_GAMUT_RGB_TO_XYZ_MATRIX',
+    'XYZ_TO_ALEXA_WIDE_GAMUT_RGB_MATRIX', 'ALEXA_WIDE_GAMUT_RGB_COLOURSPACE'
+]
 
 ALEXA_WIDE_GAMUT_RGB_PRIMARIES = np.array(
     [[0.6840, 0.3130],
      [0.2210, 0.8480],
-     [0.0861, -0.1020]])
+     [0.0861, -0.1020]])  # yapf: disable
 """
 *ALEXA Wide Gamut RGB* colourspace primaries.
 
@@ -63,8 +59,8 @@ ALEXA_WIDE_GAMUT_RGB_WHITEPOINT : unicode
 """
 
 ALEXA_WIDE_GAMUT_RGB_WHITEPOINT = (
-    ILLUMINANTS['CIE 1931 2 Degree Standard Observer'][
-        ALEXA_WIDE_GAMUT_RGB_ILLUMINANT])
+    ILLUMINANTS['CIE 1931 2 Degree Standard Observer']
+    [ALEXA_WIDE_GAMUT_RGB_ILLUMINANT])  # yapf: disable
 """
 *ALEXA Wide Gamut RGB* colourspace whitepoint.
 
@@ -74,7 +70,7 @@ ALEXA_WIDE_GAMUT_RGB_WHITEPOINT : ndarray
 ALEXA_WIDE_GAMUT_RGB_TO_XYZ_MATRIX = np.array(
     [[0.638008, 0.214704, 0.097744],
      [0.291954, 0.823841, -0.115795],
-     [0.002798, -0.067034, 1.153294]])
+     [0.002798, -0.067034, 1.153294]])  # yapf: disable
 """
 *ALEXA Wide Gamut RGB* colourspace to *CIE XYZ* tristimulus values matrix.
 
@@ -84,7 +80,7 @@ ALEXA_WIDE_GAMUT_RGB_TO_XYZ_MATRIX : array_like, (3, 3)
 XYZ_TO_ALEXA_WIDE_GAMUT_RGB_MATRIX = np.array(
     [[1.789066, -0.482534, -0.200076],
      [-0.639849, 1.396400, 0.194432],
-     [-0.041532, 0.082335, 0.878868]])
+     [-0.041532, 0.082335, 0.878868]])  # yapf: disable
 """
 *CIE XYZ* tristimulus values to *ALEXA Wide Gamut RGB* colourspace matrix.
 
@@ -99,7 +95,7 @@ ALEXA_WIDE_GAMUT_RGB_COLOURSPACE = RGB_Colourspace(
     ALEXA_WIDE_GAMUT_RGB_TO_XYZ_MATRIX,
     XYZ_TO_ALEXA_WIDE_GAMUT_RGB_MATRIX,
     log_encoding_ALEXALogC,
-    log_decoding_ALEXALogC)
+    log_decoding_ALEXALogC)  # yapf: disable
 """
 *ALEXA Wide Gamut RGB* colourspace.
 
