@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 CIE RGB Colourspace
 ===================
@@ -30,7 +29,7 @@ import numpy as np
 from functools import partial
 
 from colour.colorimetry import ILLUMINANTS
-from colour.models.rgb import RGB_Colourspace, gamma_function
+from colour.models.rgb import RGB_Colourspace, function_gamma
 
 __author__ = 'Colour Developers'
 __copyright__ = 'Copyright (C) 2013-2017 - Colour Developers'
@@ -39,17 +38,15 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['CIE_RGB_PRIMARIES',
-           'CIE_RGB_ILLUMINANT',
-           'CIE_RGB_WHITEPOINT',
-           'CIE_RGB_TO_XYZ_MATRIX',
-           'XYZ_TO_CIE_RGB_MATRIX',
-           'CIE_RGB_COLOURSPACE']
+__all__ = [
+    'CIE_RGB_PRIMARIES', 'CIE_RGB_ILLUMINANT', 'CIE_RGB_WHITEPOINT',
+    'CIE_RGB_TO_XYZ_MATRIX', 'XYZ_TO_CIE_RGB_MATRIX', 'CIE_RGB_COLOURSPACE'
+]
 
 CIE_RGB_PRIMARIES = np.array(
     [[0.734742840005998, 0.265257159994002],
      [0.273779033824958, 0.717477700256116],
-     [0.166555629580280, 0.008910726182545]])
+     [0.166555629580280, 0.008910726182545]])  # yapf: disable
 """
 *CIE RGB* colourspace primaries.
 
@@ -80,7 +77,7 @@ CIE_RGB_WHITEPOINT : ndarray
 CIE_RGB_TO_XYZ_MATRIX = np.array(
     [[0.4900, 0.3100, 0.2000],
      [0.1769, 0.8124, 0.0107],
-     [0.0000, 0.0099, 0.9901]])
+     [0.0000, 0.0099, 0.9901]])  # yapf: disable
 """
 *CIE RGB* colourspace to *CIE XYZ* tristimulus values matrix.
 
@@ -101,8 +98,8 @@ CIE_RGB_COLOURSPACE = RGB_Colourspace(
     CIE_RGB_ILLUMINANT,
     CIE_RGB_TO_XYZ_MATRIX,
     XYZ_TO_CIE_RGB_MATRIX,
-    partial(gamma_function, exponent=1 / 2.2),
-    partial(gamma_function, exponent=2.2))
+    partial(function_gamma, exponent=1 / 2.2),
+    partial(function_gamma, exponent=2.2))  # yapf: disable
 """
 *CIE RGB* colourspace.
 
