@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Don RGB 4 Colourspace
 =====================
@@ -27,10 +26,8 @@ import numpy as np
 from functools import partial
 
 from colour.colorimetry import ILLUMINANTS
-from colour.models.rgb import (
-    RGB_Colourspace,
-    gamma_function,
-    normalised_primary_matrix)
+from colour.models.rgb import (RGB_Colourspace, function_gamma,
+                               normalised_primary_matrix)
 
 __author__ = 'Colour Developers'
 __copyright__ = 'Copyright (C) 2013-2017 - Colour Developers'
@@ -39,17 +36,16 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['DON_RGB_4_PRIMARIES',
-           'DON_RGB_4_ILLUMINANT',
-           'DON_RGB_4_WHITEPOINT',
-           'DON_RGB_4_TO_XYZ_MATRIX',
-           'XYZ_TO_DON_RGB_4_MATRIX',
-           'DON_RGB_4_COLOURSPACE']
+__all__ = [
+    'DON_RGB_4_PRIMARIES', 'DON_RGB_4_ILLUMINANT', 'DON_RGB_4_WHITEPOINT',
+    'DON_RGB_4_TO_XYZ_MATRIX', 'XYZ_TO_DON_RGB_4_MATRIX',
+    'DON_RGB_4_COLOURSPACE'
+]
 
 DON_RGB_4_PRIMARIES = np.array(
     [[0.696120689655172, 0.299568965517241],
      [0.214682981090100, 0.765294771968854],
-     [0.129937629937630, 0.035343035343035]])
+     [0.129937629937630, 0.035343035343035]])  # yapf: disable
 """
 *Don RGB 4* colourspace primaries.
 
@@ -71,8 +67,8 @@ DON_RGB_4_WHITEPOINT = (
 DON_RGB_4_WHITEPOINT : ndarray
 """
 
-DON_RGB_4_TO_XYZ_MATRIX = normalised_primary_matrix(
-    DON_RGB_4_PRIMARIES, DON_RGB_4_WHITEPOINT)
+DON_RGB_4_TO_XYZ_MATRIX = normalised_primary_matrix(DON_RGB_4_PRIMARIES,
+                                                    DON_RGB_4_WHITEPOINT)
 """
 *Don RGB 4* colourspace to *CIE XYZ* tristimulus values matrix.
 
@@ -93,8 +89,8 @@ DON_RGB_4_COLOURSPACE = RGB_Colourspace(
     DON_RGB_4_ILLUMINANT,
     DON_RGB_4_TO_XYZ_MATRIX,
     XYZ_TO_DON_RGB_4_MATRIX,
-    partial(gamma_function, exponent=1 / 2.2),
-    partial(gamma_function, exponent=2.2))
+    partial(function_gamma, exponent=1 / 2.2),
+    partial(function_gamma, exponent=2.2))  # yapf: disable
 """
 *Don RGB 4* colourspace.
 
