@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 RED Colourspaces
 ================
@@ -37,12 +36,8 @@ import numpy as np
 
 from colour.colorimetry import ILLUMINANTS
 from colour.models.rgb import (
-    RGB_Colourspace,
-    normalised_primary_matrix,
-    log_encoding_REDLogFilm,
-    log_decoding_REDLogFilm,
-    log_encoding_Log3G10,
-    log_decoding_Log3G10)
+    RGB_Colourspace, normalised_primary_matrix, log_encoding_REDLogFilm,
+    log_decoding_REDLogFilm, log_encoding_Log3G10, log_decoding_Log3G10)
 
 __author__ = 'Colour Developers'
 __copyright__ = 'Copyright (C) 2013-2017 - Colour Developers'
@@ -51,53 +46,33 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['RED_COLOR_PRIMARIES',
-           'RED_COLOR_ILLUMINANT',
-           'RED_COLOR_WHITEPOINT',
-           'RED_COLOR_TO_XYZ_MATRIX',
-           'XYZ_TO_RED_COLOR_MATRIX',
-           'RED_COLOR_COLOURSPACE',
-           'RED_COLOR_2_PRIMARIES',
-           'RED_COLOR_2_ILLUMINANT',
-           'RED_COLOR_2_WHITEPOINT',
-           'RED_COLOR_2_TO_XYZ_MATRIX',
-           'XYZ_TO_RED_COLOR_2_MATRIX',
-           'RED_COLOR_2_COLOURSPACE',
-           'RED_COLOR_3_PRIMARIES',
-           'RED_COLOR_3_ILLUMINANT',
-           'RED_COLOR_3_WHITEPOINT',
-           'RED_COLOR_3_TO_XYZ_MATRIX',
-           'XYZ_TO_RED_COLOR_3_MATRIX',
-           'RED_COLOR_3_COLOURSPACE',
-           'RED_COLOR_4_PRIMARIES',
-           'RED_COLOR_4_ILLUMINANT',
-           'RED_COLOR_4_WHITEPOINT',
-           'RED_COLOR_4_TO_XYZ_MATRIX',
-           'XYZ_TO_RED_COLOR_4_MATRIX',
-           'RED_COLOR_4_COLOURSPACE',
-           'DRAGON_COLOR_PRIMARIES',
-           'DRAGON_COLOR_ILLUMINANT',
-           'DRAGON_COLOR_WHITEPOINT',
-           'DRAGON_COLOR_TO_XYZ_MATRIX',
-           'XYZ_TO_DRAGON_COLOR_MATRIX',
-           'DRAGON_COLOR_COLOURSPACE',
-           'DRAGON_COLOR_2_PRIMARIES',
-           'DRAGON_COLOR_2_ILLUMINANT',
-           'DRAGON_COLOR_2_WHITEPOINT',
-           'DRAGON_COLOR_2_TO_XYZ_MATRIX',
-           'XYZ_TO_DRAGON_COLOR_2_MATRIX',
-           'DRAGON_COLOR_2_COLOURSPACE',
-           'RED_WIDE_GAMUT_RGB_PRIMARIES',
-           'RED_WIDE_GAMUT_RGB_ILLUMINANT',
-           'RED_WIDE_GAMUT_RGB_WHITEPOINT',
-           'RED_WIDE_GAMUT_RGB_TO_XYZ_MATRIX',
-           'XYZ_TO_RED_WIDE_GAMUT_RGB_MATRIX',
-           'RED_WIDE_GAMUT_RGB_COLOURSPACE']
+__all__ = [
+    'RED_COLOR_PRIMARIES', 'RED_COLOR_ILLUMINANT', 'RED_COLOR_WHITEPOINT',
+    'RED_COLOR_TO_XYZ_MATRIX', 'XYZ_TO_RED_COLOR_MATRIX',
+    'RED_COLOR_COLOURSPACE', 'RED_COLOR_2_PRIMARIES', 'RED_COLOR_2_ILLUMINANT',
+    'RED_COLOR_2_WHITEPOINT', 'RED_COLOR_2_TO_XYZ_MATRIX',
+    'XYZ_TO_RED_COLOR_2_MATRIX', 'RED_COLOR_2_COLOURSPACE',
+    'RED_COLOR_3_PRIMARIES', 'RED_COLOR_3_ILLUMINANT',
+    'RED_COLOR_3_WHITEPOINT', 'RED_COLOR_3_TO_XYZ_MATRIX',
+    'XYZ_TO_RED_COLOR_3_MATRIX', 'RED_COLOR_3_COLOURSPACE',
+    'RED_COLOR_4_PRIMARIES', 'RED_COLOR_4_ILLUMINANT',
+    'RED_COLOR_4_WHITEPOINT', 'RED_COLOR_4_TO_XYZ_MATRIX',
+    'XYZ_TO_RED_COLOR_4_MATRIX', 'RED_COLOR_4_COLOURSPACE',
+    'DRAGON_COLOR_PRIMARIES', 'DRAGON_COLOR_ILLUMINANT',
+    'DRAGON_COLOR_WHITEPOINT', 'DRAGON_COLOR_TO_XYZ_MATRIX',
+    'XYZ_TO_DRAGON_COLOR_MATRIX', 'DRAGON_COLOR_COLOURSPACE',
+    'DRAGON_COLOR_2_PRIMARIES', 'DRAGON_COLOR_2_ILLUMINANT',
+    'DRAGON_COLOR_2_WHITEPOINT', 'DRAGON_COLOR_2_TO_XYZ_MATRIX',
+    'XYZ_TO_DRAGON_COLOR_2_MATRIX', 'DRAGON_COLOR_2_COLOURSPACE',
+    'RED_WIDE_GAMUT_RGB_PRIMARIES', 'RED_WIDE_GAMUT_RGB_ILLUMINANT',
+    'RED_WIDE_GAMUT_RGB_WHITEPOINT', 'RED_WIDE_GAMUT_RGB_TO_XYZ_MATRIX',
+    'XYZ_TO_RED_WIDE_GAMUT_RGB_MATRIX', 'RED_WIDE_GAMUT_RGB_COLOURSPACE'
+]
 
 RED_COLOR_PRIMARIES = np.array(
     [[0.699747001290731, 0.329046930312637],
      [0.304264039023547, 0.623641145129115],
-     [0.134913961296487, 0.034717441281345]])
+     [0.134913961296487, 0.034717441281345]])  # yapf: disable
 """
 *REDcolor* colourspace primaries.
 
@@ -119,8 +94,8 @@ RED_COLOR_WHITEPOINT = (
 RED_COLOR_WHITEPOINT : ndarray
 """
 
-RED_COLOR_TO_XYZ_MATRIX = normalised_primary_matrix(
-    RED_COLOR_PRIMARIES, RED_COLOR_WHITEPOINT)
+RED_COLOR_TO_XYZ_MATRIX = normalised_primary_matrix(RED_COLOR_PRIMARIES,
+                                                    RED_COLOR_WHITEPOINT)
 """
 *REDcolor* colourspace to *CIE XYZ* tristimulus values matrix.
 
@@ -142,7 +117,7 @@ RED_COLOR_COLOURSPACE = RGB_Colourspace(
     RED_COLOR_TO_XYZ_MATRIX,
     XYZ_TO_RED_COLOR_MATRIX,
     log_encoding_REDLogFilm,
-    log_decoding_REDLogFilm)
+    log_decoding_REDLogFilm)  # yapf: disable
 """
 *REDcolor* colourspace.
 
@@ -152,7 +127,7 @@ RED_COLOR_COLOURSPACE : RGB_Colourspace
 RED_COLOR_2_PRIMARIES = np.array(
     [[0.878682510476129, 0.324964007409910],
      [0.300888714367432, 0.679054755790568],
-     [0.095398694605615, -0.029379326834327]])
+     [0.095398694605615, -0.029379326834327]])  # yapf: disable
 """
 *REDcolor2* colourspace primaries.
 
@@ -173,8 +148,8 @@ RED_COLOR_2_WHITEPOINT = RED_COLOR_WHITEPOINT
 RED_COLOR_2_WHITEPOINT : ndarray
 """
 
-RED_COLOR_2_TO_XYZ_MATRIX = normalised_primary_matrix(
-    RED_COLOR_2_PRIMARIES, RED_COLOR_2_WHITEPOINT)
+RED_COLOR_2_TO_XYZ_MATRIX = normalised_primary_matrix(RED_COLOR_2_PRIMARIES,
+                                                      RED_COLOR_2_WHITEPOINT)
 """
 *REDcolor2* colourspace to *CIE XYZ* tristimulus values matrix.
 
@@ -196,7 +171,7 @@ RED_COLOR_2_COLOURSPACE = RGB_Colourspace(
     RED_COLOR_2_TO_XYZ_MATRIX,
     XYZ_TO_RED_COLOR_2_MATRIX,
     log_encoding_REDLogFilm,
-    log_decoding_REDLogFilm)
+    log_decoding_REDLogFilm)  # yapf: disable
 """
 *REDcolor2* colourspace.
 
@@ -206,7 +181,7 @@ RED_COLOR_2_COLOURSPACE : RGB_Colourspace
 RED_COLOR_3_PRIMARIES = np.array(
     [[0.701181035906413, 0.329014155583010],
      [0.300600304651563, 0.683788834268552],
-     [0.108154455624011, -0.008688175786660]])
+     [0.108154455624011, -0.008688175786660]])  # yapf: disable
 """
 *REDcolor3* colourspace primaries.
 
@@ -227,8 +202,8 @@ RED_COLOR_3_WHITEPOINT = RED_COLOR_WHITEPOINT
 RED_COLOR_3_WHITEPOINT : ndarray
 """
 
-RED_COLOR_3_TO_XYZ_MATRIX = normalised_primary_matrix(
-    RED_COLOR_3_PRIMARIES, RED_COLOR_3_WHITEPOINT)
+RED_COLOR_3_TO_XYZ_MATRIX = normalised_primary_matrix(RED_COLOR_3_PRIMARIES,
+                                                      RED_COLOR_3_WHITEPOINT)
 """
 *REDcolor3* colourspace to *CIE XYZ* tristimulus values matrix.
 
@@ -250,7 +225,7 @@ RED_COLOR_3_COLOURSPACE = RGB_Colourspace(
     RED_COLOR_3_TO_XYZ_MATRIX,
     XYZ_TO_RED_COLOR_3_MATRIX,
     log_encoding_REDLogFilm,
-    log_decoding_REDLogFilm)
+    log_decoding_REDLogFilm)  # yapf: disable
 """
 *REDcolor3* colourspace.
 
@@ -260,7 +235,7 @@ RED_COLOR_3_COLOURSPACE : RGB_Colourspace
 RED_COLOR_4_PRIMARIES = np.array(
     [[0.701180591891983, 0.329013699115539],
      [0.300600395529389, 0.683788824257266],
-     [0.145331946228869, 0.051616803622619]])
+     [0.145331946228869, 0.051616803622619]])  # yapf: disable
 """
 *REDcolor4* colourspace primaries.
 
@@ -281,8 +256,8 @@ RED_COLOR_4_WHITEPOINT = RED_COLOR_WHITEPOINT
 RED_COLOR_4_WHITEPOINT : ndarray
 """
 
-RED_COLOR_4_TO_XYZ_MATRIX = normalised_primary_matrix(
-    RED_COLOR_4_PRIMARIES, RED_COLOR_4_WHITEPOINT)
+RED_COLOR_4_TO_XYZ_MATRIX = normalised_primary_matrix(RED_COLOR_4_PRIMARIES,
+                                                      RED_COLOR_4_WHITEPOINT)
 """
 *REDcolor4* colourspace to *CIE XYZ* tristimulus values matrix.
 
@@ -304,7 +279,7 @@ RED_COLOR_4_COLOURSPACE = RGB_Colourspace(
     RED_COLOR_4_TO_XYZ_MATRIX,
     XYZ_TO_RED_COLOR_4_MATRIX,
     log_encoding_REDLogFilm,
-    log_decoding_REDLogFilm)
+    log_decoding_REDLogFilm)  # yapf: disable
 """
 *REDcolor4* colourspace.
 
@@ -314,7 +289,7 @@ RED_COLOR_4_COLOURSPACE : RGB_Colourspace
 DRAGON_COLOR_PRIMARIES = np.array(
     [[0.753044222784747, 0.327830576681599],
      [0.299570228480719, 0.700699321955751],
-     [0.079642066734959, -0.054937951088786]])
+     [0.079642066734959, -0.054937951088786]])  # yapf: disable
 """
 *DRAGONcolor* colourspace primaries.
 
@@ -335,8 +310,8 @@ DRAGON_COLOR_WHITEPOINT = RED_COLOR_WHITEPOINT
 DRAGON_COLOR_WHITEPOINT : ndarray
 """
 
-DRAGON_COLOR_TO_XYZ_MATRIX = normalised_primary_matrix(
-    DRAGON_COLOR_PRIMARIES, DRAGON_COLOR_WHITEPOINT)
+DRAGON_COLOR_TO_XYZ_MATRIX = normalised_primary_matrix(DRAGON_COLOR_PRIMARIES,
+                                                       DRAGON_COLOR_WHITEPOINT)
 """
 *DRAGONcolor* colourspace to *CIE XYZ* tristimulus values matrix.
 
@@ -358,7 +333,7 @@ DRAGON_COLOR_COLOURSPACE = RGB_Colourspace(
     DRAGON_COLOR_TO_XYZ_MATRIX,
     XYZ_TO_DRAGON_COLOR_MATRIX,
     log_encoding_REDLogFilm,
-    log_decoding_REDLogFilm)
+    log_decoding_REDLogFilm)  # yapf: disable
 """
 *DRAGONcolor* colourspace.
 
@@ -368,7 +343,7 @@ DRAGON_COLOR_COLOURSPACE : RGB_Colourspace
 DRAGON_COLOR_2_PRIMARIES = np.array(
     [[0.753044491143000, 0.327831029513214],
      [0.299570490451307, 0.700699415613996],
-     [0.145011584277975, 0.051097125087887]])
+     [0.145011584277975, 0.051097125087887]])  # yapf: disable
 """
 *DRAGONcolor2* colourspace primaries.
 
@@ -412,7 +387,7 @@ DRAGON_COLOR_2_COLOURSPACE = RGB_Colourspace(
     DRAGON_COLOR_2_TO_XYZ_MATRIX,
     XYZ_TO_DRAGON_COLOR_2_MATRIX,
     log_encoding_REDLogFilm,
-    log_decoding_REDLogFilm)
+    log_decoding_REDLogFilm)  # yapf: disable
 """
 *DRAGONcolor2* colourspace.
 
@@ -422,7 +397,7 @@ DRAGON_COLOR_2_COLOURSPACE : RGB_Colourspace
 RED_WIDE_GAMUT_RGB_PRIMARIES = np.array(
     [[0.780308, 0.304253],
      [0.121595, 1.493994],
-     [0.095612, -0.084589]])
+     [0.095612, -0.084589]])  # yapf: disable
 """
 *REDWideGamutRGB* colourspace primaries.
 
@@ -436,9 +411,8 @@ RED_WIDE_GAMUT_RGB_ILLUMINANT = 'D65'
 RED_WIDE_GAMUT_RGB_ILLUMINANT : unicode
 """
 
-RED_WIDE_GAMUT_RGB_WHITEPOINT = (
-    ILLUMINANTS['CIE 1931 2 Degree Standard Observer'][
-        RED_WIDE_GAMUT_RGB_ILLUMINANT])
+RED_WIDE_GAMUT_RGB_WHITEPOINT = (ILLUMINANTS[
+    'CIE 1931 2 Degree Standard Observer'][RED_WIDE_GAMUT_RGB_ILLUMINANT])
 """
 *REDWideGamutRGB* colourspace whitepoint.
 
@@ -448,7 +422,7 @@ RED_WIDE_GAMUT_RGB_WHITEPOINT : ndarray
 RED_WIDE_GAMUT_RGB_TO_XYZ_MATRIX = np.array(
     [[0.735275, 0.068609, 0.146571],
      [0.286694, 0.842979, -0.129673],
-     [-0.079681, -0.347343, 1.516082]])
+     [-0.079681, -0.347343, 1.516082]])  # yapf: disable
 """
 *REDWideGamutRGB* colourspace to *CIE XYZ* tristimulus values matrix.
 
@@ -471,7 +445,7 @@ RED_WIDE_GAMUT_RGB_COLOURSPACE = RGB_Colourspace(
     RED_WIDE_GAMUT_RGB_TO_XYZ_MATRIX,
     XYZ_TO_RED_WIDE_GAMUT_RGB_MATRIX,
     log_encoding_Log3G10,
-    log_decoding_Log3G10)
+    log_decoding_Log3G10)  # yapf: disable
 """
 *REDWideGamutRGB* colourspace.
 
