@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 sRGB Colourspace
 ================
@@ -33,10 +32,7 @@ from __future__ import division, unicode_literals
 import numpy as np
 
 from colour.colorimetry import ILLUMINANTS
-from colour.models.rgb import (
-    RGB_Colourspace,
-    oetf_sRGB,
-    eotf_sRGB)
+from colour.models.rgb import (RGB_Colourspace, oetf_sRGB, eotf_sRGB)
 
 __author__ = 'Colour Developers'
 __copyright__ = 'Copyright (C) 2013-2017 - Colour Developers'
@@ -45,17 +41,15 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['sRGB_PRIMARIES',
-           'sRGB_ILLUMINANT',
-           'sRGB_WHITEPOINT',
-           'sRGB_TO_XYZ_MATRIX',
-           'XYZ_TO_sRGB_MATRIX',
-           'sRGB_COLOURSPACE']
+__all__ = [
+    'sRGB_PRIMARIES', 'sRGB_ILLUMINANT', 'sRGB_WHITEPOINT',
+    'sRGB_TO_XYZ_MATRIX', 'XYZ_TO_sRGB_MATRIX', 'sRGB_COLOURSPACE'
+]
 
 sRGB_PRIMARIES = np.array(
     [[0.6400, 0.3300],
      [0.3000, 0.6000],
-     [0.1500, 0.0600]])
+     [0.1500, 0.0600]])  # yapf: disable
 """
 *sRGB* colourspace primaries.
 
@@ -80,7 +74,7 @@ sRGB_WHITEPOINT : ndarray
 sRGB_TO_XYZ_MATRIX = np.array(
     [[0.4124, 0.3576, 0.1805],
      [0.2126, 0.7152, 0.0722],
-     [0.0193, 0.1192, 0.9505]])
+     [0.0193, 0.1192, 0.9505]])  # yapf: disable
 """
 *sRGB* colourspace to *CIE XYZ* tristimulus values matrix.
 
@@ -90,7 +84,7 @@ sRGB_TO_XYZ_MATRIX : array_like, (3, 3)
 XYZ_TO_sRGB_MATRIX = np.array(
     [[3.2406, -1.5372, -0.4986],
      [-0.9689, 1.8758, 0.0415],
-     [0.0557, -0.2040, 1.0570]])
+     [0.0557, -0.2040, 1.0570]])  # yapf: disable
 """
 *CIE XYZ* tristimulus values to *sRGB* colourspace matrix.
 
@@ -105,7 +99,7 @@ sRGB_COLOURSPACE = RGB_Colourspace(
     sRGB_TO_XYZ_MATRIX,
     XYZ_TO_sRGB_MATRIX,
     oetf_sRGB,
-    eotf_sRGB)
+    eotf_sRGB)  # yapf: disable
 """
 *sRGB* colourspace.
 
