@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 V-Gamut Colourspace
 ===================
@@ -27,10 +26,8 @@ from __future__ import division, unicode_literals
 import numpy as np
 
 from colour.colorimetry import ILLUMINANTS
-from colour.models.rgb import (
-    RGB_Colourspace,
-    log_encoding_VLog,
-    log_decoding_VLog)
+from colour.models.rgb import (RGB_Colourspace, log_encoding_VLog,
+                               log_decoding_VLog)
 
 __author__ = 'Colour Developers'
 __copyright__ = 'Copyright (C) 2013-2017 - Colour Developers'
@@ -39,17 +36,15 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['V_GAMUT_PRIMARIES',
-           'V_GAMUT_ILLUMINANT',
-           'V_GAMUT_WHITEPOINT',
-           'V_GAMUT_TO_XYZ_MATRIX',
-           'XYZ_TO_V_GAMUT_MATRIX',
-           'V_GAMUT_COLOURSPACE']
+__all__ = [
+    'V_GAMUT_PRIMARIES', 'V_GAMUT_ILLUMINANT', 'V_GAMUT_WHITEPOINT',
+    'V_GAMUT_TO_XYZ_MATRIX', 'XYZ_TO_V_GAMUT_MATRIX', 'V_GAMUT_COLOURSPACE'
+]
 
 V_GAMUT_PRIMARIES = np.array(
     [[0.730, 0.280],
      [0.165, 0.840],
-     [0.100, -0.030]])
+     [0.100, -0.030]])  # yapf: disable
 """
 *V-Gamut* colourspace primaries.
 
@@ -74,7 +69,7 @@ V_GAMUT_WHITEPOINT : ndarray
 V_GAMUT_TO_XYZ_MATRIX = np.array(
     [[0.679644, 0.152211, 0.118600],
      [0.260686, 0.774894, -0.035580],
-     [-0.009310, -0.004612, 1.102980]])
+     [-0.009310, -0.004612, 1.102980]])  # yapf: disable
 """
 *V-Gamut* colourspace to *CIE XYZ* tristimulus values matrix.
 
@@ -84,7 +79,7 @@ V_GAMUT_TO_XYZ_MATRIX : array_like, (3, 3)
 XYZ_TO_V_GAMUT_MATRIX = np.array(
     [[1.589012, -0.313204, -0.180965],
      [-0.534053, 1.396011, 0.102458],
-     [0.011179, 0.003194, 0.905535]])
+     [0.011179, 0.003194, 0.905535]])  # yapf: disable
 """
 *CIE XYZ* tristimulus values to *V-Gamut* colourspace matrix.
 
@@ -99,7 +94,7 @@ V_GAMUT_COLOURSPACE = RGB_Colourspace(
     V_GAMUT_TO_XYZ_MATRIX,
     XYZ_TO_V_GAMUT_MATRIX,
     log_encoding_VLog,
-    log_decoding_VLog)
+    log_decoding_VLog)  # yapf: disable
 """
 *V-Gamut* colourspace.
 
