@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Defines unit tests for :mod:`colour.models.rgb.common` module.
 """
@@ -44,26 +43,30 @@ class TestXYZ_to_sRGB(unittest.TestCase):
             decimal=7)
 
         np.testing.assert_almost_equal(
-            XYZ_to_sRGB(np.array([0.00000000, 0.00000000, 0.00000000]),
-                        np.array([0.44757, 0.40745])),
+            XYZ_to_sRGB(
+                np.array([0.00000000, 0.00000000, 0.00000000]),
+                np.array([0.44757, 0.40745])),
             np.array([0.00000000, 0.00000000, 0.00000000]),
             decimal=7)
 
         np.testing.assert_almost_equal(
-            XYZ_to_sRGB(np.array([0.11805834, 0.10340000, 0.05150892]),
-                        np.array([0.31270, 0.32900])),
+            XYZ_to_sRGB(
+                np.array([0.11805834, 0.10340000, 0.05150892]),
+                np.array([0.31270, 0.32900])),
             np.array([0.48221920, 0.31656152, 0.22070695]),
             decimal=7)
 
         np.testing.assert_almost_equal(
-            XYZ_to_sRGB(np.array([0.07049534, 0.10080000, 0.09558313]),
-                        chromatic_adaptation_transform='Bradford'),
+            XYZ_to_sRGB(
+                np.array([0.07049534, 0.10080000, 0.09558313]),
+                chromatic_adaptation_transform='Bradford'),
             np.array([0.17498817, 0.38819472, 0.32160312]),
             decimal=7)
 
         np.testing.assert_almost_equal(
-            XYZ_to_sRGB(np.array([0.07049534, 0.10080000, 0.09558313]),
-                        apply_encoding_cctf=False),
+            XYZ_to_sRGB(
+                np.array([0.07049534, 0.10080000, 0.09558313]),
+                apply_encoding_cctf=False),
             np.array([0.02583969, 0.12474440, 0.08439476]),
             decimal=7)
 
@@ -90,26 +93,30 @@ class TestsRGB_to_XYZ(unittest.TestCase):
             decimal=7)
 
         np.testing.assert_almost_equal(
-            sRGB_to_XYZ(np.array([0.00000000, 0.00000000, 0.00000000]),
-                        np.array([0.44757, 0.40745])),
+            sRGB_to_XYZ(
+                np.array([0.00000000, 0.00000000, 0.00000000]),
+                np.array([0.44757, 0.40745])),
             np.array([0.00000000, 0.00000000, 0.00000000]),
             decimal=7)
 
         np.testing.assert_almost_equal(
-            sRGB_to_XYZ(np.array([0.48222001, 0.31654775, 0.22070353]),
-                        np.array([0.31270, 0.32900])),
+            sRGB_to_XYZ(
+                np.array([0.48222001, 0.31654775, 0.22070353]),
+                np.array([0.31270, 0.32900])),
             np.array([0.11805834, 0.10340000, 0.05150892]),
             decimal=7)
 
         np.testing.assert_almost_equal(
-            sRGB_to_XYZ(np.array([0.17498172, 0.38818743, 0.32159978]),
-                        chromatic_adaptation_method='Bradford'),
+            sRGB_to_XYZ(
+                np.array([0.17498172, 0.38818743, 0.32159978]),
+                chromatic_adaptation_method='Bradford'),
             np.array([0.07049534, 0.10080000, 0.09558313]),
             decimal=7)
 
         np.testing.assert_almost_equal(
-            sRGB_to_XYZ(np.array([0.02583795, 0.12473949, 0.08439296]),
-                        apply_decoding_cctf=False),
+            sRGB_to_XYZ(
+                np.array([0.02583795, 0.12473949, 0.08439296]),
+                apply_decoding_cctf=False),
             np.array([0.07049534, 0.10080000, 0.09558313]),
             decimal=7)
 
