@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Defines unit tests for :mod:`colour.models.rgb.deprecated` module.
 """
@@ -11,15 +10,9 @@ import numpy as np
 import unittest
 from itertools import permutations
 
-from colour.models.rgb.deprecated import (
-    RGB_to_HSV,
-    HSV_to_RGB,
-    RGB_to_HSL,
-    HSL_to_RGB,
-    RGB_to_CMY,
-    CMY_to_RGB,
-    CMY_to_CMYK,
-    CMYK_to_CMY)
+from colour.models.rgb.deprecated import (RGB_to_HSV, HSV_to_RGB, RGB_to_HSL,
+                                          HSL_to_RGB, RGB_to_CMY, CMY_to_RGB,
+                                          CMY_to_CMYK, CMYK_to_CMY)
 from colour.utilities import ignore_numpy_errors
 
 __author__ = 'Colour Developers'
@@ -29,14 +22,10 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['TestRGB_to_HSV',
-           'TestHSV_to_RGB',
-           'TestRGB_to_HSL',
-           'TestHSL_to_RGB',
-           'TestRGB_to_CMY',
-           'TestCMY_to_RGB',
-           'TestCMY_to_CMYK',
-           'TestCMYK_to_CMY']
+__all__ = [
+    'TestRGB_to_HSV', 'TestHSV_to_RGB', 'TestRGB_to_HSL', 'TestHSL_to_RGB',
+    'TestRGB_to_CMY', 'TestCMY_to_RGB', 'TestCMY_to_CMYK', 'TestCMYK_to_CMY'
+]
 
 
 class TestRGB_to_HSV(unittest.TestCase):
@@ -73,24 +62,15 @@ class TestRGB_to_HSV(unittest.TestCase):
 
         RGB = np.array([0.25000000, 0.60000000, 0.05000000])
         HSV = np.array([0.27272727, 0.91666667, 0.6])
-        np.testing.assert_almost_equal(
-            RGB_to_HSV(RGB),
-            HSV,
-            decimal=7)
+        np.testing.assert_almost_equal(RGB_to_HSV(RGB), HSV, decimal=7)
 
         RGB = np.tile(RGB, (6, 1))
         HSV = np.tile(HSV, (6, 1))
-        np.testing.assert_almost_equal(
-            RGB_to_HSV(RGB),
-            HSV,
-            decimal=7)
+        np.testing.assert_almost_equal(RGB_to_HSV(RGB), HSV, decimal=7)
 
         RGB = np.reshape(RGB, (2, 3, 3))
         HSV = np.reshape(HSV, (2, 3, 3))
-        np.testing.assert_almost_equal(
-            RGB_to_HSV(RGB),
-            HSV,
-            decimal=7)
+        np.testing.assert_almost_equal(RGB_to_HSV(RGB), HSV, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_RGB_to_HSV(self):
@@ -140,24 +120,15 @@ class TestHSV_to_RGB(unittest.TestCase):
 
         HSV = np.array([0.27272727, 0.91666667, 0.60000000])
         RGB = np.array([0.25000000, 0.60000000, 0.05000000])
-        np.testing.assert_almost_equal(
-            HSV_to_RGB(HSV),
-            RGB,
-            decimal=7)
+        np.testing.assert_almost_equal(HSV_to_RGB(HSV), RGB, decimal=7)
 
         HSV = np.tile(HSV, (6, 1))
         RGB = np.tile(RGB, (6, 1))
-        np.testing.assert_almost_equal(
-            HSV_to_RGB(HSV),
-            RGB,
-            decimal=7)
+        np.testing.assert_almost_equal(HSV_to_RGB(HSV), RGB, decimal=7)
 
         HSV = np.reshape(HSV, (2, 3, 3))
         RGB = np.reshape(RGB, (2, 3, 3))
-        np.testing.assert_almost_equal(
-            HSV_to_RGB(HSV),
-            RGB,
-            decimal=7)
+        np.testing.assert_almost_equal(HSV_to_RGB(HSV), RGB, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_HSV_to_RGB(self):
@@ -207,24 +178,15 @@ class TestRGB_to_HSL(unittest.TestCase):
 
         RGB = np.array([0.25000000, 0.60000000, 0.05000000])
         HSL = np.array([0.27272727, 0.84615385, 0.325])
-        np.testing.assert_almost_equal(
-            RGB_to_HSL(RGB),
-            HSL,
-            decimal=7)
+        np.testing.assert_almost_equal(RGB_to_HSL(RGB), HSL, decimal=7)
 
         RGB = np.tile(RGB, (6, 1))
         HSL = np.tile(HSL, (6, 1))
-        np.testing.assert_almost_equal(
-            RGB_to_HSL(RGB),
-            HSL,
-            decimal=7)
+        np.testing.assert_almost_equal(RGB_to_HSL(RGB), HSL, decimal=7)
 
         RGB = np.reshape(RGB, (2, 3, 3))
         HSL = np.reshape(HSL, (2, 3, 3))
-        np.testing.assert_almost_equal(
-            RGB_to_HSL(RGB),
-            HSL,
-            decimal=7)
+        np.testing.assert_almost_equal(RGB_to_HSL(RGB), HSL, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_RGB_to_HSL(self):
@@ -274,24 +236,15 @@ class TestHSL_to_RGB(unittest.TestCase):
 
         HSL = np.array([0.27272727, 0.84615385, 0.32500000])
         RGB = np.array([0.25000000, 0.60000000, 0.05000000])
-        np.testing.assert_almost_equal(
-            HSL_to_RGB(HSL),
-            RGB,
-            decimal=7)
+        np.testing.assert_almost_equal(HSL_to_RGB(HSL), RGB, decimal=7)
 
         HSL = np.tile(HSL, (6, 1))
         RGB = np.tile(RGB, (6, 1))
-        np.testing.assert_almost_equal(
-            HSL_to_RGB(HSL),
-            RGB,
-            decimal=7)
+        np.testing.assert_almost_equal(HSL_to_RGB(HSL), RGB, decimal=7)
 
         HSL = np.reshape(HSL, (2, 3, 3))
         RGB = np.reshape(RGB, (2, 3, 3))
-        np.testing.assert_almost_equal(
-            HSL_to_RGB(HSL),
-            RGB,
-            decimal=7)
+        np.testing.assert_almost_equal(HSL_to_RGB(HSL), RGB, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_HSL_to_RGB(self):
@@ -341,24 +294,15 @@ class TestRGB_to_CMY(unittest.TestCase):
 
         RGB = np.array([0.25000000, 0.60000000, 0.05000000])
         CMY = np.array([0.75000000, 0.40000000, 0.95000000])
-        np.testing.assert_almost_equal(
-            RGB_to_CMY(RGB),
-            CMY,
-            decimal=7)
+        np.testing.assert_almost_equal(RGB_to_CMY(RGB), CMY, decimal=7)
 
         RGB = np.tile(RGB, (6, 1))
         CMY = np.tile(CMY, (6, 1))
-        np.testing.assert_almost_equal(
-            RGB_to_CMY(RGB),
-            CMY,
-            decimal=7)
+        np.testing.assert_almost_equal(RGB_to_CMY(RGB), CMY, decimal=7)
 
         RGB = np.reshape(RGB, (2, 3, 3))
         CMY = np.reshape(CMY, (2, 3, 3))
-        np.testing.assert_almost_equal(
-            RGB_to_CMY(RGB),
-            CMY,
-            decimal=7)
+        np.testing.assert_almost_equal(RGB_to_CMY(RGB), CMY, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_RGB_to_CMY(self):
@@ -408,24 +352,15 @@ class TestCMY_to_RGB(unittest.TestCase):
 
         CMY = np.array([0.75000000, 0.40000000, 0.95000000])
         RGB = np.array([0.25000000, 0.60000000, 0.05000000])
-        np.testing.assert_almost_equal(
-            CMY_to_RGB(CMY),
-            RGB,
-            decimal=7)
+        np.testing.assert_almost_equal(CMY_to_RGB(CMY), RGB, decimal=7)
 
         CMY = np.tile(CMY, (6, 1))
         RGB = np.tile(RGB, (6, 1))
-        np.testing.assert_almost_equal(
-            CMY_to_RGB(CMY),
-            RGB,
-            decimal=7)
+        np.testing.assert_almost_equal(CMY_to_RGB(CMY), RGB, decimal=7)
 
         CMY = np.reshape(CMY, (2, 3, 3))
         RGB = np.reshape(RGB, (2, 3, 3))
-        np.testing.assert_almost_equal(
-            CMY_to_RGB(CMY),
-            RGB,
-            decimal=7)
+        np.testing.assert_almost_equal(CMY_to_RGB(CMY), RGB, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_CMY_to_RGB(self):
@@ -475,24 +410,15 @@ class TestCMY_to_CMYK(unittest.TestCase):
 
         CMY = np.array([0.75000000, 0.40000000, 0.95000000])
         CMYK = np.array([0.58333333, 0.00000000, 0.91666667, 0.40000000])
-        np.testing.assert_almost_equal(
-            CMY_to_CMYK(CMY),
-            CMYK,
-            decimal=7)
+        np.testing.assert_almost_equal(CMY_to_CMYK(CMY), CMYK, decimal=7)
 
         CMY = np.tile(CMY, (6, 1))
         CMYK = np.tile(CMYK, (6, 1))
-        np.testing.assert_almost_equal(
-            CMY_to_CMYK(CMY),
-            CMYK,
-            decimal=7)
+        np.testing.assert_almost_equal(CMY_to_CMYK(CMY), CMYK, decimal=7)
 
         CMY = np.reshape(CMY, (2, 3, 3))
         CMYK = np.reshape(CMYK, (2, 3, 4))
-        np.testing.assert_almost_equal(
-            CMY_to_CMYK(CMY),
-            CMYK,
-            decimal=7)
+        np.testing.assert_almost_equal(CMY_to_CMYK(CMY), CMYK, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_CMY_to_CMYK(self):
@@ -520,26 +446,20 @@ class TestCMYK_to_CMY(unittest.TestCase):
         """
 
         np.testing.assert_almost_equal(
-            CMYK_to_CMY(np.array([0.58333333,
-                                  0.00000000,
-                                  0.91666667,
-                                  0.40000000])),
+            CMYK_to_CMY(
+                np.array([0.58333333, 0.00000000, 0.91666667, 0.40000000])),
             np.array([0.75000000, 0.40000000, 0.95000000]),
             decimal=7)
 
         np.testing.assert_almost_equal(
-            CMYK_to_CMY(np.array([0.00000000,
-                                  1.00000000,
-                                  1.00000000,
-                                  0.15000000])),
+            CMYK_to_CMY(
+                np.array([0.00000000, 1.00000000, 1.00000000, 0.15000000])),
             np.array([0.15000000, 1.00000000, 1.00000000]),
             decimal=7)
 
         np.testing.assert_almost_equal(
-            CMYK_to_CMY(np.array([0.15000000,
-                                  0.00000000,
-                                  0.00000000,
-                                  0.00000000])),
+            CMYK_to_CMY(
+                np.array([0.15000000, 0.00000000, 0.00000000, 0.00000000])),
             np.array([0.15000000, 0.00000000, 0.00000000]),
             decimal=7)
 
@@ -549,29 +469,17 @@ class TestCMYK_to_CMY(unittest.TestCase):
         n-dimensional arrays support.
         """
 
-        CMYK = np.array([0.58333333,
-                         0.00000000,
-                         0.91666667,
-                         0.40000000])
+        CMYK = np.array([0.58333333, 0.00000000, 0.91666667, 0.40000000])
         CMY = np.array([0.75000000, 0.40000000, 0.95000000])
-        np.testing.assert_almost_equal(
-            CMYK_to_CMY(CMYK),
-            CMY,
-            decimal=7)
+        np.testing.assert_almost_equal(CMYK_to_CMY(CMYK), CMY, decimal=7)
 
         CMYK = np.tile(CMYK, (6, 1))
         CMY = np.tile(CMY, (6, 1))
-        np.testing.assert_almost_equal(
-            CMYK_to_CMY(CMYK),
-            CMY,
-            decimal=7)
+        np.testing.assert_almost_equal(CMYK_to_CMY(CMYK), CMY, decimal=7)
 
         CMYK = np.reshape(CMYK, (2, 3, 4))
         CMY = np.reshape(CMY, (2, 3, 3))
-        np.testing.assert_almost_equal(
-            CMYK_to_CMY(CMYK),
-            CMY,
-            decimal=7)
+        np.testing.assert_almost_equal(CMYK_to_CMY(CMYK), CMY, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_CMYK_to_CMY(self):
