@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Defines unit tests for :mod:`colour.models.rgb.derivation` module.
 """
@@ -14,11 +13,8 @@ from itertools import permutations
 from six import text_type
 
 from colour.models import (
-    normalised_primary_matrix,
-    chromatically_adapted_primaries,
-    primaries_whitepoint,
-    RGB_luminance_equation,
-    RGB_luminance)
+    normalised_primary_matrix, chromatically_adapted_primaries,
+    primaries_whitepoint, RGB_luminance_equation, RGB_luminance)
 from colour.models.rgb.derivation import xy_to_z
 from colour.utilities import ignore_numpy_errors
 
@@ -29,12 +25,11 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['Testxy_to_z',
-           'TestNormalisedPrimaryMatrix',
-           'TestChromaticallyAdaptedPrimaries',
-           'TestPrimariesWhitepoint',
-           'TestRGBLuminanceEquation',
-           'TestRGBLuminance']
+__all__ = [
+    'Testxy_to_z', 'TestNormalisedPrimaryMatrix',
+    'TestChromaticallyAdaptedPrimaries', 'TestPrimariesWhitepoint',
+    'TestRGBLuminanceEquation', 'TestRGBLuminance'
+]
 
 
 class Testxy_to_z(unittest.TestCase):
@@ -49,19 +44,13 @@ class Testxy_to_z(unittest.TestCase):
         """
 
         np.testing.assert_almost_equal(
-            xy_to_z(np.array([0.2500, 0.2500])),
-            0.50000000,
-            decimal=7)
+            xy_to_z(np.array([0.2500, 0.2500])), 0.50000000, decimal=7)
 
         np.testing.assert_almost_equal(
-            xy_to_z(np.array([0.0001, -0.0770])),
-            1.07690000,
-            decimal=7)
+            xy_to_z(np.array([0.0001, -0.0770])), 1.07690000, decimal=7)
 
         np.testing.assert_almost_equal(
-            xy_to_z(np.array([0.0000, 1.0000])),
-            0.00000000,
-            decimal=7)
+            xy_to_z(np.array([0.0000, 1.0000])), 0.00000000, decimal=7)
 
     def test_n_dimensional_xy_to_z(self):
         """
@@ -71,24 +60,17 @@ class Testxy_to_z(unittest.TestCase):
 
         xy = np.array([0.25, 0.25])
         z = 0.5
-        np.testing.assert_almost_equal(
-            xy_to_z(xy),
-            z,
-            decimal=7)
+        np.testing.assert_almost_equal(xy_to_z(xy), z, decimal=7)
 
         xy = np.tile(xy, (6, 1))
-        z = np.tile(z, 6, )
-        np.testing.assert_almost_equal(
-            xy_to_z(xy),
+        z = np.tile(
             z,
-            decimal=7)
+            6, )
+        np.testing.assert_almost_equal(xy_to_z(xy), z, decimal=7)
 
         xy = np.reshape(xy, (2, 3, 2))
         z = np.reshape(z, (2, 3))
-        np.testing.assert_almost_equal(
-            xy_to_z(xy),
-            z,
-            decimal=7)
+        np.testing.assert_almost_equal(xy_to_z(xy), z, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_xy_to_z(self):
@@ -117,25 +99,24 @@ class TestNormalisedPrimaryMatrix(unittest.TestCase):
 
         np.testing.assert_almost_equal(
             normalised_primary_matrix(
-                np.array([0.73470, 0.26530,
-                          0.00000, 1.00000,
-                          0.00010, -0.07700]),
+                np.array(
+                    [0.73470, 0.26530, 0.00000, 1.00000, 0.00010, -0.07700]),
                 np.array([0.32168, 0.33767])),
-            np.array([[0.95255240, 0.00000000, 0.00009368],
-                      [0.34396645, 0.72816610, -0.07213255],
-                      [0.00000000, 0.00000000, 1.00882518]]),
-            decimal=7)
+            np.array(
+                [[0.95255240, 0.00000000, 0.00009368],
+                 [0.34396645, 0.72816610, -0.07213255],
+                 [0.00000000, 0.00000000, 1.00882518]]),
+            decimal=7)  # yapf: disable
 
         np.testing.assert_almost_equal(
             normalised_primary_matrix(
-                np.array([0.640, 0.330,
-                          0.300, 0.600,
-                          0.150, 0.060]),
+                np.array([0.640, 0.330, 0.300, 0.600, 0.150, 0.060]),
                 np.array([0.3127, 0.3290])),
-            np.array([[0.41239080, 0.35758434, 0.18048079],
-                      [0.21263901, 0.71516868, 0.07219232],
-                      [0.01933082, 0.11919478, 0.95053215]]),
-            decimal=7)
+            np.array(
+                [[0.41239080, 0.35758434, 0.18048079],
+                 [0.21263901, 0.71516868, 0.07219232],
+                 [0.01933082, 0.11919478, 0.95053215]]),
+            decimal=7)  # yapf: disable
 
     @ignore_numpy_errors
     def test_nan_normalised_primary_matrix(self):
@@ -172,40 +153,35 @@ chromatically_adapted_primaries` definition.
 
         np.testing.assert_almost_equal(
             chromatically_adapted_primaries(
-                np.array([0.73470, 0.26530,
-                          0.00000, 1.00000,
-                          0.00010, -0.07700]),
-                np.array([0.32168, 0.33767]),
-                np.array([0.34570, 0.35850])),
-            np.array([[0.73431182, 0.26694964],
-                      [0.02211963, 0.98038009],
-                      [-0.05880375, -0.12573056]]),
-            decimal=7)
+                np.array(
+                    [0.73470, 0.26530, 0.00000, 1.00000, 0.00010, -0.07700]),
+                np.array([0.32168, 0.33767]), np.array([0.34570, 0.35850])),
+            np.array(
+                [[0.73431182, 0.26694964],
+                 [0.02211963, 0.98038009],
+                 [-0.05880375, -0.12573056]]),
+            decimal=7)  # yapf: disable
 
         np.testing.assert_almost_equal(
             chromatically_adapted_primaries(
-                np.array([0.640, 0.330,
-                          0.300, 0.600,
-                          0.150, 0.060]),
-                np.array([0.31270, 0.32900]),
-                np.array([0.34570, 0.35850])),
-            np.array([[0.64922534, 0.33062196],
-                      [0.32425276, 0.60237128],
-                      [0.15236177, 0.06118676]]),
-            decimal=7)
+                np.array([0.640, 0.330, 0.300, 0.600, 0.150, 0.060]),
+                np.array([0.31270, 0.32900]), np.array([0.34570, 0.35850])),
+            np.array(
+                [[0.64922534, 0.33062196],
+                 [0.32425276, 0.60237128],
+                 [0.15236177, 0.06118676]]),
+            decimal=7)  # yapf: disable
 
         np.testing.assert_almost_equal(
             chromatically_adapted_primaries(
-                np.array([0.640, 0.330,
-                          0.300, 0.600,
-                          0.150, 0.060]),
+                np.array([0.640, 0.330, 0.300, 0.600, 0.150, 0.060]),
                 np.array([0.31270, 0.32900]),
-                np.array([0.34570, 0.35850]),
-                'Bradford'),
-            np.array([[0.64844144, 0.33085331],
-                      [0.32119518, 0.59784434],
-                      [0.15589322, 0.06604921]]),
-            decimal=7)
+                np.array([0.34570, 0.35850]), 'Bradford'),
+            np.array(
+                [[0.64844144, 0.33085331],
+                 [0.32119518, 0.59784434],
+                 [0.15589322, 0.06604921]]),
+            decimal=7)  # yapf: disable
 
     @ignore_numpy_errors
     def test_nan_chromatically_adapted_primaries(self):
@@ -234,35 +210,35 @@ class TestPrimariesWhitepoint(unittest.TestCase):
         definition.
         """
 
-        P, W = primaries_whitepoint(np.array(
-            [[0.95255240, 0.00000000, 0.00009368],
-             [0.34396645, 0.72816610, -0.07213255],
-             [0.00000000, 0.00000000, 1.00882518]]))
+        P, W = primaries_whitepoint(
+            np.array(
+                [[0.95255240, 0.00000000, 0.00009368],
+                 [0.34396645, 0.72816610, -0.07213255],
+                 [0.00000000, 0.00000000, 1.00882518]]))  # yapf: disable
         np.testing.assert_almost_equal(
             P,
-            np.array([[0.73470, 0.26530],
-                      [0.00000, 1.00000],
-                      [0.00010, -0.07700]]),
-            decimal=7)
+            np.array(
+                [[0.73470, 0.26530],
+                 [0.00000, 1.00000],
+                 [0.00010, -0.07700]]),
+            decimal=7)  # yapf: disable
         np.testing.assert_almost_equal(
-            W,
-            np.array([0.32168, 0.33767]),
-            decimal=7)
+            W, np.array([0.32168, 0.33767]), decimal=7)
 
         P, W = primaries_whitepoint(
-            np.array([[0.41240000, 0.35760000, 0.18050000],
-                      [0.21260000, 0.71520000, 0.07220000],
-                      [0.01930000, 0.11920000, 0.95050000]]))
+            np.array(
+                [[0.41240000, 0.35760000, 0.18050000],
+                 [0.21260000, 0.71520000, 0.07220000],
+                 [0.01930000, 0.11920000, 0.95050000]]))  # yapf: disable
         np.testing.assert_almost_equal(
             P,
-            np.array([[0.64007450, 0.32997051],
-                      [0.30000000, 0.60000000],
-                      [0.15001662, 0.06000665]]),
-            decimal=7)
+            np.array(
+                [[0.64007450, 0.32997051],
+                 [0.30000000, 0.60000000],
+                 [0.15001662, 0.06000665]]),
+            decimal=7)  # yapf: disable
         np.testing.assert_almost_equal(
-            W,
-            np.array([0.31271591, 0.32900148]),
-            decimal=7)
+            W, np.array([0.31271591, 0.32900148]), decimal=7)
 
     @ignore_numpy_errors
     def test_nan_primaries_whitepoint(self):
@@ -292,22 +268,19 @@ class TestRGBLuminanceEquation(unittest.TestCase):
 
         self.assertIsInstance(
             RGB_luminance_equation(
-                np.array([0.73470, 0.26530,
-                          0.00000, 1.00000,
-                          0.00010, -0.07700]),
-                np.array([0.32168, 0.33767])),
-            text_type)
+                np.array(
+                    [0.73470, 0.26530, 0.00000, 1.00000, 0.00010, -0.07700]),
+                np.array([0.32168, 0.33767])), text_type)
 
-        self.assertTrue(re.match(
-            # TODO: Simplify that monster.
-            ('Y\s?=\s?[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?.'
-             '\(R\)\s?[+-]\s?[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?.'
-             '\(G\)\s?[+-]\s?[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?.\(B\)'),
-            RGB_luminance_equation(
-                np.array([0.73470, 0.26530,
-                          0.00000, 1.00000,
-                          0.00010, -0.07700]),
-                np.array([0.32168, 0.33767]))))
+        # TODO: Simplify that monster.
+        pattern = ('Y\s?=\s?[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?.'
+                   '\(R\)\s?[+-]\s?[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?.'
+                   '\(G\)\s?[+-]\s?[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?.'
+                   '\(B\)')
+        P = np.array([0.73470, 0.26530, 0.00000, 1.00000, 0.00010, -0.07700])
+        self.assertTrue(
+            re.match(pattern,
+                     RGB_luminance_equation(P, np.array([0.32168, 0.33767]))))
 
 
 class TestRGBLuminance(unittest.TestCase):
@@ -325,9 +298,8 @@ class TestRGBLuminance(unittest.TestCase):
         self.assertAlmostEqual(
             RGB_luminance(
                 np.array([50.0, 50.0, 50.0]),
-                np.array([0.73470, 0.26530,
-                          0.00000, 1.00000,
-                          0.00010, -0.07700]),
+                np.array(
+                    [0.73470, 0.26530, 0.00000, 1.00000, 0.00010, -0.07700]),
                 np.array([0.32168, 0.33767])),
             50.00000000,
             places=7)
@@ -335,9 +307,8 @@ class TestRGBLuminance(unittest.TestCase):
         self.assertAlmostEqual(
             RGB_luminance(
                 np.array([74.6, 16.1, 100.0]),
-                np.array([0.73470, 0.26530,
-                          0.00000, 1.00000,
-                          0.00010, -0.07700]),
+                np.array(
+                    [0.73470, 0.26530, 0.00000, 1.00000, 0.00010, -0.07700]),
                 np.array([0.32168, 0.33767])),
             30.17011667,
             places=7)
@@ -345,9 +316,8 @@ class TestRGBLuminance(unittest.TestCase):
         self.assertAlmostEqual(
             RGB_luminance(
                 np.array([40.6, 4.2, 67.4]),
-                np.array([0.73470, 0.26530,
-                          0.00000, 1.00000,
-                          0.00010, -0.07700]),
+                np.array(
+                    [0.73470, 0.26530, 0.00000, 1.00000, 0.00010, -0.07700]),
                 np.array([0.32168, 0.33767])),
             12.16160184,
             places=7)
@@ -359,26 +329,18 @@ class TestRGBLuminance(unittest.TestCase):
         """
 
         RGB = np.array([50.0, 50.0, 50.0]),
-        P = np.array([0.73470, 0.26530,
-                      0.00000, 1.00000,
-                      0.00010, -0.07700]),
+        P = np.array([0.73470, 0.26530, 0.00000, 1.00000, 0.00010, -0.07700]),
         W = np.array([0.32168, 0.33767])
         Y = 50
-        np.testing.assert_almost_equal(
-            RGB_luminance(RGB, P, W),
-            Y)
+        np.testing.assert_almost_equal(RGB_luminance(RGB, P, W), Y)
 
         RGB = np.tile(RGB, (6, 1))
         Y = np.tile(Y, 6)
-        np.testing.assert_almost_equal(
-            RGB_luminance(RGB, P, W),
-            Y)
+        np.testing.assert_almost_equal(RGB_luminance(RGB, P, W), Y)
 
         RGB = np.reshape(RGB, (2, 3, 3))
         Y = np.reshape(Y, (2, 3))
-        np.testing.assert_almost_equal(
-            RGB_luminance(RGB, P, W),
-            Y)
+        np.testing.assert_almost_equal(RGB_luminance(RGB, P, W), Y)
 
     @ignore_numpy_errors
     def test_nan_RGB_luminance(self):
