@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 ITU-R BT.1886
 =============
@@ -37,11 +36,10 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['oetf_BT1886',
-           'eotf_BT1886']
+__all__ = ['oetf_BT1886', 'eotf_BT1886']
 
 
-def oetf_BT1886(L, L_B=64, L_W=940):
+def oetf_BT1886(L, L_B=0, L_W=1):
     """
     Defines *Recommendation ITU-R BT.1886* opto-electrical transfer function
     (OETF / OECF).
@@ -69,7 +67,7 @@ def oetf_BT1886(L, L_B=64, L_W=940):
 
     Examples
     --------
-    >>> oetf_BT1886(277.98159179331145)  # doctest: +ELLIPSIS
+    >>> oetf_BT1886(0.11699185725296059)  # doctest: +ELLIPSIS
     0.4090077...
     """
 
@@ -92,7 +90,7 @@ def oetf_BT1886(L, L_B=64, L_W=940):
     return V
 
 
-def eotf_BT1886(V, L_B=64, L_W=940):
+def eotf_BT1886(V, L_B=0, L_W=1):
     """
     Defines *Recommendation ITU-R BT.1886* electro-optical transfer function
     (EOTF / EOCF).
@@ -118,7 +116,7 @@ def eotf_BT1886(V, L_B=64, L_W=940):
     Examples
     --------
     >>> eotf_BT1886(0.409007728864150)  # doctest: +ELLIPSIS
-    277.9815917...
+    0.1169918...
     """
 
     V = np.asarray(V)
