@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Defines unit tests for :mod:`colour.models.rgb.transfer_functions.aces`
 module.
@@ -12,12 +11,8 @@ import numpy as np
 import unittest
 
 from colour.models.rgb.transfer_functions import (
-    log_encoding_ACESproxy,
-    log_decoding_ACESproxy,
-    log_encoding_ACEScc,
-    log_decoding_ACEScc,
-    log_encoding_ACEScct,
-    log_decoding_ACEScct)
+    log_encoding_ACESproxy, log_decoding_ACESproxy, log_encoding_ACEScc,
+    log_decoding_ACEScc, log_encoding_ACEScct, log_decoding_ACEScct)
 from colour.utilities import ignore_numpy_errors
 
 __author__ = 'Colour Developers'
@@ -27,11 +22,11 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['TestLogEncoding_ACESproxy',
-           'TestLogDecoding_ACESproxy',
-           'TestLogEncoding_ACEScc',
-           'TestLogDecoding_ACEScc',
-           'TestLogDecoding_ACEScct']
+__all__ = [
+    'TestLogEncoding_ACESproxy', 'TestLogDecoding_ACESproxy',
+    'TestLogEncoding_ACEScc', 'TestLogDecoding_ACEScc',
+    'TestLogDecoding_ACEScct'
+]
 
 
 class TestLogEncoding_ACESproxy(unittest.TestCase):
@@ -61,27 +56,19 @@ log_encoding_ACESproxy` definition n-dimensional arrays support.
 
         linear = 0.18
         log = 426
-        np.testing.assert_equal(
-            log_encoding_ACESproxy(linear),
-            log)
+        np.testing.assert_equal(log_encoding_ACESproxy(linear), log)
 
         linear = np.tile(linear, 6)
         log = np.tile(log, 6)
-        np.testing.assert_equal(
-            log_encoding_ACESproxy(linear),
-            log)
+        np.testing.assert_equal(log_encoding_ACESproxy(linear), log)
 
         linear = np.reshape(linear, (2, 3))
         log = np.reshape(log, (2, 3))
-        np.testing.assert_equal(
-            log_encoding_ACESproxy(linear),
-            log)
+        np.testing.assert_equal(log_encoding_ACESproxy(linear), log)
 
         linear = np.reshape(linear, (2, 3, 1))
         log = np.reshape(log, (2, 3, 1))
-        np.testing.assert_almost_equal(
-            log_encoding_ACESproxy(linear),
-            log)
+        np.testing.assert_almost_equal(log_encoding_ACESproxy(linear), log)
 
     @ignore_numpy_errors
     def test_nan_log_encoding_ACESproxy(self):
@@ -108,19 +95,12 @@ log_decoding_ACESproxy` definition.
         """
 
         self.assertAlmostEqual(
-            log_decoding_ACESproxy(64),
-            0.001185737191792,
-            places=7)
+            log_decoding_ACESproxy(64), 0.001185737191792, places=7)
 
         self.assertAlmostEqual(
-            log_decoding_ACESproxy(426),
-            0.179244406001978,
-            places=7)
+            log_decoding_ACESproxy(426), 0.179244406001978, places=7)
 
-        self.assertAlmostEqual(
-            log_decoding_ACESproxy(550),
-            1.0,
-            places=7)
+        self.assertAlmostEqual(log_decoding_ACESproxy(550), 1.0, places=7)
 
     def test_n_dimensional_log_decoding_ACESproxy(self):
         """
@@ -131,30 +111,22 @@ log_decoding_ACESproxy` definition n-dimensional arrays support.
         log = 426.0
         linear = 0.179244406001978
         np.testing.assert_almost_equal(
-            log_decoding_ACESproxy(log),
-            linear,
-            decimal=7)
+            log_decoding_ACESproxy(log), linear, decimal=7)
 
         log = np.tile(log, 6)
         linear = np.tile(linear, 6)
         np.testing.assert_almost_equal(
-            log_decoding_ACESproxy(log),
-            linear,
-            decimal=7)
+            log_decoding_ACESproxy(log), linear, decimal=7)
 
         log = np.reshape(log, (2, 3))
         linear = np.reshape(linear, (2, 3))
         np.testing.assert_almost_equal(
-            log_decoding_ACESproxy(log),
-            linear,
-            decimal=7)
+            log_decoding_ACESproxy(log), linear, decimal=7)
 
         log = np.reshape(log, (2, 3, 1))
         linear = np.reshape(linear, (2, 3, 1))
         np.testing.assert_almost_equal(
-            log_decoding_ACESproxy(log),
-            linear,
-            decimal=7)
+            log_decoding_ACESproxy(log), linear, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_log_decoding_ACESproxy(self):
@@ -180,19 +152,13 @@ log_encoding_ACEScc` definition.
         """
 
         self.assertAlmostEqual(
-            log_encoding_ACEScc(0.0),
-            -0.358447488584475,
-            places=7)
+            log_encoding_ACEScc(0.0), -0.358447488584475, places=7)
 
         self.assertAlmostEqual(
-            log_encoding_ACEScc(0.18),
-            0.413588402492442,
-            places=7)
+            log_encoding_ACEScc(0.18), 0.413588402492442, places=7)
 
         self.assertAlmostEqual(
-            log_encoding_ACEScc(1.0),
-            0.554794520547945,
-            places=7)
+            log_encoding_ACEScc(1.0), 0.554794520547945, places=7)
 
     def test_n_dimensional_log_encoding_ACEScc(self):
         """
@@ -203,30 +169,22 @@ log_encoding_ACEScc` definition n-dimensional arrays support.
         linear = 0.18
         log = 0.413588402492442
         np.testing.assert_almost_equal(
-            log_encoding_ACEScc(linear),
-            log,
-            decimal=7)
+            log_encoding_ACEScc(linear), log, decimal=7)
 
         linear = np.tile(linear, 6)
         log = np.tile(log, 6)
         np.testing.assert_almost_equal(
-            log_encoding_ACEScc(linear),
-            log,
-            decimal=7)
+            log_encoding_ACEScc(linear), log, decimal=7)
 
         linear = np.reshape(linear, (2, 3))
         log = np.reshape(log, (2, 3))
         np.testing.assert_almost_equal(
-            log_encoding_ACEScc(linear),
-            log,
-            decimal=7)
+            log_encoding_ACEScc(linear), log, decimal=7)
 
         linear = np.reshape(linear, (2, 3, 1))
         log = np.reshape(log, (2, 3, 1))
         np.testing.assert_almost_equal(
-            log_encoding_ACEScc(linear),
-            log,
-            decimal=7)
+            log_encoding_ACEScc(linear), log, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_log_encoding_ACEScc(self):
@@ -252,19 +210,13 @@ log_decoding_ACEScc` definition.
         """
 
         self.assertAlmostEqual(
-            log_decoding_ACEScc(-0.358447488584475),
-            0.0,
-            places=7)
+            log_decoding_ACEScc(-0.358447488584475), 0.0, places=7)
 
         self.assertAlmostEqual(
-            log_decoding_ACEScc(0.413588402492442),
-            0.18,
-            places=7)
+            log_decoding_ACEScc(0.413588402492442), 0.18, places=7)
 
         self.assertAlmostEqual(
-            log_decoding_ACEScc(0.554794520547945),
-            1.0,
-            places=7)
+            log_decoding_ACEScc(0.554794520547945), 1.0, places=7)
 
     def test_n_dimensional_log_decoding_ACEScc(self):
         """
@@ -275,30 +227,22 @@ log_decoding_ACEScc` definition n-dimensional arrays support.
         log = 0.413588402492442
         linear = 0.18
         np.testing.assert_almost_equal(
-            log_decoding_ACEScc(log),
-            linear,
-            decimal=7)
+            log_decoding_ACEScc(log), linear, decimal=7)
 
         log = np.tile(log, 6)
         linear = np.tile(linear, 6)
         np.testing.assert_almost_equal(
-            log_decoding_ACEScc(log),
-            linear,
-            decimal=7)
+            log_decoding_ACEScc(log), linear, decimal=7)
 
         log = np.reshape(log, (2, 3))
         linear = np.reshape(linear, (2, 3))
         np.testing.assert_almost_equal(
-            log_decoding_ACEScc(log),
-            linear,
-            decimal=7)
+            log_decoding_ACEScc(log), linear, decimal=7)
 
         log = np.reshape(log, (2, 3, 1))
         linear = np.reshape(linear, (2, 3, 1))
         np.testing.assert_almost_equal(
-            log_decoding_ACEScc(log),
-            linear,
-            decimal=7)
+            log_decoding_ACEScc(log), linear, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_log_decoding_ACEScc(self):
@@ -324,19 +268,13 @@ log_encoding_ACEScct` definition.
         """
 
         self.assertAlmostEqual(
-            log_encoding_ACEScct(0.0),
-            0.072905534195835495,
-            places=7)
+            log_encoding_ACEScct(0.0), 0.072905534195835495, places=7)
 
         self.assertAlmostEqual(
-            log_encoding_ACEScct(0.18),
-            0.413588402492442,
-            places=7)
+            log_encoding_ACEScct(0.18), 0.413588402492442, places=7)
 
         self.assertAlmostEqual(
-            log_encoding_ACEScct(1.0),
-            0.554794520547945,
-            places=7)
+            log_encoding_ACEScct(1.0), 0.554794520547945, places=7)
 
     def test_n_dimensional_log_encoding_ACEScct(self):
         """
@@ -347,30 +285,22 @@ log_encoding_ACEScct` definition n-dimensional arrays support.
         linear = 0.18
         log = 0.413588402492442
         np.testing.assert_almost_equal(
-            log_encoding_ACEScct(linear),
-            log,
-            decimal=7)
+            log_encoding_ACEScct(linear), log, decimal=7)
 
         linear = np.tile(linear, 6)
         log = np.tile(log, 6)
         np.testing.assert_almost_equal(
-            log_encoding_ACEScct(linear),
-            log,
-            decimal=7)
+            log_encoding_ACEScct(linear), log, decimal=7)
 
         linear = np.reshape(linear, (2, 3))
         log = np.reshape(log, (2, 3))
         np.testing.assert_almost_equal(
-            log_encoding_ACEScct(linear),
-            log,
-            decimal=7)
+            log_encoding_ACEScct(linear), log, decimal=7)
 
         linear = np.reshape(linear, (2, 3, 1))
         log = np.reshape(log, (2, 3, 1))
         np.testing.assert_almost_equal(
-            log_encoding_ACEScct(linear),
-            log,
-            decimal=7)
+            log_encoding_ACEScct(linear), log, decimal=7)
 
     def test_ACEScc_equivalency_log_encoding_ACEScct(self):
         """
@@ -382,9 +312,7 @@ aces-dev/blob/v1.0.3/documents/LaTeX/S-2016-001/introduction.tex#L14)
 
         equiv = np.linspace(0.0078125, 222.86094420380761, 100)
         np.testing.assert_almost_equal(
-            log_encoding_ACEScct(equiv),
-            log_encoding_ACEScc(equiv),
-            decimal=7)
+            log_encoding_ACEScct(equiv), log_encoding_ACEScc(equiv), decimal=7)
 
     @ignore_numpy_errors
     def test_nan_log_encoding_ACEScct(self):
@@ -410,19 +338,13 @@ log_decoding_ACEScct` definition.
         """
 
         self.assertAlmostEqual(
-            log_decoding_ACEScct(0.072905534195835495),
-            0.0,
-            places=7)
+            log_decoding_ACEScct(0.072905534195835495), 0.0, places=7)
 
         self.assertAlmostEqual(
-            log_decoding_ACEScct(0.41358840249244228),
-            0.18,
-            places=7)
+            log_decoding_ACEScct(0.41358840249244228), 0.18, places=7)
 
         self.assertAlmostEqual(
-            log_decoding_ACEScct(0.554794520547945),
-            1.0,
-            places=7)
+            log_decoding_ACEScct(0.554794520547945), 1.0, places=7)
 
     def test_n_dimensional_log_decoding_ACEScct(self):
         """
@@ -433,30 +355,22 @@ log_decoding_ACEScct` definition n-dimensional arrays support.
         log = 0.413588402492442
         linear = 0.18
         np.testing.assert_almost_equal(
-            log_decoding_ACEScct(log),
-            linear,
-            decimal=7)
+            log_decoding_ACEScct(log), linear, decimal=7)
 
         log = np.tile(log, 6)
         linear = np.tile(linear, 6)
         np.testing.assert_almost_equal(
-            log_decoding_ACEScct(log),
-            linear,
-            decimal=7)
+            log_decoding_ACEScct(log), linear, decimal=7)
 
         log = np.reshape(log, (2, 3))
         linear = np.reshape(linear, (2, 3))
         np.testing.assert_almost_equal(
-            log_decoding_ACEScct(log),
-            linear,
-            decimal=7)
+            log_decoding_ACEScct(log), linear, decimal=7)
 
         log = np.reshape(log, (2, 3, 1))
         linear = np.reshape(linear, (2, 3, 1))
         np.testing.assert_almost_equal(
-            log_decoding_ACEScct(log),
-            linear,
-            decimal=7)
+            log_decoding_ACEScct(log), linear, decimal=7)
 
     def test_ACEScc_equivalency_log_decoding_ACEScct(self):
         """
@@ -468,9 +382,7 @@ aces-dev/blob/v1.0.3/documents/LaTeX/S-2016-001/introduction.tex#L14)
 
         equiv = np.linspace(0.15525114155251146, 1.0, 100)
         np.testing.assert_almost_equal(
-            log_decoding_ACEScct(equiv),
-            log_decoding_ACEScc(equiv),
-            decimal=7)
+            log_decoding_ACEScct(equiv), log_decoding_ACEScc(equiv), decimal=7)
 
     @ignore_numpy_errors
     def test_nan_log_decoding_ACEScct(self):
