@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Defines unit tests for
 :mod:`colour.models.rgb.transfer_functions.alexa_log_c` module.
@@ -11,9 +10,8 @@ from __future__ import division, unicode_literals
 import numpy as np
 import unittest
 
-from colour.models.rgb.transfer_functions import (
-    log_encoding_ALEXALogC,
-    log_decoding_ALEXALogC)
+from colour.models.rgb.transfer_functions import (log_encoding_ALEXALogC,
+                                                  log_decoding_ALEXALogC)
 from colour.utilities import ignore_numpy_errors
 
 __author__ = 'Colour Developers'
@@ -23,8 +21,7 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['TestLogEncoding_ALEXALogC',
-           'TestLogDecoding_ALEXALogC']
+__all__ = ['TestLogEncoding_ALEXALogC', 'TestLogDecoding_ALEXALogC']
 
 
 class TestLogEncoding_ALEXALogC(unittest.TestCase):
@@ -40,19 +37,13 @@ log_encoding_ALEXALogC` definition.
         """
 
         self.assertAlmostEqual(
-            log_encoding_ALEXALogC(0.0),
-            0.092809000000000,
-            places=7)
+            log_encoding_ALEXALogC(0.0), 0.092809000000000, places=7)
 
         self.assertAlmostEqual(
-            log_encoding_ALEXALogC(0.18),
-            0.391006832034084,
-            places=7)
+            log_encoding_ALEXALogC(0.18), 0.391006832034084, places=7)
 
         self.assertAlmostEqual(
-            log_encoding_ALEXALogC(1.0),
-            0.570631558120417,
-            places=7)
+            log_encoding_ALEXALogC(1.0), 0.570631558120417, places=7)
 
     def test_n_dimensional_log_encoding_ALEXALogC(self):
         """
@@ -62,31 +53,19 @@ log_encoding_ALEXALogC` definition n-dimensional arrays support.
 
         L = 0.18
         V = 0.391006832034084
-        np.testing.assert_almost_equal(
-            log_encoding_ALEXALogC(L),
-            V,
-            decimal=7)
+        np.testing.assert_almost_equal(log_encoding_ALEXALogC(L), V, decimal=7)
 
         L = np.tile(L, 6)
         V = np.tile(V, 6)
-        np.testing.assert_almost_equal(
-            log_encoding_ALEXALogC(L),
-            V,
-            decimal=7)
+        np.testing.assert_almost_equal(log_encoding_ALEXALogC(L), V, decimal=7)
 
         L = np.reshape(L, (2, 3))
         V = np.reshape(V, (2, 3))
-        np.testing.assert_almost_equal(
-            log_encoding_ALEXALogC(L),
-            V,
-            decimal=7)
+        np.testing.assert_almost_equal(log_encoding_ALEXALogC(L), V, decimal=7)
 
         L = np.reshape(L, (2, 3, 1))
         V = np.reshape(V, (2, 3, 1))
-        np.testing.assert_almost_equal(
-            log_encoding_ALEXALogC(L),
-            V,
-            decimal=7)
+        np.testing.assert_almost_equal(log_encoding_ALEXALogC(L), V, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_log_encoding_ALEXALogC(self):
@@ -111,20 +90,13 @@ log_decoding_ALEXALogC` definition unit tests methods.
 log_decoding_ALEXALogC` definition.
         """
 
-        self.assertAlmostEqual(
-            log_decoding_ALEXALogC(0.092809),
-            0.0,
-            places=7)
+        self.assertAlmostEqual(log_decoding_ALEXALogC(0.092809), 0.0, places=7)
 
         self.assertAlmostEqual(
-            log_decoding_ALEXALogC(0.391006832034084),
-            0.18,
-            places=7)
+            log_decoding_ALEXALogC(0.391006832034084), 0.18, places=7)
 
         self.assertAlmostEqual(
-            log_decoding_ALEXALogC(0.570631558120417),
-            1.0,
-            places=7)
+            log_decoding_ALEXALogC(0.570631558120417), 1.0, places=7)
 
     def test_n_dimensional_log_decoding_ALEXALogC(self):
         """
@@ -134,31 +106,19 @@ log_decoding_ALEXALogC` definition n-dimensional arrays support.
 
         V = 0.391006832034084
         L = 0.18
-        np.testing.assert_almost_equal(
-            log_decoding_ALEXALogC(V),
-            L,
-            decimal=7)
+        np.testing.assert_almost_equal(log_decoding_ALEXALogC(V), L, decimal=7)
 
         V = np.tile(V, 6)
         L = np.tile(L, 6)
-        np.testing.assert_almost_equal(
-            log_decoding_ALEXALogC(V),
-            L,
-            decimal=7)
+        np.testing.assert_almost_equal(log_decoding_ALEXALogC(V), L, decimal=7)
 
         V = np.reshape(V, (2, 3))
         L = np.reshape(L, (2, 3))
-        np.testing.assert_almost_equal(
-            log_decoding_ALEXALogC(V),
-            L,
-            decimal=7)
+        np.testing.assert_almost_equal(log_decoding_ALEXALogC(V), L, decimal=7)
 
         V = np.reshape(V, (2, 3, 1))
         L = np.reshape(L, (2, 3, 1))
-        np.testing.assert_almost_equal(
-            log_decoding_ALEXALogC(V),
-            L,
-            decimal=7)
+        np.testing.assert_almost_equal(log_decoding_ALEXALogC(V), L, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_log_decoding_ALEXALogC(self):
