@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Defines unit tests for :mod:`colour.models.rgb.transfer_functions.bt_1886`
 module.
@@ -21,8 +20,7 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['TestOetf_BT1886',
-           'TestEotf_BT1886']
+__all__ = ['TestOetf_BT1886', 'TestEotf_BT1886']
 
 
 class TestOetf_BT1886(unittest.TestCase):
@@ -37,20 +35,11 @@ class TestOetf_BT1886(unittest.TestCase):
 oetf_BT1886` definition.
         """
 
-        self.assertAlmostEqual(
-            oetf_BT1886(64.0),
-            0.0,
-            places=7)
+        self.assertAlmostEqual(oetf_BT1886(0.0), 0.0, places=7)
 
-        self.assertAlmostEqual(
-            oetf_BT1886(184.32),
-            0.268401363726554,
-            places=7)
+        self.assertAlmostEqual(oetf_BT1886(0.016317514686316), 0.18, places=7)
 
-        self.assertAlmostEqual(
-            oetf_BT1886(940),
-            1.000000000000000,
-            places=7)
+        self.assertAlmostEqual(oetf_BT1886(1.0), 1.0, places=7)
 
     def test_n_dimensional_oetf_BT1886(self):
         """
@@ -58,33 +47,21 @@ oetf_BT1886` definition.
 oetf_BT1886` definition n-dimensional arrays support.
         """
 
-        L = 184.32
-        V = 0.268401363726554
-        np.testing.assert_almost_equal(
-            oetf_BT1886(L),
-            V,
-            decimal=7)
+        L = 0.016317514686316
+        V = 0.18
+        np.testing.assert_almost_equal(oetf_BT1886(L), V, decimal=7)
 
         L = np.tile(L, 6)
         V = np.tile(V, 6)
-        np.testing.assert_almost_equal(
-            oetf_BT1886(L),
-            V,
-            decimal=7)
+        np.testing.assert_almost_equal(oetf_BT1886(L), V, decimal=7)
 
         L = np.reshape(L, (2, 3))
         V = np.reshape(V, (2, 3))
-        np.testing.assert_almost_equal(
-            oetf_BT1886(L),
-            V,
-            decimal=7)
+        np.testing.assert_almost_equal(oetf_BT1886(L), V, decimal=7)
 
         L = np.reshape(L, (2, 3, 1))
         V = np.reshape(V, (2, 3, 1))
-        np.testing.assert_almost_equal(
-            oetf_BT1886(L),
-            V,
-            decimal=7)
+        np.testing.assert_almost_equal(oetf_BT1886(L), V, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_oetf_BT1886(self):
@@ -93,8 +70,7 @@ oetf_BT1886` definition n-dimensional arrays support.
 oetf_BT1886` definition nan support.
         """
 
-        oetf_BT1886(
-            np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
+        oetf_BT1886(np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
 
 
 class TestEotf_BT1886(unittest.TestCase):
@@ -109,20 +85,11 @@ class TestEotf_BT1886(unittest.TestCase):
 eotf_BT1886` definition.
         """
 
-        self.assertAlmostEqual(
-            eotf_BT1886(0.0),
-            64.0,
-            places=7)
+        self.assertAlmostEqual(eotf_BT1886(0.0), 0.0, places=7)
 
-        self.assertAlmostEqual(
-            eotf_BT1886(0.18),
-            136.58617957,
-            places=7)
+        self.assertAlmostEqual(eotf_BT1886(0.18), 0.016317514686316, places=7)
 
-        self.assertAlmostEqual(
-            eotf_BT1886(1.0),
-            940.00000000,
-            places=7)
+        self.assertAlmostEqual(eotf_BT1886(1.0), 1.0, places=7)
 
     def test_n_dimensional_eotf_BT1886(self):
         """
@@ -131,32 +98,20 @@ eotf_BT1886` definition n-dimensional arrays support.
         """
 
         V = 0.18
-        L = 136.58617957
-        np.testing.assert_almost_equal(
-            eotf_BT1886(V),
-            L,
-            decimal=7)
+        L = 0.016317514686316
+        np.testing.assert_almost_equal(eotf_BT1886(V), L, decimal=7)
 
         V = np.tile(V, 6)
         L = np.tile(L, 6)
-        np.testing.assert_almost_equal(
-            eotf_BT1886(V),
-            L,
-            decimal=7)
+        np.testing.assert_almost_equal(eotf_BT1886(V), L, decimal=7)
 
         V = np.reshape(V, (2, 3))
         L = np.reshape(L, (2, 3))
-        np.testing.assert_almost_equal(
-            eotf_BT1886(V),
-            L,
-            decimal=7)
+        np.testing.assert_almost_equal(eotf_BT1886(V), L, decimal=7)
 
         V = np.reshape(V, (2, 3, 1))
         L = np.reshape(L, (2, 3, 1))
-        np.testing.assert_almost_equal(
-            eotf_BT1886(V),
-            L,
-            decimal=7)
+        np.testing.assert_almost_equal(eotf_BT1886(V), L, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_eotf_BT1886(self):
@@ -165,8 +120,7 @@ eotf_BT1886` definition n-dimensional arrays support.
 eotf_BT1886` definition nan support.
         """
 
-        eotf_BT1886(
-            np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
+        eotf_BT1886(np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
 
 
 if __name__ == '__main__':
