@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Defines unit tests for :mod:`colour.models.rgb.transfer_functions.\
 pivoted_log` module.
@@ -11,9 +10,8 @@ from __future__ import division, unicode_literals
 import numpy as np
 import unittest
 
-from colour.models.rgb.transfer_functions import (
-    log_encoding_PivotedLog,
-    log_decoding_PivotedLog)
+from colour.models.rgb.transfer_functions import (log_encoding_PivotedLog,
+                                                  log_decoding_PivotedLog)
 from colour.utilities import ignore_numpy_errors
 
 __author__ = 'Colour Developers'
@@ -23,8 +21,7 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['TestLogEncoding_PivotedLog',
-           'TestLogDecoding_PivotedLog']
+__all__ = ['TestLogEncoding_PivotedLog', 'TestLogDecoding_PivotedLog']
 
 
 class TestLogEncoding_PivotedLog(unittest.TestCase):
@@ -39,20 +36,13 @@ log_encoding_PivotedLog` definition unit tests methods.
 log_encoding_PivotedLog` definition.
         """
 
-        self.assertAlmostEqual(
-            log_encoding_PivotedLog(0.0),
-            -np.inf,
-            places=7)
+        self.assertAlmostEqual(log_encoding_PivotedLog(0.0), -np.inf, places=7)
 
         self.assertAlmostEqual(
-            log_encoding_PivotedLog(0.18),
-            0.434995112414467,
-            places=7)
+            log_encoding_PivotedLog(0.18), 0.434995112414467, places=7)
 
         self.assertAlmostEqual(
-            log_encoding_PivotedLog(1.0),
-            0.653390272208219,
-            places=7)
+            log_encoding_PivotedLog(1.0), 0.653390272208219, places=7)
 
     def test_n_dimensional_log_encoding_PivotedLog(self):
         """
@@ -63,30 +53,22 @@ log_encoding_PivotedLog` definition n-dimensional arrays support.
         L = 0.18
         V = 0.434995112414467
         np.testing.assert_almost_equal(
-            log_encoding_PivotedLog(L),
-            V,
-            decimal=7)
+            log_encoding_PivotedLog(L), V, decimal=7)
 
         L = np.tile(L, 6)
         V = np.tile(V, 6)
         np.testing.assert_almost_equal(
-            log_encoding_PivotedLog(L),
-            V,
-            decimal=7)
+            log_encoding_PivotedLog(L), V, decimal=7)
 
         L = np.reshape(L, (2, 3))
         V = np.reshape(V, (2, 3))
         np.testing.assert_almost_equal(
-            log_encoding_PivotedLog(L),
-            V,
-            decimal=7)
+            log_encoding_PivotedLog(L), V, decimal=7)
 
         L = np.reshape(L, (2, 3, 1))
         V = np.reshape(V, (2, 3, 1))
         np.testing.assert_almost_equal(
-            log_encoding_PivotedLog(L),
-            V,
-            decimal=7)
+            log_encoding_PivotedLog(L), V, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_log_encoding_PivotedLog(self):
@@ -111,20 +93,13 @@ log_decoding_PivotedLog` definition unit tests methods.
 log_decoding_PivotedLog` definition.
         """
 
-        self.assertAlmostEqual(
-            log_decoding_PivotedLog(-np.inf),
-            0.0,
-            places=7)
+        self.assertAlmostEqual(log_decoding_PivotedLog(-np.inf), 0.0, places=7)
 
         self.assertAlmostEqual(
-            log_decoding_PivotedLog(0.434995112414467),
-            0.18,
-            places=7)
+            log_decoding_PivotedLog(0.434995112414467), 0.18, places=7)
 
         self.assertAlmostEqual(
-            log_decoding_PivotedLog(0.653390272208219),
-            1.0,
-            places=7)
+            log_decoding_PivotedLog(0.653390272208219), 1.0, places=7)
 
     def test_n_dimensional_log_decoding_PivotedLog(self):
         """
@@ -135,30 +110,22 @@ log_decoding_PivotedLog` definition n-dimensional arrays support.
         V = 0.434995112414467
         L = 0.18
         np.testing.assert_almost_equal(
-            log_decoding_PivotedLog(V),
-            L,
-            decimal=7)
+            log_decoding_PivotedLog(V), L, decimal=7)
 
         V = np.tile(V, 6)
         L = np.tile(L, 6)
         np.testing.assert_almost_equal(
-            log_decoding_PivotedLog(V),
-            L,
-            decimal=7)
+            log_decoding_PivotedLog(V), L, decimal=7)
 
         V = np.reshape(V, (2, 3))
         L = np.reshape(L, (2, 3))
         np.testing.assert_almost_equal(
-            log_decoding_PivotedLog(V),
-            L,
-            decimal=7)
+            log_decoding_PivotedLog(V), L, decimal=7)
 
         V = np.reshape(V, (2, 3, 1))
         L = np.reshape(L, (2, 3, 1))
         np.testing.assert_almost_equal(
-            log_decoding_PivotedLog(V),
-            L,
-            decimal=7)
+            log_decoding_PivotedLog(V), L, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_log_decoding_PivotedLog(self):
