@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Defines unit tests for :mod:`colour.models.rgb.transfer_functions.red_log`
 module.
@@ -12,14 +11,9 @@ import numpy as np
 import unittest
 
 from colour.models.rgb.transfer_functions import (
-    log_encoding_REDLog,
-    log_decoding_REDLog,
-    log_encoding_REDLogFilm,
-    log_decoding_REDLogFilm,
-    log_encoding_Log3G10,
-    log_decoding_Log3G10,
-    log_encoding_Log3G12,
-    log_decoding_Log3G12)
+    log_encoding_REDLog, log_decoding_REDLog, log_encoding_REDLogFilm,
+    log_decoding_REDLogFilm, log_encoding_Log3G10, log_decoding_Log3G10,
+    log_encoding_Log3G12, log_decoding_Log3G12)
 from colour.utilities import ignore_numpy_errors
 
 __author__ = 'Colour Developers'
@@ -29,14 +23,12 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Development'
 
-__all__ = ['TestLogEncoding_REDLog',
-           'TestLogDecoding_REDLog',
-           'TestLogDecoding_REDLogFilm',
-           'TestLogDecoding_REDLogFilm',
-           'TestLogDecoding_Log3G10',
-           'TestLogDecoding_Log3G10',
-           'TestLogDecoding_Log3G12',
-           'TestLogDecoding_Log3G12']
+__all__ = [
+    'TestLogEncoding_REDLog', 'TestLogDecoding_REDLog',
+    'TestLogDecoding_REDLogFilm', 'TestLogDecoding_REDLogFilm',
+    'TestLogDecoding_Log3G10', 'TestLogDecoding_Log3G10',
+    'TestLogDecoding_Log3G12', 'TestLogDecoding_Log3G12'
+]
 
 
 class TestLogEncoding_REDLog(unittest.TestCase):
@@ -51,20 +43,12 @@ log_encoding_REDLog` definition unit tests methods.
 log_encoding_REDLog` definition.
         """
 
-        self.assertAlmostEqual(
-            log_encoding_REDLog(0.0),
-            0.0,
-            places=7)
+        self.assertAlmostEqual(log_encoding_REDLog(0.0), 0.0, places=7)
 
         self.assertAlmostEqual(
-            log_encoding_REDLog(0.18),
-            0.637621845988175,
-            places=7)
+            log_encoding_REDLog(0.18), 0.637621845988175, places=7)
 
-        self.assertAlmostEqual(
-            log_encoding_REDLog(1.0),
-            1.0,
-            places=7)
+        self.assertAlmostEqual(log_encoding_REDLog(1.0), 1.0, places=7)
 
     def test_n_dimensional_log_encoding_REDLog(self):
         """
@@ -74,31 +58,19 @@ log_encoding_REDLog` definition n-dimensional arrays support.
 
         L = 0.18
         V = 0.637621845988175
-        np.testing.assert_almost_equal(
-            log_encoding_REDLog(L),
-            V,
-            decimal=7)
+        np.testing.assert_almost_equal(log_encoding_REDLog(L), V, decimal=7)
 
         L = np.tile(L, 6)
         V = np.tile(V, 6)
-        np.testing.assert_almost_equal(
-            log_encoding_REDLog(L),
-            V,
-            decimal=7)
+        np.testing.assert_almost_equal(log_encoding_REDLog(L), V, decimal=7)
 
         L = np.reshape(L, (2, 3))
         V = np.reshape(V, (2, 3))
-        np.testing.assert_almost_equal(
-            log_encoding_REDLog(L),
-            V,
-            decimal=7)
+        np.testing.assert_almost_equal(log_encoding_REDLog(L), V, decimal=7)
 
         L = np.reshape(L, (2, 3, 1))
         V = np.reshape(V, (2, 3, 1))
-        np.testing.assert_almost_equal(
-            log_encoding_REDLog(L),
-            V,
-            decimal=7)
+        np.testing.assert_almost_equal(log_encoding_REDLog(L), V, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_log_encoding_REDLog(self):
@@ -123,20 +95,12 @@ log_decoding_REDLog` definition unit tests methods.
 log_decoding_REDLog` definition.
         """
 
-        self.assertAlmostEqual(
-            log_decoding_REDLog(0.0),
-            0.0,
-            places=7)
+        self.assertAlmostEqual(log_decoding_REDLog(0.0), 0.0, places=7)
 
         self.assertAlmostEqual(
-            log_decoding_REDLog(0.637621845988175),
-            0.18,
-            places=7)
+            log_decoding_REDLog(0.637621845988175), 0.18, places=7)
 
-        self.assertAlmostEqual(
-            log_decoding_REDLog(1.0),
-            1.0,
-            places=7)
+        self.assertAlmostEqual(log_decoding_REDLog(1.0), 1.0, places=7)
 
     def test_n_dimensional_log_decoding_REDLog(self):
         """
@@ -146,31 +110,19 @@ log_decoding_REDLog` definition n-dimensional arrays support.
 
         V = 0.637621845988175
         L = 0.18
-        np.testing.assert_almost_equal(
-            log_decoding_REDLog(V),
-            L,
-            decimal=7)
+        np.testing.assert_almost_equal(log_decoding_REDLog(V), L, decimal=7)
 
         V = np.tile(V, 6)
         L = np.tile(L, 6)
-        np.testing.assert_almost_equal(
-            log_decoding_REDLog(V),
-            L,
-            decimal=7)
+        np.testing.assert_almost_equal(log_decoding_REDLog(V), L, decimal=7)
 
         V = np.reshape(V, (2, 3))
         L = np.reshape(L, (2, 3))
-        np.testing.assert_almost_equal(
-            log_decoding_REDLog(V),
-            L,
-            decimal=7)
+        np.testing.assert_almost_equal(log_decoding_REDLog(V), L, decimal=7)
 
         V = np.reshape(V, (2, 3, 1))
         L = np.reshape(L, (2, 3, 1))
-        np.testing.assert_almost_equal(
-            log_decoding_REDLog(V),
-            L,
-            decimal=7)
+        np.testing.assert_almost_equal(log_decoding_REDLog(V), L, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_log_decoding_REDLog(self):
@@ -196,19 +148,13 @@ log_encoding_REDLogFilm` definition.
         """
 
         self.assertAlmostEqual(
-            log_encoding_REDLogFilm(0.0),
-            0.092864125122190,
-            places=7)
+            log_encoding_REDLogFilm(0.0), 0.092864125122190, places=7)
 
         self.assertAlmostEqual(
-            log_encoding_REDLogFilm(0.18),
-            0.457319613085418,
-            places=7)
+            log_encoding_REDLogFilm(0.18), 0.457319613085418, places=7)
 
         self.assertAlmostEqual(
-            log_encoding_REDLogFilm(1.0),
-            0.669599217986315,
-            places=7)
+            log_encoding_REDLogFilm(1.0), 0.669599217986315, places=7)
 
     def test_n_dimensional_log_encoding_REDLogFilm(self):
         """
@@ -219,30 +165,22 @@ log_encoding_REDLogFilm` definition n-dimensional arrays support.
         L = 0.18
         V = 0.457319613085418
         np.testing.assert_almost_equal(
-            log_encoding_REDLogFilm(L),
-            V,
-            decimal=7)
+            log_encoding_REDLogFilm(L), V, decimal=7)
 
         L = np.tile(L, 6)
         V = np.tile(V, 6)
         np.testing.assert_almost_equal(
-            log_encoding_REDLogFilm(L),
-            V,
-            decimal=7)
+            log_encoding_REDLogFilm(L), V, decimal=7)
 
         L = np.reshape(L, (2, 3))
         V = np.reshape(V, (2, 3))
         np.testing.assert_almost_equal(
-            log_encoding_REDLogFilm(L),
-            V,
-            decimal=7)
+            log_encoding_REDLogFilm(L), V, decimal=7)
 
         L = np.reshape(L, (2, 3, 1))
         V = np.reshape(V, (2, 3, 1))
         np.testing.assert_almost_equal(
-            log_encoding_REDLogFilm(L),
-            V,
-            decimal=7)
+            log_encoding_REDLogFilm(L), V, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_log_encoding_REDLogFilm(self):
@@ -268,19 +206,13 @@ log_decoding_REDLogFilm` definition.
         """
 
         self.assertAlmostEqual(
-            log_decoding_REDLogFilm(0.092864125122190),
-            0.0,
-            places=7)
+            log_decoding_REDLogFilm(0.092864125122190), 0.0, places=7)
 
         self.assertAlmostEqual(
-            log_decoding_REDLogFilm(0.457319613085418),
-            0.18,
-            places=7)
+            log_decoding_REDLogFilm(0.457319613085418), 0.18, places=7)
 
         self.assertAlmostEqual(
-            log_decoding_REDLogFilm(0.669599217986315),
-            1.0,
-            places=7)
+            log_decoding_REDLogFilm(0.669599217986315), 1.0, places=7)
 
     def test_n_dimensional_log_decoding_REDLogFilm(self):
         """
@@ -291,30 +223,22 @@ log_decoding_REDLogFilm` definition n-dimensional arrays support.
         V = 0.457319613085418
         L = 0.18
         np.testing.assert_almost_equal(
-            log_decoding_REDLogFilm(V),
-            L,
-            decimal=7)
+            log_decoding_REDLogFilm(V), L, decimal=7)
 
         V = np.tile(V, 6)
         L = np.tile(L, 6)
         np.testing.assert_almost_equal(
-            log_decoding_REDLogFilm(V),
-            L,
-            decimal=7)
+            log_decoding_REDLogFilm(V), L, decimal=7)
 
         V = np.reshape(V, (2, 3))
         L = np.reshape(L, (2, 3))
         np.testing.assert_almost_equal(
-            log_decoding_REDLogFilm(V),
-            L,
-            decimal=7)
+            log_decoding_REDLogFilm(V), L, decimal=7)
 
         V = np.reshape(V, (2, 3, 1))
         L = np.reshape(L, (2, 3, 1))
         np.testing.assert_almost_equal(
-            log_decoding_REDLogFilm(V),
-            L,
-            decimal=7)
+            log_decoding_REDLogFilm(V), L, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_log_decoding_REDLogFilm(self):
@@ -345,9 +269,7 @@ log_encoding_Log3G10` definition.
             places=7)
 
         self.assertAlmostEqual(
-            log_encoding_Log3G10(0.0, legacy_curve=True),
-            0.0,
-            places=7)
+            log_encoding_Log3G10(0.0, legacy_curve=True), 0.0, places=7)
 
         self.assertAlmostEqual(
             log_encoding_Log3G10(0.18, legacy_curve=True),
@@ -379,49 +301,33 @@ log_encoding_Log3G10` definition n-dimensional arrays support.
         V1 = 0.333333644207707
         V2 = 0.333332912025992
         np.testing.assert_almost_equal(
-            log_encoding_Log3G10(L, legacy_curve=True),
-            V1,
-            decimal=7)
+            log_encoding_Log3G10(L, legacy_curve=True), V1, decimal=7)
         np.testing.assert_almost_equal(
-            log_encoding_Log3G10(L, legacy_curve=False),
-            V2,
-            decimal=7)
+            log_encoding_Log3G10(L, legacy_curve=False), V2, decimal=7)
 
         L = np.tile(L, 6)
         V1 = np.tile(V1, 6)
         V2 = np.tile(V2, 6)
         np.testing.assert_almost_equal(
-            log_encoding_Log3G10(L, legacy_curve=True),
-            V1,
-            decimal=7)
+            log_encoding_Log3G10(L, legacy_curve=True), V1, decimal=7)
         np.testing.assert_almost_equal(
-            log_encoding_Log3G10(L, legacy_curve=False),
-            V2,
-            decimal=7)
+            log_encoding_Log3G10(L, legacy_curve=False), V2, decimal=7)
 
         L = np.reshape(L, (2, 3))
         V1 = np.reshape(V1, (2, 3))
         V2 = np.reshape(V2, (2, 3))
         np.testing.assert_almost_equal(
-            log_encoding_Log3G10(L, legacy_curve=True),
-            V1,
-            decimal=7)
+            log_encoding_Log3G10(L, legacy_curve=True), V1, decimal=7)
         np.testing.assert_almost_equal(
-            log_encoding_Log3G10(L, legacy_curve=False),
-            V2,
-            decimal=7)
+            log_encoding_Log3G10(L, legacy_curve=False), V2, decimal=7)
 
         L = np.reshape(L, (2, 3, 1))
         V1 = np.reshape(V1, (2, 3, 1))
         V2 = np.reshape(V2, (2, 3, 1))
         np.testing.assert_almost_equal(
-            log_encoding_Log3G10(L, legacy_curve=True),
-            V1,
-            decimal=7)
+            log_encoding_Log3G10(L, legacy_curve=True), V1, decimal=7)
         np.testing.assert_almost_equal(
-            log_encoding_Log3G10(L, legacy_curve=False),
-            V2,
-            decimal=7)
+            log_encoding_Log3G10(L, legacy_curve=False), V2, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_log_encoding_Log3G10(self):
@@ -456,9 +362,7 @@ log_decoding_Log3G10` definition.
             places=7)
 
         self.assertAlmostEqual(
-            log_decoding_Log3G10(0.0, legacy_curve=True),
-            0.0,
-            places=7)
+            log_decoding_Log3G10(0.0, legacy_curve=True), 0.0, places=7)
 
         self.assertAlmostEqual(
             log_decoding_Log3G10(0.333333644207707, legacy_curve=True),
@@ -490,49 +394,33 @@ log_decoding_Log3G10` definition n-dimensional arrays support.
         V2 = 0.333332912025992
         L = 0.18
         np.testing.assert_almost_equal(
-            log_decoding_Log3G10(V1, legacy_curve=True),
-            L,
-            decimal=7)
+            log_decoding_Log3G10(V1, legacy_curve=True), L, decimal=7)
         np.testing.assert_almost_equal(
-            log_decoding_Log3G10(V2, legacy_curve=False),
-            L,
-            decimal=7)
+            log_decoding_Log3G10(V2, legacy_curve=False), L, decimal=7)
 
         V1 = np.tile(V1, 6)
         V2 = np.tile(V2, 6)
         L = np.tile(L, 6)
         np.testing.assert_almost_equal(
-            log_decoding_Log3G10(V1, legacy_curve=True),
-            L,
-            decimal=7)
+            log_decoding_Log3G10(V1, legacy_curve=True), L, decimal=7)
         np.testing.assert_almost_equal(
-            log_decoding_Log3G10(V2, legacy_curve=False),
-            L,
-            decimal=7)
+            log_decoding_Log3G10(V2, legacy_curve=False), L, decimal=7)
 
         V1 = np.reshape(V1, (2, 3))
         V2 = np.reshape(V2, (2, 3))
         L = np.reshape(L, (2, 3))
         np.testing.assert_almost_equal(
-            log_decoding_Log3G10(V1, legacy_curve=True),
-            L,
-            decimal=7)
+            log_decoding_Log3G10(V1, legacy_curve=True), L, decimal=7)
         np.testing.assert_almost_equal(
-            log_decoding_Log3G10(V2, legacy_curve=False),
-            L,
-            decimal=7)
+            log_decoding_Log3G10(V2, legacy_curve=False), L, decimal=7)
 
         V1 = np.reshape(V1, (2, 3, 1))
         V2 = np.reshape(V2, (2, 3, 1))
         L = np.reshape(L, (2, 3, 1))
         np.testing.assert_almost_equal(
-            log_decoding_Log3G10(V1, legacy_curve=True),
-            L,
-            decimal=7)
+            log_decoding_Log3G10(V1, legacy_curve=True), L, decimal=7)
         np.testing.assert_almost_equal(
-            log_decoding_Log3G10(V2, legacy_curve=False),
-            L,
-            decimal=7)
+            log_decoding_Log3G10(V2, legacy_curve=False), L, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_log_decoding_Log3G10(self):
@@ -561,25 +449,16 @@ log_encoding_Log3G12` definition unit tests methods.
 log_encoding_Log3G12` definition.
         """
 
-        self.assertAlmostEqual(
-            log_encoding_Log3G12(0.0),
-            0.0,
-            places=7)
+        self.assertAlmostEqual(log_encoding_Log3G12(0.0), 0.0, places=7)
 
         self.assertAlmostEqual(
-            log_encoding_Log3G12(0.18),
-            0.333332662015923,
-            places=7)
+            log_encoding_Log3G12(0.18), 0.333332662015923, places=7)
 
         self.assertAlmostEqual(
-            log_encoding_Log3G12(1.0),
-            0.469991923234319,
-            places=7)
+            log_encoding_Log3G12(1.0), 0.469991923234319, places=7)
 
         self.assertAlmostEqual(
-            log_encoding_Log3G12(0.18 * 2 ** 12),
-            0.999997986792394,
-            places=7)
+            log_encoding_Log3G12(0.18 * 2 ** 12), 0.999997986792394, places=7)
 
     def test_n_dimensional_log_encoding_Log3G12(self):
         """
@@ -589,31 +468,19 @@ log_encoding_Log3G12` definition n-dimensional arrays support.
 
         L = 0.18
         V = 0.333332662015923
-        np.testing.assert_almost_equal(
-            log_encoding_Log3G12(L),
-            V,
-            decimal=7)
+        np.testing.assert_almost_equal(log_encoding_Log3G12(L), V, decimal=7)
 
         L = np.tile(L, 6)
         V = np.tile(V, 6)
-        np.testing.assert_almost_equal(
-            log_encoding_Log3G12(L),
-            V,
-            decimal=7)
+        np.testing.assert_almost_equal(log_encoding_Log3G12(L), V, decimal=7)
 
         L = np.reshape(L, (2, 3))
         V = np.reshape(V, (2, 3))
-        np.testing.assert_almost_equal(
-            log_encoding_Log3G12(L),
-            V,
-            decimal=7)
+        np.testing.assert_almost_equal(log_encoding_Log3G12(L), V, decimal=7)
 
         L = np.reshape(L, (2, 3, 1))
         V = np.reshape(V, (2, 3, 1))
-        np.testing.assert_almost_equal(
-            log_encoding_Log3G12(L),
-            V,
-            decimal=7)
+        np.testing.assert_almost_equal(log_encoding_Log3G12(L), V, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_log_encoding_Log3G12(self):
@@ -638,25 +505,16 @@ log_decoding_Log3G12` definition unit tests methods.
 log_decoding_Log3G12` definition.
         """
 
-        self.assertAlmostEqual(
-            log_decoding_Log3G12(0.0),
-            0.0,
-            places=7)
+        self.assertAlmostEqual(log_decoding_Log3G12(0.0), 0.0, places=7)
 
         self.assertAlmostEqual(
-            log_decoding_Log3G12(0.333332662015923),
-            0.18,
-            places=7)
+            log_decoding_Log3G12(0.333332662015923), 0.18, places=7)
 
         self.assertAlmostEqual(
-            log_decoding_Log3G12(0.469991923234319),
-            1.0,
-            places=7)
+            log_decoding_Log3G12(0.469991923234319), 1.0, places=7)
 
         self.assertAlmostEqual(
-            log_decoding_Log3G12(1.0),
-            737.29848406719,
-            places=7)
+            log_decoding_Log3G12(1.0), 737.29848406719, places=7)
 
     def test_n_dimensional_log_decoding_Log3G12(self):
         """
@@ -666,31 +524,19 @@ log_decoding_Log3G12` definition n-dimensional arrays support.
 
         V = 0.333332662015923
         L = 0.18
-        np.testing.assert_almost_equal(
-            log_decoding_Log3G12(V),
-            L,
-            decimal=7)
+        np.testing.assert_almost_equal(log_decoding_Log3G12(V), L, decimal=7)
 
         V = np.tile(V, 6)
         L = np.tile(L, 6)
-        np.testing.assert_almost_equal(
-            log_decoding_Log3G12(V),
-            L,
-            decimal=7)
+        np.testing.assert_almost_equal(log_decoding_Log3G12(V), L, decimal=7)
 
         V = np.reshape(V, (2, 3))
         L = np.reshape(L, (2, 3))
-        np.testing.assert_almost_equal(
-            log_decoding_Log3G12(V),
-            L,
-            decimal=7)
+        np.testing.assert_almost_equal(log_decoding_Log3G12(V), L, decimal=7)
 
         V = np.reshape(V, (2, 3, 1))
         L = np.reshape(L, (2, 3, 1))
-        np.testing.assert_almost_equal(
-            log_decoding_Log3G12(V),
-            L,
-            decimal=7)
+        np.testing.assert_almost_equal(log_decoding_Log3G12(V), L, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_log_decoding_Log3G12(self):
