@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Defines unit tests for :mod:`colour.models.rgb.transfer_functions.sRGB`
 module.
@@ -21,8 +20,7 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['TestOetf_sRGB',
-           'TestEotf_sRGB']
+__all__ = ['TestOetf_sRGB', 'TestEotf_sRGB']
 
 
 class TestOetf_sRGB(unittest.TestCase):
@@ -37,20 +35,11 @@ class TestOetf_sRGB(unittest.TestCase):
 oetf_sRGB` definition.
         """
 
-        self.assertAlmostEqual(
-            oetf_sRGB(0.0),
-            0.0,
-            places=7)
+        self.assertAlmostEqual(oetf_sRGB(0.0), 0.0, places=7)
 
-        self.assertAlmostEqual(
-            oetf_sRGB(0.18),
-            0.461356129500442,
-            places=7)
+        self.assertAlmostEqual(oetf_sRGB(0.18), 0.461356129500442, places=7)
 
-        self.assertAlmostEqual(
-            oetf_sRGB(1.0),
-            1.0,
-            places=7)
+        self.assertAlmostEqual(oetf_sRGB(1.0), 1.0, places=7)
 
     def test_n_dimensional_oetf_sRGB(self):
         """
@@ -60,31 +49,19 @@ oetf_sRGB` definition n-dimensional arrays support.
 
         L = 0.18
         V = 0.461356129500442
-        np.testing.assert_almost_equal(
-            oetf_sRGB(L),
-            V,
-            decimal=7)
+        np.testing.assert_almost_equal(oetf_sRGB(L), V, decimal=7)
 
         L = np.tile(L, 6)
         V = np.tile(V, 6)
-        np.testing.assert_almost_equal(
-            oetf_sRGB(L),
-            V,
-            decimal=7)
+        np.testing.assert_almost_equal(oetf_sRGB(L), V, decimal=7)
 
         L = np.reshape(L, (2, 3))
         V = np.reshape(V, (2, 3))
-        np.testing.assert_almost_equal(
-            oetf_sRGB(L),
-            V,
-            decimal=7)
+        np.testing.assert_almost_equal(oetf_sRGB(L), V, decimal=7)
 
         L = np.reshape(L, (2, 3, 1))
         V = np.reshape(V, (2, 3, 1))
-        np.testing.assert_almost_equal(
-            oetf_sRGB(L),
-            V,
-            decimal=7)
+        np.testing.assert_almost_equal(oetf_sRGB(L), V, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_oetf_sRGB(self):
@@ -93,8 +70,7 @@ oetf_sRGB` definition n-dimensional arrays support.
 oetf_sRGB` definition nan support.
         """
 
-        oetf_sRGB(
-            np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
+        oetf_sRGB(np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
 
 
 class TestEotf_sRGB(unittest.TestCase):
@@ -109,20 +85,11 @@ class TestEotf_sRGB(unittest.TestCase):
 eotf_sRGB` definition.
         """
 
-        self.assertAlmostEqual(
-            eotf_sRGB(0.0),
-            0.0,
-            places=7)
+        self.assertAlmostEqual(eotf_sRGB(0.0), 0.0, places=7)
 
-        self.assertAlmostEqual(
-            eotf_sRGB(0.461356129500442),
-            0.18,
-            places=7)
+        self.assertAlmostEqual(eotf_sRGB(0.461356129500442), 0.18, places=7)
 
-        self.assertAlmostEqual(
-            eotf_sRGB(1.0),
-            1.0,
-            places=7)
+        self.assertAlmostEqual(eotf_sRGB(1.0), 1.0, places=7)
 
     def test_n_dimensional_eotf_sRGB(self):
         """
@@ -132,31 +99,19 @@ eotf_sRGB` definition n-dimensional arrays support.
 
         V = 0.461356129500442
         L = 0.18
-        np.testing.assert_almost_equal(
-            eotf_sRGB(V),
-            L,
-            decimal=7)
+        np.testing.assert_almost_equal(eotf_sRGB(V), L, decimal=7)
 
         V = np.tile(V, 6)
         L = np.tile(L, 6)
-        np.testing.assert_almost_equal(
-            eotf_sRGB(V),
-            L,
-            decimal=7)
+        np.testing.assert_almost_equal(eotf_sRGB(V), L, decimal=7)
 
         V = np.reshape(V, (2, 3))
         L = np.reshape(L, (2, 3))
-        np.testing.assert_almost_equal(
-            eotf_sRGB(V),
-            L,
-            decimal=7)
+        np.testing.assert_almost_equal(eotf_sRGB(V), L, decimal=7)
 
         V = np.reshape(V, (2, 3, 1))
         L = np.reshape(L, (2, 3, 1))
-        np.testing.assert_almost_equal(
-            eotf_sRGB(V),
-            L,
-            decimal=7)
+        np.testing.assert_almost_equal(eotf_sRGB(V), L, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_eotf_sRGB(self):
@@ -165,8 +120,7 @@ eotf_sRGB` definition n-dimensional arrays support.
 eotf_sRGB` definition nan support.
         """
 
-        eotf_sRGB(
-            np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
+        eotf_sRGB(np.array([-1.0, 0.0, 1.0, -np.inf, np.inf, np.nan]))
 
 
 if __name__ == '__main__':
