@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Viper Log Encodings
 ===================
@@ -34,8 +33,7 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['log_encoding_ViperLog',
-           'log_decoding_ViperLog']
+__all__ = ['log_encoding_ViperLog', 'log_decoding_ViperLog']
 
 
 def log_encoding_ViperLog(x):
