@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Defines unit tests for :mod:`colour.models.cie_ucs` module.
 """
@@ -21,10 +20,9 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['TestXYZ_to_UCS',
-           'TestUCS_to_XYZ',
-           'TestUCS_to_uv',
-           'TestUCS_uv_to_xy']
+__all__ = [
+    'TestXYZ_to_UCS', 'TestUCS_to_XYZ', 'TestUCS_to_uv', 'TestUCS_uv_to_xy'
+]
 
 
 class TestXYZ_to_UCS(unittest.TestCase):
@@ -61,24 +59,15 @@ class TestXYZ_to_UCS(unittest.TestCase):
 
         XYZ = np.array([0.07049534, 0.10080000, 0.09558313])
         UCS = np.array([0.04699689, 0.10080000, 0.16374390])
-        np.testing.assert_almost_equal(
-            XYZ_to_UCS(XYZ),
-            UCS,
-            decimal=7)
+        np.testing.assert_almost_equal(XYZ_to_UCS(XYZ), UCS, decimal=7)
 
         UCS = np.tile(UCS, (6, 1))
         XYZ = np.tile(XYZ, (6, 1))
-        np.testing.assert_almost_equal(
-            XYZ_to_UCS(XYZ),
-            UCS,
-            decimal=7)
+        np.testing.assert_almost_equal(XYZ_to_UCS(XYZ), UCS, decimal=7)
 
         UCS = np.reshape(UCS, (2, 3, 3))
         XYZ = np.reshape(XYZ, (2, 3, 3))
-        np.testing.assert_almost_equal(
-            XYZ_to_UCS(XYZ),
-            UCS,
-            decimal=7)
+        np.testing.assert_almost_equal(XYZ_to_UCS(XYZ), UCS, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_XYZ_to_UCS(self):
@@ -127,24 +116,15 @@ class TestUCS_to_XYZ(unittest.TestCase):
 
         UCS = np.array([0.04699689, 0.10080000, 0.16374390])
         XYZ = np.array([0.07049534, 0.10080000, 0.09558313])
-        np.testing.assert_almost_equal(
-            UCS_to_XYZ(UCS),
-            XYZ,
-            decimal=7)
+        np.testing.assert_almost_equal(UCS_to_XYZ(UCS), XYZ, decimal=7)
 
         UCS = np.tile(UCS, (6, 1))
         XYZ = np.tile(XYZ, (6, 1))
-        np.testing.assert_almost_equal(
-            UCS_to_XYZ(UCS),
-            XYZ,
-            decimal=7)
+        np.testing.assert_almost_equal(UCS_to_XYZ(UCS), XYZ, decimal=7)
 
         UCS = np.reshape(UCS, (2, 3, 3))
         XYZ = np.reshape(XYZ, (2, 3, 3))
-        np.testing.assert_almost_equal(
-            UCS_to_XYZ(UCS),
-            XYZ,
-            decimal=7)
+        np.testing.assert_almost_equal(UCS_to_XYZ(UCS), XYZ, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_UCS_to_XYZ(self):
@@ -193,24 +173,15 @@ class TestUCS_to_uv(unittest.TestCase):
 
         UCS = np.array([0.04699689, 0.10080000, 0.16374390])
         uv = np.array([0.15085309, 0.32355314])
-        np.testing.assert_almost_equal(
-            UCS_to_uv(UCS),
-            uv,
-            decimal=7)
+        np.testing.assert_almost_equal(UCS_to_uv(UCS), uv, decimal=7)
 
         UCS = np.tile(UCS, (6, 1))
         uv = np.tile(uv, (6, 1))
-        np.testing.assert_almost_equal(
-            UCS_to_uv(UCS),
-            uv,
-            decimal=7)
+        np.testing.assert_almost_equal(UCS_to_uv(UCS), uv, decimal=7)
 
         UCS = np.reshape(UCS, (2, 3, 3))
         uv = np.reshape(uv, (2, 3, 2))
-        np.testing.assert_almost_equal(
-            UCS_to_uv(UCS),
-            uv,
-            decimal=7)
+        np.testing.assert_almost_equal(UCS_to_uv(UCS), uv, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_UCS_to_uv(self):
@@ -259,24 +230,15 @@ class TestUCS_uv_to_xy(unittest.TestCase):
 
         uv = np.array([0.15085309, 0.32355314])
         xy = np.array([0.26414771, 0.37770001])
-        np.testing.assert_almost_equal(
-            UCS_uv_to_xy(uv),
-            xy,
-            decimal=7)
+        np.testing.assert_almost_equal(UCS_uv_to_xy(uv), xy, decimal=7)
 
         uv = np.tile(uv, (6, 1))
         xy = np.tile(xy, (6, 1))
-        np.testing.assert_almost_equal(
-            UCS_uv_to_xy(uv),
-            xy,
-            decimal=7)
+        np.testing.assert_almost_equal(UCS_uv_to_xy(uv), xy, decimal=7)
 
         uv = np.reshape(uv, (2, 3, 2))
         xy = np.reshape(xy, (2, 3, 2))
-        np.testing.assert_almost_equal(
-            UCS_uv_to_xy(uv),
-            xy,
-            decimal=7)
+        np.testing.assert_almost_equal(UCS_uv_to_xy(uv), xy, decimal=7)
 
     @ignore_numpy_errors
     def test_nan_UCS_uv_to_xy(self):
