@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Characterisation Plotting
 =========================
@@ -18,13 +17,8 @@ import pylab
 from colour.characterisation import COLOURCHECKERS
 from colour.models import RGB_COLOURSPACES
 from colour.models import XYZ_to_sRGB, xyY_to_XYZ
-from colour.plotting import (
-    ColourParameter,
-    boundaries,
-    canvas,
-    decorate,
-    display,
-    multi_colour_plot)
+from colour.plotting import (ColourParameter, boundaries, canvas, decorate,
+                             display, multi_colour_plot)
 
 __author__ = 'Colour Developers'
 __copyright__ = 'Copyright (C) 2013-2017 - Colour Developers'
@@ -93,10 +87,9 @@ def colour_checker_plot(colour_checker='ColorChecker 2005', **kwargs):
 
     colour_checker, name = COLOURCHECKERS.get(colour_checker), colour_checker
     if colour_checker is None:
-        raise KeyError(
-            ('Colour checker "{0}" not found in '
-             'factory colour checkers: "{1}".').format(
-                name, sorted(COLOURCHECKERS.keys())))
+        raise KeyError(('Colour checker "{0}" not found in '
+                        'factory colour checkers: "{1}".').format(
+                            name, sorted(COLOURCHECKERS.keys())))
 
     _name, data, illuminant = colour_checker
     colour_parameters = []
@@ -120,7 +113,8 @@ def colour_checker_plot(colour_checker='ColorChecker 2005', **kwargs):
         'across': across,
         'text_size': 8,
         'background_colour': background_colour,
-        'margins': (-0.125, 0.125, -0.5, 0.125)}
+        'margins': (-0.125, 0.125, -0.5, 0.125)
+    }
     settings.update(kwargs)
 
     multi_colour_plot(colour_parameters, **settings)
@@ -128,19 +122,21 @@ def colour_checker_plot(colour_checker='ColorChecker 2005', **kwargs):
     text_x = width * (across / 2) + (across * (spacing / 2)) - spacing / 2
     text_y = -(len(colour_parameters) / across + spacing / 2)
 
-    pylab.text(text_x,
-               text_y,
-               '{0} - {1} - Colour Rendition Chart'.format(
-                   name, RGB_COLOURSPACES['sRGB'].name),
-               color='0.95',
-               clip_on=True,
-               ha='center')
+    pylab.text(
+        text_x,
+        text_y,
+        '{0} - {1} - Colour Rendition Chart'.format(
+            name, RGB_COLOURSPACES['sRGB'].name),
+        color='0.95',
+        clip_on=True,
+        ha='center')
 
     settings.update({
         'title': name,
         'facecolor': background_colour,
         'edgecolor': None,
-        'standalone': True})
+        'standalone': True
+    })
 
     boundaries(**settings)
     decorate(**settings)
