@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Corresponding Chromaticities Prediction Plotting
 ================================================
@@ -14,13 +13,9 @@ from __future__ import division
 import pylab
 
 from colour.corresponding import corresponding_chromaticities_prediction
-from colour.plotting import (
-    CIE_1976_UCS_chromaticity_diagram_plot,
-    DEFAULT_FIGURE_WIDTH,
-    boundaries,
-    canvas,
-    decorate,
-    display)
+from colour.plotting import (CIE_1976_UCS_chromaticity_diagram_plot,
+                             DEFAULT_FIGURE_WIDTH, boundaries, canvas,
+                             decorate, display)
 
 __author__ = 'Colour Developers'
 __copyright__ = 'Copyright (C) 2013-2017 - Colour Developers'
@@ -32,11 +27,10 @@ __status__ = 'Production'
 __all__ = ['corresponding_chromaticities_prediction_plot']
 
 
-def corresponding_chromaticities_prediction_plot(
-        experiment=1,
-        model='Von Kries',
-        transform='CAT02',
-        **kwargs):
+def corresponding_chromaticities_prediction_plot(experiment=1,
+                                                 model='Von Kries',
+                                                 transform='CAT02',
+                                                 **kwargs):
     """
     Plots given chromatic adaptation model corresponding chromaticities
     prediction.
@@ -78,12 +72,14 @@ def corresponding_chromaticities_prediction_plot(
     settings.update({
         'title': (('Corresponding Chromaticities Prediction\n{0} ({1}) - '
                    'Experiment {2}\nCIE 1976 UCS Chromaticity Diagram').format(
-            model, transform, experiment)
-            if model.lower() in ('von kries', 'vonkries') else
-            ('Corresponding Chromaticities Prediction\n{0} - '
-                'Experiment {1}\nCIE 1976 UCS Chromaticity Diagram').format(
-                    model, experiment)),
-        'standalone': False})
+                       model, transform, experiment)
+                  if model.lower() in ('von kries', 'vonkries') else
+                  ('Corresponding Chromaticities Prediction\n{0} - '
+                   'Experiment {1}\nCIE 1976 UCS Chromaticity Diagram').format(
+                       model, experiment)),
+        'standalone':
+            False
+    })
     settings.update(kwargs)
 
     CIE_1976_UCS_chromaticity_diagram_plot(**settings)
@@ -93,14 +89,15 @@ def corresponding_chromaticities_prediction_plot(
 
     for result in results:
         name, uvp_t, uvp_m, uvp_p = result
-        pylab.arrow(uvp_t[0],
-                    uvp_t[1],
-                    uvp_p[0] - uvp_t[0] - 0.1 * (uvp_p[0] - uvp_t[0]),
-                    uvp_p[1] - uvp_t[1] - 0.1 * (uvp_p[1] - uvp_t[1]),
-                    head_width=0.005,
-                    head_length=0.005,
-                    linewidth=0.5,
-                    color='black')
+        pylab.arrow(
+            uvp_t[0],
+            uvp_t[1],
+            uvp_p[0] - uvp_t[0] - 0.1 * (uvp_p[0] - uvp_t[0]),
+            uvp_p[1] - uvp_t[1] - 0.1 * (uvp_p[1] - uvp_t[1]),
+            head_width=0.005,
+            head_length=0.005,
+            linewidth=0.5,
+            color='black')
         pylab.plot(uvp_t[0], uvp_t[1], 'o', color='white')
         pylab.plot(uvp_m[0], uvp_m[1], '^', color='white')
         pylab.plot(uvp_p[0], uvp_p[1], '^', color='black')
@@ -108,7 +105,8 @@ def corresponding_chromaticities_prediction_plot(
         'x_tighten': True,
         'y_tighten': True,
         'limits': (-0.1, 0.7, -0.1, 0.7),
-        'standalone': True})
+        'standalone': True
+    })
     settings.update(kwargs)
 
     boundaries(**settings)
