@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 CIE Chromaticity Diagrams Plotting
 ==================================
@@ -29,25 +28,12 @@ from scipy.spatial import Delaunay
 
 from colour.algebra import normalise_vector
 from colour.colorimetry import spectral_to_XYZ
-from colour.models import (
-    Luv_to_uv,
-    Luv_uv_to_xy,
-    UCS_to_uv,
-    UCS_uv_to_xy,
-    XYZ_to_Luv,
-    XYZ_to_UCS,
-    XYZ_to_sRGB,
-    XYZ_to_xy,
-    xy_to_XYZ)
-from colour.plotting import (
-    DEFAULT_FIGURE_WIDTH,
-    DEFAULT_PLOTTING_ILLUMINANT,
-    PLOTTING_RESOURCES_DIRECTORY,
-    canvas,
-    decorate,
-    boundaries,
-    display,
-    get_cmfs)
+from colour.models import (Luv_to_uv, Luv_uv_to_xy, UCS_to_uv, UCS_uv_to_xy,
+                           XYZ_to_Luv, XYZ_to_UCS, XYZ_to_sRGB, XYZ_to_xy,
+                           xy_to_XYZ)
+from colour.plotting import (DEFAULT_FIGURE_WIDTH, DEFAULT_PLOTTING_ILLUMINANT,
+                             PLOTTING_RESOURCES_DIRECTORY, canvas, decorate,
+                             boundaries, display, get_cmfs)
 from colour.utilities import normalise_maximum, tsplit, tstack
 
 __author__ = 'Colour Developers'
@@ -57,15 +43,17 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['CIE_1931_chromaticity_diagram_colours_plot',
-           'CIE_1931_chromaticity_diagram_plot',
-           'CIE_1960_UCS_chromaticity_diagram_colours_plot',
-           'CIE_1960_UCS_chromaticity_diagram_plot',
-           'CIE_1976_UCS_chromaticity_diagram_colours_plot',
-           'CIE_1976_UCS_chromaticity_diagram_plot',
-           'spds_CIE_1931_chromaticity_diagram_plot',
-           'spds_CIE_1960_UCS_chromaticity_diagram_plot',
-           'spds_CIE_1976_UCS_chromaticity_diagram_plot']
+__all__ = [
+    'CIE_1931_chromaticity_diagram_colours_plot',
+    'CIE_1931_chromaticity_diagram_plot',
+    'CIE_1960_UCS_chromaticity_diagram_colours_plot',
+    'CIE_1960_UCS_chromaticity_diagram_plot',
+    'CIE_1976_UCS_chromaticity_diagram_colours_plot',
+    'CIE_1976_UCS_chromaticity_diagram_plot',
+    'spds_CIE_1931_chromaticity_diagram_plot',
+    'spds_CIE_1960_UCS_chromaticity_diagram_plot',
+    'spds_CIE_1976_UCS_chromaticity_diagram_plot'
+]
 
 
 def CIE_1931_chromaticity_diagram_colours_plot(
@@ -111,10 +99,10 @@ def CIE_1931_chromaticity_diagram_colours_plot(
 
     illuminant = DEFAULT_PLOTTING_ILLUMINANT
 
-    triangulation = Delaunay(XYZ_to_xy(cmfs.values, illuminant),
-                             qhull_options='QJ')
-    xx, yy = np.meshgrid(np.linspace(0, 1, samples),
-                         np.linspace(0, 1, samples))
+    triangulation = Delaunay(
+        XYZ_to_xy(cmfs.values, illuminant), qhull_options='QJ')
+    xx, yy = np.meshgrid(
+        np.linspace(0, 1, samples), np.linspace(0, 1, samples))
     xy = tstack((xx, yy))
     xy = xy[triangulation.find_simplex(xy) > 0]
 
@@ -129,7 +117,8 @@ def CIE_1931_chromaticity_diagram_colours_plot(
     settings.update({
         'x_ticker': False,
         'y_ticker': False,
-        'bounding_box': (0, 1, 0, 1)})
+        'bounding_box': (0, 1, 0, 1)
+    })
     settings.update(kwargs)
 
     ax = matplotlib.pyplot.gca()
@@ -188,8 +177,8 @@ def CIE_1931_chromaticity_diagram_plot(
                              cmfs.name.replace(' ', '_'))))
         pylab.imshow(image, interpolation=None, extent=(0, 1, 0, 1))
 
-    labels = (
-        390, 460, 470, 480, 490, 500, 510, 520, 540, 560, 580, 600, 620, 700)
+    labels = (390, 460, 470, 480, 490, 500, 510, 520, 540, 560, 580, 600, 620,
+              700)
 
     wavelengths = cmfs.wavelengths
     equal_energy = np.array([1 / 3] * 2)
@@ -199,10 +188,10 @@ def CIE_1931_chromaticity_diagram_plot(
     wavelengths_chromaticity_coordinates = dict(tuple(zip(wavelengths, xy)))
 
     pylab.plot(xy[..., 0], xy[..., 1], color='black', linewidth=2)
-    pylab.plot((xy[-1][0], xy[0][0]),
-               (xy[-1][1], xy[0][1]),
-               color='black',
-               linewidth=2)
+    pylab.plot(
+        (xy[-1][0], xy[0][0]), (xy[-1][1], xy[0][1]),
+        color='black',
+        linewidth=2)
 
     for label in labels:
         x, y = wavelengths_chromaticity_coordinates[label]
@@ -211,8 +200,7 @@ def CIE_1931_chromaticity_diagram_plot(
         index = bisect.bisect(wavelengths, label)
         left = wavelengths[index - 1] if index >= 0 else wavelengths[index]
         right = (wavelengths[index]
-                 if index < len(wavelengths) else
-                 wavelengths[-1])
+                 if index < len(wavelengths) else wavelengths[-1])
 
         dx = (wavelengths_chromaticity_coordinates[right][0] -
               wavelengths_chromaticity_coordinates[left][0])
@@ -222,25 +210,25 @@ def CIE_1931_chromaticity_diagram_plot(
         xy = np.array([x, y])
         direction = np.array([-dy, dx])
 
-        normal = (np.array([-dy, dx])
-                  if np.dot(normalise_vector(xy - equal_energy),
-                            normalise_vector(direction)) > 0 else
-                  np.array([dy, -dx]))
+        normal = (np.array([-dy, dx]) if np.dot(
+            normalise_vector(xy - equal_energy), normalise_vector(direction)) >
+                  0 else np.array([dy, -dx]))
         normal = normalise_vector(normal)
         normal /= 25
 
-        pylab.plot((x, x + normal[0] * 0.75),
-                   (y, y + normal[1] * 0.75),
-                   color='black',
-                   linewidth=1.5)
-        pylab.text(x + normal[0],
-                   y + normal[1],
-                   label,
-                   color='black',
-                   clip_on=True,
-                   ha='left' if normal[0] >= 0 else 'right',
-                   va='center',
-                   fontdict={'size': 'small'})
+        pylab.plot(
+            (x, x + normal[0] * 0.75), (y, y + normal[1] * 0.75),
+            color='black',
+            linewidth=1.5)
+        pylab.text(
+            x + normal[0],
+            y + normal[1],
+            label,
+            color='black',
+            clip_on=True,
+            ha='left' if normal[0] >= 0 else 'right',
+            va='center',
+            fontdict={'size': 'small'})
 
     ticks = np.arange(-10, 10, 0.1)
 
@@ -252,7 +240,8 @@ def CIE_1931_chromaticity_diagram_plot(
         'x_label': 'CIE x',
         'y_label': 'CIE y',
         'grid': True,
-        'bounding_box': (0, 1, 0, 1)})
+        'bounding_box': (0, 1, 0, 1)
+    })
     settings.update(kwargs)
 
     boundaries(**settings)
@@ -304,10 +293,10 @@ def CIE_1960_UCS_chromaticity_diagram_colours_plot(
 
     illuminant = DEFAULT_PLOTTING_ILLUMINANT
 
-    triangulation = Delaunay(UCS_to_uv(XYZ_to_UCS(cmfs.values)),
-                             qhull_options='QJ')
-    xx, yy = np.meshgrid(np.linspace(0, 1, samples),
-                         np.linspace(0, 1, samples))
+    triangulation = Delaunay(
+        UCS_to_uv(XYZ_to_UCS(cmfs.values)), qhull_options='QJ')
+    xx, yy = np.meshgrid(
+        np.linspace(0, 1, samples), np.linspace(0, 1, samples))
     xy = tstack((xx, yy))
     xy = xy[triangulation.find_simplex(xy) > 0]
 
@@ -322,7 +311,8 @@ def CIE_1960_UCS_chromaticity_diagram_colours_plot(
     settings.update({
         'x_ticker': False,
         'y_ticker': False,
-        'bounding_box': (0, 1, 0, 1)})
+        'bounding_box': (0, 1, 0, 1)
+    })
     settings.update(kwargs)
 
     ax = matplotlib.pyplot.gca()
@@ -379,8 +369,8 @@ def CIE_1960_UCS_chromaticity_diagram_plot(
                              cmfs.name.replace(' ', '_'))))
         pylab.imshow(image, interpolation=None, extent=(0, 1, 0, 1))
 
-    labels = (420, 430, 440, 450, 460, 470, 480, 490, 500, 510, 520, 530,
-              540, 550, 560, 570, 580, 590, 600, 610, 620, 630, 640, 680)
+    labels = (420, 430, 440, 450, 460, 470, 480, 490, 500, 510, 520, 530, 540,
+              550, 560, 570, 580, 590, 600, 610, 620, 630, 640, 680)
 
     wavelengths = cmfs.wavelengths
     equal_energy = np.array([1 / 3] * 2)
@@ -390,10 +380,10 @@ def CIE_1960_UCS_chromaticity_diagram_plot(
     wavelengths_chromaticity_coordinates = dict(tuple(zip(wavelengths, uv)))
 
     pylab.plot(uv[..., 0], uv[..., 1], color='black', linewidth=2)
-    pylab.plot((uv[-1][0], uv[0][0]),
-               (uv[-1][1], uv[0][1]),
-               color='black',
-               linewidth=2)
+    pylab.plot(
+        (uv[-1][0], uv[0][0]), (uv[-1][1], uv[0][1]),
+        color='black',
+        linewidth=2)
 
     for label in labels:
         u, v = wavelengths_chromaticity_coordinates[label]
@@ -402,8 +392,7 @@ def CIE_1960_UCS_chromaticity_diagram_plot(
         index = bisect.bisect(wavelengths, label)
         left = wavelengths[index - 1] if index >= 0 else wavelengths[index]
         right = (wavelengths[index]
-                 if index < len(wavelengths) else
-                 wavelengths[-1])
+                 if index < len(wavelengths) else wavelengths[-1])
 
         dx = (wavelengths_chromaticity_coordinates[right][0] -
               wavelengths_chromaticity_coordinates[left][0])
@@ -413,25 +402,25 @@ def CIE_1960_UCS_chromaticity_diagram_plot(
         uv = np.array([u, v])
         direction = np.array([-dy, dx])
 
-        normal = (np.array([-dy, dx])
-                  if np.dot(normalise_vector(uv - equal_energy),
-                            normalise_vector(direction)) > 0 else
-                  np.array([dy, -dx]))
+        normal = (np.array([-dy, dx]) if np.dot(
+            normalise_vector(uv - equal_energy), normalise_vector(direction)) >
+                  0 else np.array([dy, -dx]))
         normal = normalise_vector(normal)
         normal /= 25
 
-        pylab.plot((u, u + normal[0] * 0.75),
-                   (v, v + normal[1] * 0.75),
-                   color='black',
-                   linewidth=1.5)
-        pylab.text(u + normal[0],
-                   v + normal[1],
-                   label,
-                   color='black',
-                   clip_on=True,
-                   ha='left' if normal[0] >= 0 else 'right',
-                   va='center',
-                   fontdict={'size': 'small'})
+        pylab.plot(
+            (u, u + normal[0] * 0.75), (v, v + normal[1] * 0.75),
+            color='black',
+            linewidth=1.5)
+        pylab.text(
+            u + normal[0],
+            v + normal[1],
+            label,
+            color='black',
+            clip_on=True,
+            ha='left' if normal[0] >= 0 else 'right',
+            va='center',
+            fontdict={'size': 'small'})
 
     ticks = np.arange(-10, 10, 0.1)
 
@@ -443,7 +432,8 @@ def CIE_1960_UCS_chromaticity_diagram_plot(
         'x_label': 'CIE u',
         'y_label': 'CIE v',
         'grid': True,
-        'bounding_box': (0, 1, 0, 1)})
+        'bounding_box': (0, 1, 0, 1)
+    })
     settings.update(kwargs)
 
     boundaries(**settings)
@@ -498,8 +488,8 @@ def CIE_1976_UCS_chromaticity_diagram_colours_plot(
     triangulation = Delaunay(
         Luv_to_uv(XYZ_to_Luv(cmfs.values, illuminant), illuminant),
         qhull_options='QJ Qf')
-    xx, yy = np.meshgrid(np.linspace(0, 1, samples),
-                         np.linspace(0, 1, samples))
+    xx, yy = np.meshgrid(
+        np.linspace(0, 1, samples), np.linspace(0, 1, samples))
     xy = tstack((xx, yy))
     xy = xy[triangulation.find_simplex(xy) > 0]
 
@@ -514,7 +504,8 @@ def CIE_1976_UCS_chromaticity_diagram_colours_plot(
     settings.update({
         'x_ticker': False,
         'y_ticker': False,
-        'bounding_box': (0, 1, 0, 1)})
+        'bounding_box': (0, 1, 0, 1)
+    })
     settings.update(kwargs)
 
     ax = matplotlib.pyplot.gca()
@@ -573,8 +564,8 @@ def CIE_1976_UCS_chromaticity_diagram_plot(
                              cmfs.name.replace(' ', '_'))))
         pylab.imshow(image, interpolation=None, extent=(0, 1, 0, 1))
 
-    labels = (420, 430, 440, 450, 460, 470, 480, 490, 500, 510, 520, 530,
-              540, 550, 560, 570, 580, 590, 600, 610, 620, 630, 640, 680)
+    labels = (420, 430, 440, 450, 460, 470, 480, 490, 500, 510, 520, 530, 540,
+              550, 560, 570, 580, 590, 600, 610, 620, 630, 640, 680)
 
     wavelengths = cmfs.wavelengths
     equal_energy = np.array([1 / 3] * 2)
@@ -584,10 +575,10 @@ def CIE_1976_UCS_chromaticity_diagram_plot(
     wavelengths_chromaticity_coordinates = dict(zip(wavelengths, uv))
 
     pylab.plot(uv[..., 0], uv[..., 1], color='black', linewidth=2)
-    pylab.plot((uv[-1][0], uv[0][0]),
-               (uv[-1][1], uv[0][1]),
-               color='black',
-               linewidth=2)
+    pylab.plot(
+        (uv[-1][0], uv[0][0]), (uv[-1][1], uv[0][1]),
+        color='black',
+        linewidth=2)
 
     for label in labels:
         u, v = wavelengths_chromaticity_coordinates[label]
@@ -596,8 +587,7 @@ def CIE_1976_UCS_chromaticity_diagram_plot(
         index = bisect.bisect(wavelengths, label)
         left = wavelengths[index - 1] if index >= 0 else wavelengths[index]
         right = (wavelengths[index]
-                 if index < len(wavelengths) else
-                 wavelengths[-1])
+                 if index < len(wavelengths) else wavelengths[-1])
 
         dx = (wavelengths_chromaticity_coordinates[right][0] -
               wavelengths_chromaticity_coordinates[left][0])
@@ -607,25 +597,25 @@ def CIE_1976_UCS_chromaticity_diagram_plot(
         uv = np.array([u, v])
         direction = np.array([-dy, dx])
 
-        normal = (np.array([-dy, dx])
-                  if np.dot(normalise_vector(uv - equal_energy),
-                            normalise_vector(direction)) > 0 else
-                  np.array([dy, -dx]))
+        normal = (np.array([-dy, dx]) if np.dot(
+            normalise_vector(uv - equal_energy), normalise_vector(direction)) >
+                  0 else np.array([dy, -dx]))
         normal = normalise_vector(normal)
         normal /= 25
 
-        pylab.plot((u, u + normal[0] * 0.75),
-                   (v, v + normal[1] * 0.75),
-                   color='black',
-                   linewidth=1.5)
-        pylab.text(u + normal[0],
-                   v + normal[1],
-                   label,
-                   color='black',
-                   clip_on=True,
-                   ha='left' if normal[0] >= 0 else 'right',
-                   va='center',
-                   fontdict={'size': 'small'})
+        pylab.plot(
+            (u, u + normal[0] * 0.75), (v, v + normal[1] * 0.75),
+            color='black',
+            linewidth=1.5)
+        pylab.text(
+            u + normal[0],
+            v + normal[1],
+            label,
+            color='black',
+            clip_on=True,
+            ha='left' if normal[0] >= 0 else 'right',
+            va='center',
+            fontdict={'size': 'small'})
 
     ticks = np.arange(-10, 10, 0.1)
 
@@ -637,7 +627,8 @@ def CIE_1976_UCS_chromaticity_diagram_plot(
         'x_label': 'CIE u\'',
         'y_label': 'CIE v\'',
         'grid': True,
-        'bounding_box': (0, 1, 0, 1)})
+        'bounding_box': (0, 1, 0, 1)
+    })
     settings.update(kwargs)
 
     boundaries(**settings)
@@ -647,9 +638,7 @@ def CIE_1976_UCS_chromaticity_diagram_plot(
 
 
 def spds_CIE_1931_chromaticity_diagram_plot(
-        spds,
-        cmfs='CIE 1931 2 Degree Standard Observer',
-        annotate=True,
+        spds, cmfs='CIE 1931 2 Degree Standard Observer', annotate=True,
         **kwargs):
     """
     Plots given spectral power distribution chromaticity coordinates into the
@@ -701,19 +690,21 @@ def spds_CIE_1931_chromaticity_diagram_plot(
         pylab.plot(xy[0], xy[1], 'o', color='white')
 
         if spd.name is not None and annotate:
-            pylab.annotate(spd.name,
-                           xy=xy,
-                           xytext=(50, 30),
-                           color='black',
-                           textcoords='offset points',
-                           arrowprops=dict(arrowstyle='->',
-                                           connectionstyle='arc3, rad=0.2'))
+            pylab.annotate(
+                spd.name,
+                xy=xy,
+                xytext=(50, 30),
+                color='black',
+                textcoords='offset points',
+                arrowprops=dict(
+                    arrowstyle='->', connectionstyle='arc3, rad=0.2'))
 
     settings.update({
         'x_tighten': True,
         'y_tighten': True,
         'limits': (-0.1, 0.9, -0.1, 0.9),
-        'standalone': True})
+        'standalone': True
+    })
     settings.update(kwargs)
 
     boundaries(**settings)
@@ -723,9 +714,7 @@ def spds_CIE_1931_chromaticity_diagram_plot(
 
 
 def spds_CIE_1960_UCS_chromaticity_diagram_plot(
-        spds,
-        cmfs='CIE 1931 2 Degree Standard Observer',
-        annotate=True,
+        spds, cmfs='CIE 1931 2 Degree Standard Observer', annotate=True,
         **kwargs):
     """
     Plots given spectral power distribution chromaticity coordinates into the
@@ -777,19 +766,21 @@ def spds_CIE_1960_UCS_chromaticity_diagram_plot(
         pylab.plot(uv[0], uv[1], 'o', color='white')
 
         if spd.name is not None and annotate:
-            pylab.annotate(spd.name,
-                           xy=uv,
-                           xytext=(50, 30),
-                           color='black',
-                           textcoords='offset points',
-                           arrowprops=dict(arrowstyle='->',
-                                           connectionstyle='arc3, rad=0.2'))
+            pylab.annotate(
+                spd.name,
+                xy=uv,
+                xytext=(50, 30),
+                color='black',
+                textcoords='offset points',
+                arrowprops=dict(
+                    arrowstyle='->', connectionstyle='arc3, rad=0.2'))
 
     settings.update({
         'x_tighten': True,
         'y_tighten': True,
         'limits': (-0.1, 0.7, -0.2, 0.6),
-        'standalone': True})
+        'standalone': True
+    })
     settings.update(kwargs)
 
     boundaries(**settings)
@@ -799,9 +790,7 @@ def spds_CIE_1960_UCS_chromaticity_diagram_plot(
 
 
 def spds_CIE_1976_UCS_chromaticity_diagram_plot(
-        spds,
-        cmfs='CIE 1931 2 Degree Standard Observer',
-        annotate=True,
+        spds, cmfs='CIE 1931 2 Degree Standard Observer', annotate=True,
         **kwargs):
     """
     Plots given spectral power distribution chromaticity coordinates into the
@@ -853,19 +842,21 @@ def spds_CIE_1976_UCS_chromaticity_diagram_plot(
         pylab.plot(uv[0], uv[1], 'o', color='white')
 
         if spd.name is not None and annotate:
-            pylab.annotate(spd.name,
-                           xy=uv,
-                           xytext=(50, 30),
-                           color='black',
-                           textcoords='offset points',
-                           arrowprops=dict(arrowstyle='->',
-                                           connectionstyle='arc3, rad=0.2'))
+            pylab.annotate(
+                spd.name,
+                xy=uv,
+                xytext=(50, 30),
+                color='black',
+                textcoords='offset points',
+                arrowprops=dict(
+                    arrowstyle='->', connectionstyle='arc3, rad=0.2'))
 
     settings.update({
         'x_tighten': True,
         'y_tighten': True,
         'limits': (-0.1, 0.7, -0.1, 0.7),
-        'standalone': True})
+        'standalone': True
+    })
     settings.update(kwargs)
 
     boundaries(**settings)
