@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Colour Temperature & Correlated Colour Temperature Plotting
 ===========================================================
@@ -17,21 +16,12 @@ from __future__ import division
 import numpy as np
 import pylab
 
-from colour.colorimetry import (
-    CMFS,
-    ILLUMINANTS)
-from colour.models import (
-    UCS_uv_to_xy,
-    XYZ_to_UCS,
-    UCS_to_uv,
-    xy_to_XYZ)
+from colour.colorimetry import (CMFS, ILLUMINANTS)
+from colour.models import (UCS_uv_to_xy, XYZ_to_UCS, UCS_to_uv, xy_to_XYZ)
 from colour.temperature import CCT_to_uv
-from colour.plotting import (
-    CIE_1931_chromaticity_diagram_plot,
-    CIE_1960_UCS_chromaticity_diagram_plot,
-    boundaries,
-    decorate,
-    display)
+from colour.plotting import (CIE_1931_chromaticity_diagram_plot,
+                             CIE_1960_UCS_chromaticity_diagram_plot,
+                             boundaries, decorate, display)
 
 __author__ = 'Colour Developers'
 __copyright__ = 'Copyright (C) 2013-2017 - Colour Developers'
@@ -40,13 +30,14 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['planckian_locus_CIE_1931_chromaticity_diagram_plot',
-           'planckian_locus_CIE_1960_UCS_chromaticity_diagram_plot']
+__all__ = [
+    'planckian_locus_CIE_1931_chromaticity_diagram_plot',
+    'planckian_locus_CIE_1960_UCS_chromaticity_diagram_plot'
+]
 
 
-def planckian_locus_CIE_1931_chromaticity_diagram_plot(
-        illuminants=None,
-        **kwargs):
+def planckian_locus_CIE_1931_chromaticity_diagram_plot(illuminants=None,
+                                                       **kwargs):
     """
     Plots the planckian locus and given illuminants in
     *CIE 1931 Chromaticity Diagram*.
@@ -91,19 +82,21 @@ def planckian_locus_CIE_1931_chromaticity_diagram_plot(
     settings = {
         'title': ('{0} Illuminants - Planckian Locus\n'
                   'CIE 1931 Chromaticity Diagram - '
-                  'CIE 1931 2 Degree Standard Observer').format(
-            ', '.join(illuminants))
-        if illuminants else
-        ('Planckian Locus\nCIE 1931 Chromaticity Diagram - '
-         'CIE 1931 2 Degree Standard Observer'),
-        'standalone': False}
+                  'CIE 1931 2 Degree Standard Observer'
+                  ).format(', '.join(illuminants)) if illuminants else
+                 ('Planckian Locus\nCIE 1931 Chromaticity Diagram - '
+                  'CIE 1931 2 Degree Standard Observer'),
+        'standalone':
+            False
+    }
     settings.update(kwargs)
 
     CIE_1931_chromaticity_diagram_plot(**settings)
 
     start, end = 1667, 100000
-    xy = np.array([UCS_uv_to_xy(CCT_to_uv(x, 'Robertson 1968', D_uv=0))
-                   for x in np.arange(start, end + 250, 250)])
+    xy = np.array(
+        [UCS_uv_to_xy(CCT_to_uv(x, 'Robertson 1968', D_uv=0))
+         for x in np.arange(start, end + 250, 250)])  # yapf: disable
 
     pylab.plot(xy[..., 0], xy[..., 1], color='black', linewidth=2)
 
@@ -111,12 +104,13 @@ def planckian_locus_CIE_1931_chromaticity_diagram_plot(
         x0, y0 = UCS_uv_to_xy(CCT_to_uv(i, 'Robertson 1968', D_uv=-0.025))
         x1, y1 = UCS_uv_to_xy(CCT_to_uv(i, 'Robertson 1968', D_uv=0.025))
         pylab.plot((x0, x1), (y0, y1), color='black', linewidth=2)
-        pylab.annotate('{0}K'.format(i),
-                       xy=(x0, y0),
-                       xytext=(0, -10),
-                       color='black',
-                       textcoords='offset points',
-                       size='x-small')
+        pylab.annotate(
+            '{0}K'.format(i),
+            xy=(x0, y0),
+            xytext=(0, -10),
+            color='black',
+            textcoords='offset points',
+            size='x-small')
 
     for illuminant in illuminants:
         xy = ILLUMINANTS.get(cmfs.name).get(illuminant)
@@ -128,19 +122,20 @@ def planckian_locus_CIE_1931_chromaticity_diagram_plot(
 
         pylab.plot(xy[0], xy[1], 'o', color='white', linewidth=2)
 
-        pylab.annotate(illuminant,
-                       xy=(xy[0], xy[1]),
-                       xytext=(-50, 30),
-                       color='black',
-                       textcoords='offset points',
-                       arrowprops=dict(arrowstyle='->',
-                                       connectionstyle='arc3, rad=-0.2'))
+        pylab.annotate(
+            illuminant,
+            xy=(xy[0], xy[1]),
+            xytext=(-50, 30),
+            color='black',
+            textcoords='offset points',
+            arrowprops=dict(arrowstyle='->', connectionstyle='arc3, rad=-0.2'))
 
     settings.update({
         'x_tighten': True,
         'y_tighten': True,
         'limits': (-0.1, 0.9, -0.1, 0.9),
-        'standalone': True})
+        'standalone': True
+    })
     settings.update(kwargs)
 
     boundaries(**settings)
@@ -150,8 +145,7 @@ def planckian_locus_CIE_1931_chromaticity_diagram_plot(
 
 
 def planckian_locus_CIE_1960_UCS_chromaticity_diagram_plot(
-        illuminants=None,
-        **kwargs):
+        illuminants=None, **kwargs):
     """
     Plots the planckian locus and given illuminants in
     *CIE 1960 UCS Chromaticity Diagram*.
@@ -196,19 +190,21 @@ def planckian_locus_CIE_1960_UCS_chromaticity_diagram_plot(
     settings = {
         'title': ('{0} Illuminants - Planckian Locus\n'
                   'CIE 1960 UCS Chromaticity Diagram - '
-                  'CIE 1931 2 Degree Standard Observer').format(
-            ', '.join(illuminants))
-        if illuminants else
-        ('Planckian Locus\nCIE 1960 UCS Chromaticity Diagram - '
-         'CIE 1931 2 Degree Standard Observer'),
-        'standalone': False}
+                  'CIE 1931 2 Degree Standard Observer'
+                  ).format(', '.join(illuminants)) if illuminants else
+                 ('Planckian Locus\nCIE 1960 UCS Chromaticity Diagram - '
+                  'CIE 1931 2 Degree Standard Observer'),
+        'standalone':
+            False
+    }
     settings.update(kwargs)
 
     CIE_1960_UCS_chromaticity_diagram_plot(**settings)
 
     start, end = 1667, 100000
-    uv = np.array([CCT_to_uv(x, 'Robertson 1968', D_uv=0)
-                   for x in np.arange(start, end + 250, 250)])
+    uv = np.array(
+        [CCT_to_uv(x, 'Robertson 1968', D_uv=0)
+         for x in np.arange(start, end + 250, 250)])  # yapf: disable
 
     pylab.plot(uv[..., 0], uv[..., 1], color='black', linewidth=2)
 
@@ -216,12 +212,13 @@ def planckian_locus_CIE_1960_UCS_chromaticity_diagram_plot(
         u0, v0 = CCT_to_uv(i, 'Robertson 1968', D_uv=-0.05)
         u1, v1 = CCT_to_uv(i, 'Robertson 1968', D_uv=0.05)
         pylab.plot((u0, u1), (v0, v1), color='black', linewidth=2)
-        pylab.annotate('{0}K'.format(i),
-                       xy=(u0, v0),
-                       xytext=(0, -10),
-                       color='black',
-                       textcoords='offset points',
-                       size='x-small')
+        pylab.annotate(
+            '{0}K'.format(i),
+            xy=(u0, v0),
+            xytext=(0, -10),
+            color='black',
+            textcoords='offset points',
+            size='x-small')
 
     for illuminant in illuminants:
         xy = ILLUMINANTS.get(cmfs.name).get(illuminant)
@@ -235,19 +232,20 @@ def planckian_locus_CIE_1960_UCS_chromaticity_diagram_plot(
 
         pylab.plot(uv[0], uv[1], 'o', color='white', linewidth=2)
 
-        pylab.annotate(illuminant,
-                       xy=(uv[0], uv[1]),
-                       xytext=(-50, 30),
-                       color='black',
-                       textcoords='offset points',
-                       arrowprops=dict(arrowstyle='->',
-                                       connectionstyle='arc3, rad=-0.2'))
+        pylab.annotate(
+            illuminant,
+            xy=(uv[0], uv[1]),
+            xytext=(-50, 30),
+            color='black',
+            textcoords='offset points',
+            arrowprops=dict(arrowstyle='->', connectionstyle='arc3, rad=-0.2'))
 
     settings.update({
         'x_tighten': True,
         'y_tighten': True,
         'limits': (-0.1, 0.7, -0.2, 0.6),
-        'standalone': True})
+        'standalone': True
+    })
     settings.update(kwargs)
 
     boundaries(**settings)
