@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Colour Rendering Index
 ======================
@@ -29,11 +28,8 @@ from collections import namedtuple
 
 from colour.algebra import euclidean_distance
 from colour.colorimetry import (
-    ASTME30815_PRACTISE_SHAPE,
-    D_illuminant_relative_spd,
-    STANDARD_OBSERVERS_CMFS,
-    blackbody_spd,
-    spectral_to_XYZ)
+    ASTME30815_PRACTISE_SHAPE, D_illuminant_relative_spd,
+    STANDARD_OBSERVERS_CMFS, blackbody_spd, spectral_to_XYZ)
 from colour.quality.dataset.tcs import TCS_INDEXES_TO_NAMES, TCS_SPDS
 from colour.models import UCS_to_uv, XYZ_to_UCS, XYZ_to_xyY
 from colour.temperature import CCT_to_xy_CIE_D, uv_to_CCT_Robertson1968
@@ -45,25 +41,22 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['TCS_ColorimetryData',
-           'TCS_ColourQualityScaleData',
-           'CRI_Specification',
-           'colour_rendering_index',
-           'tcs_colorimetry_data',
-           'colour_rendering_indexes']
+__all__ = [
+    'TCS_ColorimetryData', 'TCS_ColourQualityScaleData', 'CRI_Specification',
+    'colour_rendering_index', 'tcs_colorimetry_data',
+    'colour_rendering_indexes'
+]
 
 
 class TCS_ColorimetryData(
-    namedtuple('TCS_ColorimetryData',
-               ('name', 'XYZ', 'uv', 'UVW'))):
+        namedtuple('TCS_ColorimetryData', ('name', 'XYZ', 'uv', 'UVW'))):
     """
     Defines the the class storing *test colour samples* colorimetry data.
     """
 
 
 class TCS_ColourQualityScaleData(
-    namedtuple('TCS_ColourQualityScaleData',
-               ('name', 'Q_a'))):
+        namedtuple('TCS_ColourQualityScaleData', ('name', 'Q_a'))):
     """
     Defines the the class storing *test colour samples* colour rendering
     index data.
@@ -71,9 +64,8 @@ class TCS_ColourQualityScaleData(
 
 
 class CRI_Specification(
-    namedtuple(
-        'CRI_Specification',
-        ('name', 'Q_a', 'Q_as', 'colorimetry_data'))):
+        namedtuple('CRI_Specification', ('name', 'Q_a', 'Q_as',
+                                         'colorimetry_data'))):
     """
     Defines the *Colour Rendering Index* (CRI) colour quality specification.
 
@@ -117,12 +109,14 @@ def colour_rendering_index(spd_test, additional_data=False):
 
     cmfs = STANDARD_OBSERVERS_CMFS[
         'CIE 1931 2 Degree Standard Observer'].clone().trim_wavelengths(
-        ASTME30815_PRACTISE_SHAPE)
+            ASTME30815_PRACTISE_SHAPE)
 
     shape = cmfs.shape
     spd_test = spd_test.clone().align(shape)
-    tcs_spds = {spd.name: spd.clone().align(shape)
-                for spd in TCS_SPDS.values()}
+    tcs_spds = {
+        spd.name: spd.clone().align(shape)
+        for spd in TCS_SPDS.values()
+    }
 
     XYZ = spectral_to_XYZ(spd_test, cmfs)
     uv = UCS_to_uv(XYZ_to_UCS(XYZ))
@@ -136,28 +130,19 @@ def colour_rendering_index(spd_test, additional_data=False):
         spd_reference.align(shape)
 
     test_tcs_colorimetry_data = tcs_colorimetry_data(
-        spd_test,
-        spd_reference,
-        tcs_spds,
-        cmfs,
-        chromatic_adaptation=True)
+        spd_test, spd_reference, tcs_spds, cmfs, chromatic_adaptation=True)
 
     reference_tcs_colorimetry_data = tcs_colorimetry_data(
-        spd_reference,
-        spd_reference,
-        tcs_spds,
-        cmfs)
+        spd_reference, spd_reference, tcs_spds, cmfs)
 
-    Q_as = colour_rendering_indexes(
-        test_tcs_colorimetry_data, reference_tcs_colorimetry_data)
+    Q_as = colour_rendering_indexes(test_tcs_colorimetry_data,
+                                    reference_tcs_colorimetry_data)
 
-    Q_a = np.average([v.Q_a for k, v in Q_as.items()
-                      if k in (1, 2, 3, 4, 5, 6, 7, 8)])
+    Q_a = np.average(
+        [v.Q_a for k, v in Q_as.items() if k in (1, 2, 3, 4, 5, 6, 7, 8)])
 
     if additional_data:
-        return CRI_Specification(spd_test.name,
-                                 Q_a,
-                                 Q_as,
+        return CRI_Specification(spd_test.name, Q_a, Q_as,
                                  (test_tcs_colorimetry_data,
                                   reference_tcs_colorimetry_data))
     else:
@@ -226,21 +211,18 @@ def tcs_colorimetry_data(spd_t,
             c_t, d_t = c(u_t, v_t), d(u_t, v_t)
             c_r, d_r = c(u_r, v_r), d(u_r, v_r)
             tcs_c, tcs_d = c(u_tcs, v_tcs), d(u_tcs, v_tcs)
-            u_tcs = ((10.872 + 0.404 * c_r / c_t * tcs_c - 4 *
-                      d_r / d_t * tcs_d) /
-                     (16.518 + 1.481 * c_r / c_t * tcs_c -
-                      d_r / d_t * tcs_d))
-            v_tcs = (5.52 / (16.518 + 1.481 * c_r / c_t * tcs_c -
-                             d_r / d_t * tcs_d))
+            u_tcs = ((
+                10.872 + 0.404 * c_r / c_t * tcs_c - 4 * d_r / d_t * tcs_d) /
+                     (16.518 + 1.481 * c_r / c_t * tcs_c - d_r / d_t * tcs_d))
+            v_tcs = (5.52 /
+                     (16.518 + 1.481 * c_r / c_t * tcs_c - d_r / d_t * tcs_d))
 
         W_tcs = 25 * xyY_tcs[-1] ** (1 / 3) - 17
         U_tcs = 13 * W_tcs * (u_tcs - u_r)
         V_tcs = 13 * W_tcs * (v_tcs - v_r)
 
         tcs_data.append(
-            TCS_ColorimetryData(spd_tcs.name,
-                                XYZ_tcs,
-                                uv_tcs,
+            TCS_ColorimetryData(spd_tcs.name, XYZ_tcs, uv_tcs,
                                 np.array([U_tcs, V_tcs, W_tcs])))
 
     return tcs_data
@@ -266,7 +248,6 @@ def colour_rendering_indexes(test_data, reference_data):
     Q_as = {}
     for i, _ in enumerate(test_data):
         Q_as[i + 1] = TCS_ColourQualityScaleData(
-            test_data[i].name,
-            100 - 4.6 * euclidean_distance(reference_data[i].UVW,
-                                           test_data[i].UVW))
+            test_data[i].name, 100 -
+            4.6 * euclidean_distance(reference_data[i].UVW, test_data[i].UVW))
     return Q_as
