@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Test Colour Samples Spectral Power Distributions
 ================================================
@@ -37,9 +36,7 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['TCS_APPROXIMATE_MUNSELL_NOTATIONS',
-           'TCS_SPDS_DATA',
-           'TCS_SPDS']
+__all__ = ['TCS_APPROXIMATE_MUNSELL_NOTATIONS', 'TCS_SPDS_DATA', 'TCS_SPDS']
 
 TCS_INDEXES_TO_NAMES = {
     1: 'TCS01',
@@ -55,28 +52,30 @@ TCS_INDEXES_TO_NAMES = {
     11: 'TCS11',
     12: 'TCS12',
     13: 'TCS13',
-    14: 'TCS14'}
+    14: 'TCS14'
+}
 """
 Test colour samples indexes to names mapping.
 
 TCS_INDEXES_TO_NAMES : dict
 """
 
-TCS_APPROXIMATE_MUNSELL_NOTATIONS = CaseInsensitiveMapping(
-    {'TCS01': '7.5 R 6/4',
-     'TCS02': '5 Y 6/4',
-     'TCS03': '5 GY 6/8',
-     'TCS04': '2.5 G 6/6',
-     'TCS05': '10 BG 6/4',
-     'TCS06': '5 PB 6/8',
-     'TCS07': '2.5 P 6/8',
-     'TCS08': '10 P 6/8',
-     'TCS09': '4.5 R 4/13',
-     'TCS10': '5 Y 8/10',
-     'TCS11': '4.5 G 5/8',
-     'TCS12': '3 PB 3/11',
-     'TCS13': '5 YR 8/4',
-     'TCS14': '5 GY 4/4'})
+TCS_APPROXIMATE_MUNSELL_NOTATIONS = CaseInsensitiveMapping({
+    'TCS01': '7.5 R 6/4',
+    'TCS02': '5 Y 6/4',
+    'TCS03': '5 GY 6/8',
+    'TCS04': '2.5 G 6/6',
+    'TCS05': '10 BG 6/4',
+    'TCS06': '5 PB 6/8',
+    'TCS07': '2.5 P 6/8',
+    'TCS08': '10 P 6/8',
+    'TCS09': '4.5 R 4/13',
+    'TCS10': '5 Y 8/10',
+    'TCS11': '4.5 G 5/8',
+    'TCS12': '3 PB 3/11',
+    'TCS13': '5 YR 8/4',
+    'TCS14': '5 GY 4/4'
+})
 """
 Test colour samples *Munsell* colour approximations.
 
@@ -179,7 +178,8 @@ TCS_SPDS_DATA = {
         815: 0.466,
         820: 0.465,
         825: 0.464,
-        830: 0.464},
+        830: 0.464
+    },
     'TCS02': {
         360: 0.053,
         365: 0.055,
@@ -275,7 +275,8 @@ TCS_SPDS_DATA = {
         815: 0.311,
         820: 0.311,
         825: 0.311,
-        830: 0.310},
+        830: 0.310
+    },
     'TCS03': {
         360: 0.058,
         365: 0.059,
@@ -371,7 +372,8 @@ TCS_SPDS_DATA = {
         815: 0.544,
         820: 0.548,
         825: 0.552,
-        830: 0.555},
+        830: 0.555
+    },
     'TCS04': {
         360: 0.057,
         365: 0.059,
@@ -467,7 +469,8 @@ TCS_SPDS_DATA = {
         815: 0.243,
         820: 0.254,
         825: 0.264,
-        830: 0.274},
+        830: 0.274
+    },
     'TCS05': {
         360: 0.143,
         365: 0.187,
@@ -563,7 +566,8 @@ TCS_SPDS_DATA = {
         815: 0.257,
         820: 0.265,
         825: 0.273,
-        830: 0.280},
+        830: 0.280
+    },
     'TCS06': {
         360: 0.079,
         365: 0.081,
@@ -659,7 +663,8 @@ TCS_SPDS_DATA = {
         815: 0.525,
         820: 0.529,
         825: 0.532,
-        830: 0.535},
+        830: 0.535
+    },
     'TCS07': {
         360: 0.150,
         365: 0.177,
@@ -755,7 +760,8 @@ TCS_SPDS_DATA = {
         815: 0.590,
         820: 0.590,
         825: 0.591,
-        830: 0.592},
+        830: 0.592
+    },
     'TCS08': {
         360: 0.075,
         365: 0.078,
@@ -851,7 +857,8 @@ TCS_SPDS_DATA = {
         815: 0.731,
         820: 0.731,
         825: 0.731,
-        830: 0.731},
+        830: 0.731
+    },
     'TCS09': {
         360: 0.069,
         365: 0.072,
@@ -947,7 +954,8 @@ TCS_SPDS_DATA = {
         815: 0.837,
         820: 0.837,
         825: 0.836,
-        830: 0.836},
+        830: 0.836
+    },
     'TCS10': {
         360: 0.042,
         365: 0.043,
@@ -1043,7 +1051,8 @@ TCS_SPDS_DATA = {
         815: 0.757,
         820: 0.757,
         825: 0.756,
-        830: 0.756},
+        830: 0.756
+    },
     'TCS11': {
         360: 0.074,
         365: 0.079,
@@ -1139,7 +1148,8 @@ TCS_SPDS_DATA = {
         815: 0.380,
         820: 0.388,
         825: 0.396,
-        830: 0.403},
+        830: 0.403
+    },
     'TCS12': {
         360: 0.189,
         365: 0.175,
@@ -1235,7 +1245,8 @@ TCS_SPDS_DATA = {
         815: 0.694,
         820: 0.697,
         825: 0.700,
-        830: 0.702},
+        830: 0.702
+    },
     'TCS13': {
         360: 0.071,
         365: 0.076,
@@ -1331,7 +1342,8 @@ TCS_SPDS_DATA = {
         815: 0.745,
         820: 0.745,
         825: 0.745,
-        830: 0.745},
+        830: 0.745
+    },
     'TCS14': {
         360: 0.036,
         365: 0.036,
@@ -1427,11 +1439,13 @@ TCS_SPDS_DATA = {
         815: 0.444,
         820: 0.448,
         825: 0.451,
-        830: 0.454}}
+        830: 0.454
+    }
+}
 
 TCS_SPDS = CaseInsensitiveMapping(
-    dict((key, SpectralPowerDistribution(key, value)) for key, value in
-         TCS_SPDS_DATA.items()))
+    dict((key, SpectralPowerDistribution(key, value))
+         for key, value in TCS_SPDS_DATA.items()))
 """
 Test colour samples spectral power distributions.
 
