@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 CQS Test Colour Samples Spectral Power Distributions
 ====================================================
@@ -38,9 +37,7 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['VS_APPROXIMATE_MUNSELL_NOTATIONS',
-           'VS_SPDS_DATA',
-           'VS_SPDS']
+__all__ = ['VS_APPROXIMATE_MUNSELL_NOTATIONS', 'VS_SPDS_DATA', 'VS_SPDS']
 
 VS_INDEXES_TO_NAMES = {
     1: 'VS1',
@@ -57,29 +54,31 @@ VS_INDEXES_TO_NAMES = {
     12: 'VS12',
     13: 'VS13',
     14: 'VS14',
-    15: 'VS15'}
+    15: 'VS15'
+}
 """
 CQS test colour samples indexes to names mapping.
 
 VS_INDEXES_TO_NAMES : dict
 """
 
-VS_APPROXIMATE_MUNSELL_NOTATIONS = CaseInsensitiveMapping(
-    {'VS1': '7.5P 4/10',
-     'VS2': '10PB 4/10',
-     'VS3': '5PB 4/2',
-     'VS4': '7.5B 5/10',
-     'VS5': '10B G6/8',
-     'VS6': '2.5BG 6/10',
-     'VS7': '2.5G 6/12',
-     'VS8': '7.5GY 7/10',
-     'VS9': '2.5GY 8/10',
-     'VS10': '5Y 8.5/12',
-     'VS11': '10YR 7/12',
-     'VS12': '5YR 7/12',
-     'VS13': '10R 6/12',
-     'VS14': '5R 4/14',
-     'VS15': '7.5RP 4/12'})
+VS_APPROXIMATE_MUNSELL_NOTATIONS = CaseInsensitiveMapping({
+    'VS1': '7.5P 4/10',
+    'VS2': '10PB 4/10',
+    'VS3': '5PB 4/2',
+    'VS4': '7.5B 5/10',
+    'VS5': '10B G6/8',
+    'VS6': '2.5BG 6/10',
+    'VS7': '2.5G 6/12',
+    'VS8': '7.5GY 7/10',
+    'VS9': '2.5GY 8/10',
+    'VS10': '5Y 8.5/12',
+    'VS11': '10YR 7/12',
+    'VS12': '5YR 7/12',
+    'VS13': '10R 6/12',
+    'VS14': '5R 4/14',
+    'VS15': '7.5RP 4/12'
+})
 """
 CQS test colour samples *Munsell* colour approximations.
 
@@ -178,7 +177,8 @@ VS_SPDS_DATA = {
         815: 0.5191,
         820: 0.5191,
         825: 0.5191,
-        830: 0.5191},
+        830: 0.5191
+    },
     'VS2': {
         380: 0.1053,
         385: 0.1323,
@@ -270,7 +270,8 @@ VS_SPDS_DATA = {
         815: 0.4537,
         820: 0.4537,
         825: 0.4537,
-        830: 0.4537},
+        830: 0.4537
+    },
     'VS3': {
         380: 0.0858,
         385: 0.0990,
@@ -362,7 +363,8 @@ VS_SPDS_DATA = {
         815: 0.2338,
         820: 0.2338,
         825: 0.2338,
-        830: 0.2338},
+        830: 0.2338
+    },
     'VS4': {
         380: 0.0790,
         385: 0.0984,
@@ -454,7 +456,8 @@ VS_SPDS_DATA = {
         815: 0.3512,
         820: 0.3512,
         825: 0.3512,
-        830: 0.3512},
+        830: 0.3512
+    },
     'VS5': {
         380: 0.1167,
         385: 0.1352,
@@ -546,7 +549,8 @@ VS_SPDS_DATA = {
         815: 0.2269,
         820: 0.2269,
         825: 0.2269,
-        830: 0.2269},
+        830: 0.2269
+    },
     'VS6': {
         380: 0.0872,
         385: 0.1001,
@@ -638,7 +642,8 @@ VS_SPDS_DATA = {
         815: 0.1646,
         820: 0.1646,
         825: 0.1646,
-        830: 0.1646},
+        830: 0.1646
+    },
     'VS7': {
         380: 0.0726,
         385: 0.0760,
@@ -730,7 +735,8 @@ VS_SPDS_DATA = {
         815: 0.1393,
         820: 0.1393,
         825: 0.1393,
-        830: 0.1393},
+        830: 0.1393
+    },
     'VS8': {
         380: 0.0652,
         385: 0.0657,
@@ -822,7 +828,8 @@ VS_SPDS_DATA = {
         815: 0.3239,
         820: 0.3239,
         825: 0.3239,
-        830: 0.3239},
+        830: 0.3239
+    },
     'VS9': {
         380: 0.0643,
         385: 0.0661,
@@ -914,7 +921,8 @@ VS_SPDS_DATA = {
         815: 0.5450,
         820: 0.5450,
         825: 0.5450,
-        830: 0.5450},
+        830: 0.5450
+    },
     'VS10': {
         380: 0.0540,
         385: 0.0489,
@@ -1006,7 +1014,8 @@ VS_SPDS_DATA = {
         815: 0.7789,
         820: 0.7789,
         825: 0.7789,
-        830: 0.7789},
+        830: 0.7789
+    },
     'VS11': {
         380: 0.0482,
         385: 0.0456,
@@ -1098,7 +1107,8 @@ VS_SPDS_DATA = {
         815: 0.5953,
         820: 0.5953,
         825: 0.5953,
-        830: 0.5953},
+        830: 0.5953
+    },
     'VS12': {
         380: 0.0691,
         385: 0.0692,
@@ -1190,7 +1200,8 @@ VS_SPDS_DATA = {
         815: 0.7158,
         820: 0.7158,
         825: 0.7158,
-        830: 0.7158},
+        830: 0.7158
+    },
     'VS13': {
         380: 0.0829,
         385: 0.0829,
@@ -1282,7 +1293,8 @@ VS_SPDS_DATA = {
         815: 0.6813,
         820: 0.6813,
         825: 0.6813,
-        830: 0.6813},
+        830: 0.6813
+    },
     'VS14': {
         380: 0.0530,
         385: 0.0507,
@@ -1374,7 +1386,8 @@ VS_SPDS_DATA = {
         815: 0.7683,
         820: 0.7683,
         825: 0.7683,
-        830: 0.7683},
+        830: 0.7683
+    },
     'VS15': {
         380: 0.0908,
         385: 0.1021,
@@ -1466,11 +1479,13 @@ VS_SPDS_DATA = {
         815: 0.7075,
         820: 0.7075,
         825: 0.7075,
-        830: 0.7075}}
+        830: 0.7075
+    }
+}
 
 VS_SPDS = CaseInsensitiveMapping(
-    dict((key, SpectralPowerDistribution(key, value)) for key, value in
-         VS_SPDS_DATA.items()))
+    dict((key, SpectralPowerDistribution(key, value))
+         for key, value in VS_SPDS_DATA.items()))
 """
 CQS test colour samples spectral power distributions.
 
