@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Defines unit tests for :mod:`colour.volume.mesh` module.
 """
@@ -35,11 +34,12 @@ class TestIsWithinMeshVolume(unittest.TestCase):
         Initialises common tests attributes.
         """
 
-        self._mesh = np.array([[-1.0, -1.0, 1.0],
-                               [1.0, -1.0, 1.0],
-                               [1.0, -1.0, -1.0],
-                               [-1.0, -1.0, -1.0],
-                               [0.0, 1.0, 0.0]])
+        self._mesh = np.array(
+            [[-1.0, -1.0, 1.0],
+             [1.0, -1.0, 1.0],
+             [1.0, -1.0, -1.0],
+             [-1.0, -1.0, -1.0],
+             [0.0, 1.0, 0.0]])  # yapf: disable
 
     def test_is_within_mesh_volume(self):
         """
@@ -47,20 +47,20 @@ class TestIsWithinMeshVolume(unittest.TestCase):
         """
 
         self.assertTrue(
-            is_within_mesh_volume(np.array([0.0005, 0.0031, 0.0010]),
-                                  self._mesh))
+            is_within_mesh_volume(
+                np.array([0.0005, 0.0031, 0.0010]), self._mesh))
 
         self.assertFalse(
-            is_within_mesh_volume(np.array([0.3205, 0.4131, 0.5100]),
-                                  self._mesh))
+            is_within_mesh_volume(
+                np.array([0.3205, 0.4131, 0.5100]), self._mesh))
 
         self.assertTrue(
-            is_within_mesh_volume(np.array([0.0025, 0.0088, 0.0340]),
-                                  self._mesh))
+            is_within_mesh_volume(
+                np.array([0.0025, 0.0088, 0.0340]), self._mesh))
 
         self.assertFalse(
-            is_within_mesh_volume(np.array([0.4325, 0.3788, 0.1034]),
-                                  self._mesh))
+            is_within_mesh_volume(
+                np.array([0.4325, 0.3788, 0.1034]), self._mesh))
 
     def test_n_dimensional_is_within_mesh_volume(self):
         """
@@ -70,21 +70,15 @@ class TestIsWithinMeshVolume(unittest.TestCase):
 
         a = np.array([0.0005, 0.0031, 0.0010])
         b = np.array([True])
-        np.testing.assert_almost_equal(
-            is_within_mesh_volume(a, self._mesh),
-            b)
+        np.testing.assert_almost_equal(is_within_mesh_volume(a, self._mesh), b)
 
         a = np.tile(a, (6, 1))
         b = np.tile(b, 6)
-        np.testing.assert_almost_equal(
-            is_within_mesh_volume(a, self._mesh),
-            b)
+        np.testing.assert_almost_equal(is_within_mesh_volume(a, self._mesh), b)
 
         a = np.reshape(a, (2, 3, 3))
         b = np.reshape(b, (2, 3))
-        np.testing.assert_almost_equal(
-            is_within_mesh_volume(a, self._mesh),
-            b)
+        np.testing.assert_almost_equal(is_within_mesh_volume(a, self._mesh), b)
 
     @ignore_numpy_errors
     def test_nan_is_within_mesh_volume(self):
