@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """
 Defines unit tests for :mod:`colour.volume.rgb` module.
 
@@ -25,13 +24,10 @@ from __future__ import division, unicode_literals
 import numpy as np
 import unittest
 
-from colour.models import (
-    ACES_2065_1_COLOURSPACE,
-    REC_2020_COLOURSPACE,
-    REC_709_COLOURSPACE)
+from colour.models import (ACES_2065_1_COLOURSPACE, REC_2020_COLOURSPACE,
+                           REC_709_COLOURSPACE)
 from colour.volume import (
-    RGB_colourspace_limits,
-    RGB_colourspace_volume_MonteCarlo,
+    RGB_colourspace_limits, RGB_colourspace_volume_MonteCarlo,
     RGB_colourspace_volume_coverage_MonteCarlo,
     RGB_colourspace_pointer_gamut_coverage_MonteCarlo,
     RGB_colourspace_visible_spectrum_coverage_MonteCarlo,
@@ -44,11 +40,12 @@ __maintainer__ = 'Colour Developers'
 __email__ = 'colour-science@googlegroups.com'
 __status__ = 'Production'
 
-__all__ = ['TestRGB_colourspaceLimits',
-           'TestRGB_colourspaceVolumeMonteCarlo',
-           'TestRGB_colourspace_volume_coverage_MonteCarlo',
-           'TestRGB_colourspacePointerGamutCoverageMonteCarlo',
-           'TestRGB_colourspaceVisibleSpectrumCoverageMonteCarlo']
+__all__ = [
+    'TestRGB_colourspaceLimits', 'TestRGB_colourspaceVolumeMonteCarlo',
+    'TestRGB_colourspace_volume_coverage_MonteCarlo',
+    'TestRGB_colourspacePointerGamutCoverageMonteCarlo',
+    'TestRGB_colourspaceVisibleSpectrumCoverageMonteCarlo'
+]
 
 
 class TestRGB_colourspaceLimits(unittest.TestCase):
@@ -64,22 +61,21 @@ class TestRGB_colourspaceLimits(unittest.TestCase):
 
         np.testing.assert_almost_equal(
             RGB_colourspace_limits(REC_709_COLOURSPACE),
-            np.array([[0.00000000, 100.00000000],
-                      [-79.21854477, 94.65669508],
+            np.array([[0.00000000, 100.00000000], [-79.21854477, 94.65669508],
                       [-114.78759841, 96.72026446]]),
             decimal=7)
 
         np.testing.assert_almost_equal(
             RGB_colourspace_limits(REC_2020_COLOURSPACE),
-            np.array([[0.00000000, 100.00000000],
-                      [-159.59726205, 127.32669335],
+            np.array([[0.00000000,
+                       100.00000000], [-159.59726205, 127.32669335],
                       [-129.74325643, 142.13784519]]),
             decimal=7)
 
         np.testing.assert_almost_equal(
             RGB_colourspace_limits(ACES_2065_1_COLOURSPACE),
-            np.array([[-79.45116285, 103.30589122],
-                      [-461.76531700, 176.36321555],
+            np.array([[-79.45116285,
+                       103.30589122], [-461.76531700, 176.36321555],
                       [-309.68548384, 184.82616441]]),
             decimal=7)
 
@@ -101,8 +97,7 @@ class TestRGB_colourspaceVolumeMonteCarlo(unittest.TestCase):
                 REC_709_COLOURSPACE,
                 10e3,
                 random_state=np.random.RandomState(2),
-                processes=1),
-            858600.0)
+                processes=1), 858600.0)
 
 
 class TestRGB_colourspace_volume_coverage_MonteCarlo(unittest.TestCase):
